### Shrubs, bryophytes and snow influence microclimate across topographic and moisture gradients in the Arctic tundra
### von Oppen J, et al. 2022

### Data exploration and analyses

### by Jonathan von Oppen, Aarhus University, jonathan.vonoppen@bio.au.dk, Feb 2020 - January 2022
### (sections 1-3 partly based on code by Jakob Assmann, j.assmann@bio.au.dk)



### 0) Dependencies ----

  # >> [a] packages ----
  
    # load pacman package from the repository, if you do not already have it
    if(!require(pacman)){       # provides p_load() as wrapper for require() and library()
      install.packages("pacman")
      library(pacman)
    }
    pacman::p_load(tidyverse,   # for multiple data wrangling & visualisation packages
                   tidylog,     # to log operations in pipes
                   magrittr,    # for piping functions
                   lubridate,   # to wrangle dates and times
                   corrr,       # for correlations
                   usdm,        # for VIF analysis
                   MCMCglmm,    # for Bayesian GLMM
                   cowplot,     
                   patchwork,   # to combine plots in panels
                   lemon)       # to reposition ggplot legends
  
  # >> [b] functions ----
  
    # load model and plotting functions
    source(file = file.path("scripts", "functions.R"))
  
  
  # >> [c] colour scheme ----

    theme_purple <- "#8757B3"
    theme_darkblue <- "#4f5faf"
    theme_lightblue <- "#5995c5"
    theme_yellow <- "#ffcc00"
    theme_orange <- "#c87e1f"
    theme_red <- "#a44748"
    theme_violet <- "#a177e0"
    theme_green <- "#58bb5b"
    theme_brown <- "#9e5f3f"
    theme_turquoise <- "#28BECB"
    theme_darkgreen <- "#355d00"
    theme_darkred <- "#7c3f3f"
    theme_forestgreen <- "#3d8225"
    theme_grey <- "#EDEDEDFF"
  
  
  # >> [d] directories ----
  
    # figures
    if(!dir.exists("figures")) dir.create("figures")
    
    # model outputs
    if(!dir.exists("model_outputs")) dir.create("model_outputs")



### 1) Data exploration ----

# load data
disko_plotdata_complete <- read_csv(file = file.path("data", "plot_data", "processed", "microclim_plot_data_complete.csv"))

temp_offset_responses <- c("tms_dT4T3_mean_season19", "tms_dT4T3_min_season19", "tms_dT4T3_max_season19", "tms_dT4T3_amp_season19", "tms_dT4T3_range_season19",
                           "tms_dT4T1_mean_season19", "tms_dT4T1_min_season19", "tms_dT4T1_max_season19", "tms_dT4T1_amp_season19", "tms_dT4T1_range_season19",
                           "tms_dT3T1_mean", "tms_dT3T1_min", "tms_dT3T1_max", "tms_dT3T1_amp", "tms_dT3T1_range",
                           "tms_dT3T2_mean", "tms_dT3T2_min", "tms_dT3T2_max", "tms_dT3T2_amp", "tms_dT3T2_range", 
                           "tms_dT2T1_mean", "tms_dT2T1_min", "tms_dT2T1_max", "tms_dT2T1_amp", "tms_dT2T1_range",
                           "hobo_dT4hobo_mean_ndjfm1920", "hobo_dT4hobo_min_ndjfm1920", "hobo_dT4hobo_max_ndjfm1920", "hobo_dT4hobo_amp_ndjfm1920", "hobo_dT4hobo_range_ndjfm1920")

# >> [a] temperature offset variables: histograms ----

# histogram - separate panels
plot_list_temp_hist <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = get(x))) + 
    geom_density() + 
    xlab(x)})
plot_grid(plotlist = plot_list_temp_hist, nrow = 6, ncol = 5)

# histogram - overlapping density plots
hist_df_delta_temp <- disko_plotdata_complete %>% 
  
  select(all_of(temp_offset_responses)) %>% 
  
  pivot_longer(cols = everything(),
               names_to = "variable",
               values_to = "temp_value") %>% 
  
  mutate(stat_group = factor(str_extract(variable, "mean|min|max|amp|range"),
                             levels = c("mean", "min", "max", "amp", "range")),
         sensor_pair = factor(str_extract(variable, "dT\\d[:alnum:]+"),
                              levels = c("dT4T3", "dT4T1", "dT3T1", "dT3T2", "dT2T1", "dT4hobo")),
         sensor_pair = forcats::fct_recode(sensor_pair,
                                           "canopy - air" = "dT4T3",
                                           "soil (summer) - air" = "dT4T1",
                                           "soil - canopy" = "dT3T1",
                                           "near-surface - canopy" = "dT3T2",
                                           "soil - near-surface" = "dT2T1",
                                           "soil (winter) - air" = "dT4hobo"))

temp_delta_densities <- ggplot(hist_df_delta_temp) +
  
  geom_density(aes(x = temp_value,
                   colour = sensor_pair,
                   fill = sensor_pair),
               alpha = 0.6,
               size = 1.3) +
  
  facet_wrap(~stat_group,
             nrow = 2, ncol = 3,
             scales = "free_y") +
  
  scale_colour_manual(values = c(theme_purple, theme_darkblue, theme_yellow, theme_orange, theme_red, theme_lightblue)) +
  scale_fill_manual(values = c(theme_purple, theme_darkblue, theme_yellow, theme_orange, theme_red, theme_lightblue)) +
  theme_cowplot(16)

# adjust legend position
(temp_delta_densities <- reposition_legend(temp_delta_densities,
                                           position = "center",
                                           panel = "panel-3-2"))

    # NOTE => much more variation in winter air-soil temps than in other variables!!

# save plot
save_plot(temp_delta_densities,
          file = file.path("scripts", "jonathan", "plots", "microclim_delta_temp_variables_density_plots.png"),
          base_height = 10, base_aspect_ratio = 1.5)


# >> [b] T offset variables vs. predictors (50 cm circles): scatterplot matrices ----

# vs. elevation
plot_list_temp_elev <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = elevation, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_elev, nrow = 6, ncol = 5)

# vs. aspect
plot_list_temp_aspect <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = aspect, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_aspect, nrow = 6, ncol = 5)

# vs. SRI (summer)
plot_list_temp_sri_s <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = sri_season19, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_sri_s, nrow = 6, ncol = 5)

# vs. SRI (winter)
plot_list_temp_sri_w <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = sri_ndjfm1920, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_sri_w, nrow = 6, ncol = 5)

# vs. landform/topographic position
plot_list_temp_topo <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = topo_prim_num, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_topo, nrow = 6, ncol = 5)

# vs. snow cover duration
plot_list_temp_snow <- lapply(temp_offset_responses[26:30], function(x) {
  ggplot(disko_plotdata_complete, aes(x = ndays_snowcover_ndjfm, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_snow, nrow = 2, ncol = 3)

# vs. soil moisture
plot_list_temp_moist <- lapply(temp_offset_responses[1:25], function(x) {
  ggplot(disko_plotdata_complete, aes(x = tms_moist_vol_mean, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_moist, nrow = 5, ncol = 5)

# vs. rock cover
plot_list_temp_rocks <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_rocks_50, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_rocks, nrow = 6, ncol = 5)

# vs. shrub cover
plot_list_temp_shrubs <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_shrubs_50, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_shrubs, nrow = 6, ncol = 5)

# vs. bryophyte cover
plot_list_temp_bryo <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_bryophytes_50, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_bryo, nrow = 6, ncol = 5)

# vs. lichen cover
plot_list_temp_lichen <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_lichen_50, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_lichen, nrow = 6, ncol = 5)

# vs. veg height
plot_list_temp_veg_ht <- lapply(temp_offset_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = veg_height_avg_50, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_veg_ht, nrow = 6, ncol = 5)


# >> [c] T offset variables vs. predictors (200/564 cm circles): scatterplot matrices ----

temp_offset_responses_area <- c("tms_dT3T1_mean", "tms_dT3T1_min", "tms_dT3T1_max")

# vs. rock cover
# 10 cm
plot_list_temp_rocks_10 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_rocks_10, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
# 200 cm
plot_list_temp_rocks_200 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_rocks_200, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
# 564 cm
plot_list_temp_rocks_564 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_rocks_564, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = c(plot_list_temp_rocks_10,
                       list(plot_list_temp_rocks[[1]], 
                            plot_list_temp_rocks[[2]], 
                            plot_list_temp_rocks[[3]]), 
                       plot_list_temp_rocks_200, 
                       plot_list_temp_rocks_564), nrow = 4, ncol = 3)

# vs. shrub cover
# 10 cm
plot_list_temp_shrubs_10 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_shrubs_10, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
# 200 cm
plot_list_temp_shrubs_200 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_shrubs_200, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
# 564 cm
plot_list_temp_shrubs_564 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_shrubs_564, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = c(plot_list_temp_shrubs_10,
                       list(plot_list_temp_shrubs[[1]], 
                            plot_list_temp_shrubs[[2]], 
                            plot_list_temp_shrubs[[3]]), 
                       plot_list_temp_shrubs_200, 
                       plot_list_temp_shrubs_564), nrow = 4, ncol = 3)

# vs. bryophyte cover
# 10 cm
plot_list_temp_bryo_10 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_bryophytes_10, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
# 200 cm
plot_list_temp_bryo_200 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_bryophytes_200, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
# 564 cm
plot_list_temp_bryo_564 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_bryophytes_564, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = c(plot_list_temp_bryo_10,
                       list(plot_list_temp_bryo[[1]], 
                            plot_list_temp_bryo[[2]], 
                            plot_list_temp_bryo[[3]]), 
                       plot_list_temp_bryo_200, 
                       plot_list_temp_bryo_564), nrow = 4, ncol = 3)

# vs. lichen cover
# 10 cm
plot_list_temp_lichen_10 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_lichen_10, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
# 200 cm
plot_list_temp_lichen_200 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_lichen_200, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
# 564 cm
plot_list_temp_lichen_564 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_lichen_564, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = c(plot_list_temp_lichen_10,
                       list(plot_list_temp_lichen[[1]], 
                            plot_list_temp_lichen[[2]], 
                            plot_list_temp_lichen[[3]]), 
                       plot_list_temp_lichen_200, 
                       plot_list_temp_lichen_564), nrow = 4, ncol = 3)

# vs. veg height
# 10 cm
plot_list_temp_veg_ht_10 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = veg_height_avg_10, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
# 200 cm
plot_list_temp_veg_ht_200 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = veg_height_avg_200, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
# 564 cm
plot_list_temp_veg_ht_564 <- lapply(temp_offset_responses_area, function(x) {
  ggplot(disko_plotdata_complete, aes(x = veg_height_avg_564, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = c(plot_list_temp_veg_ht_10,
                       list(plot_list_temp_veg_ht[[1]], 
                            plot_list_temp_veg_ht[[2]], 
                            plot_list_temp_veg_ht[[3]]), 
                       plot_list_temp_veg_ht_200, 
                       plot_list_temp_veg_ht_564), nrow = 4, ncol = 3)



# >> [d] trait values ----

# load data
disko_traits <- read.csv(file.path("data", "microclim", "species_traits", "processed", "microclim_traits_cleaned.csv"),
                         header = TRUE)

# observation level
plot_list_traits <- lapply(c("la", "sla", "ldmc", 
                             "height_veg", "height_tot", 
                             "total_N_perc", "total_C_perc", 
                             "d15N_permill", "d13C_permill"), function(x) {
  ggplot(disko_traits, aes(x = get(x))) + geom_histogram() + xlab(x)}) 
plot_grid(plotlist = plot_list_traits, nrow = 3, ncol = 3)
# consider log transforming LA & heights:  + scale_x_continuous(trans = "log")

# CWMs
# 50 cm circles
plot_list_cwm_traits_50 <- lapply(paste("cwm", c("la", "sla", "ldmc", "height_veg", "height_tot"),"50",sep = "_"), function(x) {
  ggplot(cwm_traits_50, aes(x = get(x))) + geom_histogram() + xlab(x)+ scale_x_continuous(trans = "log")}) 
plot_grid(plotlist = plot_list_cwm_traits_50, nrow = 3, ncol = 2)
# 200 cm circles
plot_list_cwm_traits_200 <- lapply(paste("cwm", c("la", "sla", "ldmc", "height_veg", "height_tot"),"200",sep = "_"), function(x) {
  ggplot(cwm_traits_200, aes(x = get(x))) + geom_histogram() + xlab(x)+ scale_x_continuous(trans = "log")}) 
plot_grid(plotlist = plot_list_cwm_traits_200, nrow = 3, ncol = 2)

# >> [e] plot cover, terrain, species richness ----
# group cover variables
cover_vars <- c("cov_shrubs_50", "cov_vascular_50", "cov_bryophytes_50", "cov_lichen_50", "cov_bare_50", "cov_rocks_50")
plot_list_meta <- lapply(cover_vars, function(x) {
  ggplot(disko_plotdata_complete, aes(x = get(x))) + geom_density() + xlab(x)})
plot_grid(plotlist = plot_list_meta, nrow = 3, ncol = 2)
# plot terrain & diversity variables
plot_list_meta <- lapply(c("slope", "aspect", "plant_div_50", "plant_div_200"), function(x) {
  ggplot(disko_plotdata_complete, aes(x = get(x))) + geom_histogram() + xlab(x)})
plot_grid(plotlist = plot_list_meta, nrow = 2, ncol = 2)

# >> [f] mean temperature variables: histograms ----
mean_temp_responses <- c("station_T4_mean_canopy_season19", "station_T4_min_canopy_season19", "station_T4_max_canopy_season19", "station_T4_amp_canopy_season19", "station_T4_range_canopy_season19",
                         "tms_T3_mean", "tms_T3_min", "tms_T3_max", "tms_T3_amp", "tms_T3_range",
                         "tms_T2_mean", "tms_T2_min", "tms_T2_max", "tms_T2_amp", "tms_T2_range",
                         "tms_T1_mean", "tms_T1_min", "tms_T1_max", "tms_T1_amp", "tms_T1_range",
                         "station_T4_mean_soil_ndjfm1920", "station_T4_min_soil_ndjfm1920", "station_T4_max_soil_ndjfm1920", "station_T4_amp_soil_ndjfm1920", "station_T4_range_soil_ndjfm1920",
                         "hobo_mean_ndjfm1920", "hobo_min_ndjfm1920", "hobo_max_ndjfm1920", "hobo_amp_ndjfm1920", "hobo_range_ndjfm1920")

# histograms - separate panels
plot_list_temp_hist <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = get(x))) + 
    geom_histogram() + 
    xlab(x)})
plot_grid(plotlist = plot_list_temp_hist, nrow = 4, ncol = 5)


# histogram - overlapping density plots
hist_df_mean_temp <- disko_plotdata_complete %>% 
  
  select(all_of(mean_temp_responses)) %>% 
  
  pivot_longer(cols = everything(),
               names_to = "variable",
               values_to = "temp_value") %>% 
  
  mutate(stat_group = factor(str_extract(variable, "mean|min|max|amp|range"),
                             levels = c("mean", "min", "max", "amp", "range")),
         sensor = case_when(str_detect(variable, "station.*canopy_season19") ~ "free-air (summer)",
                            str_detect(variable, "station.*soil_ndjfm1920") ~ "free-air (winter)",
                            str_detect(variable, "tms_T3") ~ "canopy-level (TMS T3)",
                            str_detect(variable, "tms_T2") ~ "near-surface (TMS T2)",
                            str_detect(variable, "tms_T1") ~ "soil (summer, TMS T1)",
                            str_detect(variable, "hobo") ~ "soil (winter, HOBO)",
                            TRUE ~ NA_character_),
         sensor = factor(sensor,
                         levels = c("free-air (summer)", 
                                    "canopy-level (TMS T3)", 
                                    "near-surface (TMS T2)", 
                                    "soil (summer, TMS T1)", 
                                    "free-air (winter)", 
                                    "soil (winter, HOBO)")))

temp_means_densities <- ggplot(hist_df_mean_temp) +
  
  geom_density(aes(x = temp_value,
                   colour = sensor,
                   fill = sensor),
               alpha = 0.6,
               size = 1.3) +
  
  facet_wrap(~stat_group,
             nrow = 2, ncol = 3,
             scales = "free_y") +
  
  scale_colour_manual(values = c(theme_purple, theme_darkblue, theme_yellow, theme_orange, theme_red, theme_lightblue)) +
  scale_fill_manual(values = c(theme_purple, theme_darkblue, theme_yellow, theme_orange, theme_red, theme_lightblue)) +
  theme_cowplot(16)

# adjust legend position
(temp_means_densities <- reposition_legend(temp_means_densities,
                                           position = "center",
                                           panel = "panel-3-2"))

# NOTE => much more variation in winter air-soil temps than in other variables!!

# save plot
save_plot(temp_means_densities,
          file = file.path("scripts", "jonathan", "plots", "microclim_mean_temp_variables_density_plots.png"),
          base_height = 10, base_aspect_ratio = 1.5)


# >> [g] mean T variables vs. predictors (50 cm circles): scatterplot matrices ----

# vs. elevation
plot_list_temp_elev <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = elevation, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_elev, nrow = 6, ncol = 5)

# vs. aspect
plot_list_temp_aspect <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = aspect, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_aspect, nrow = 6, ncol = 5)

# vs. SRI (summer)
plot_list_temp_sri_s <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = sri_season19, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_sri_s, nrow = 6, ncol = 5)

# vs. SRI (winter)
plot_list_temp_sri_w <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = sri_ndjfm1920, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_sri_w, nrow = 6, ncol = 5)

# vs. landform/topographic position
plot_list_temp_topo <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = topo_prim_num, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_topo, nrow = 6, ncol = 5)

# vs. snow cover duration
plot_list_temp_snow <- lapply(mean_temp_responses[21:30], function(x) {
  ggplot(disko_plotdata_complete, aes(x = ndays_snowcover_ndjfm, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_snow, nrow = 2, ncol = 5)

# vs. soil moisture
plot_list_temp_moist <- lapply(mean_temp_responses[1:25], function(x) {
  ggplot(disko_plotdata_complete, aes(x = tms_moist_vol_mean, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_moist, nrow = 5, ncol = 5)

# vs. rock cover
plot_list_temp_rocks <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_rocks_50, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_rocks, nrow = 6, ncol = 5)

# vs. shrub cover
plot_list_temp_shrubs <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_shrubs_50, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_shrubs, nrow = 6, ncol = 5)

# vs. bryophyte cover
plot_list_temp_bryo <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_bryophytes_50, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_bryo, nrow = 6, ncol = 5)

# vs. lichen cover
plot_list_temp_lichen <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = cov_lichen_50, y = get(x))) + 
    geom_point() + 
    geom_smooth() +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_lichen, nrow = 6, ncol = 5)

# vs. veg height
plot_list_temp_veg_ht <- lapply(mean_temp_responses, function(x) {
  ggplot(disko_plotdata_complete, aes(x = veg_height_avg_50, y = get(x))) + 
    geom_point() + 
    geom_smooth(method = "lm") +
    ylab(x)})
plot_grid(plotlist = plot_list_temp_veg_ht, nrow = 6, ncol = 5)


### 2) Model to analyse effects of topography and vegetation on microclimate ----

# load data
# growing season 2019
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))
# winter 2019-20
disko_data_complete_ndjfm1920 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_ndjfm1920.csv"))

# >> select predictors ---- 
# ¨¨¨¨ 2019 growing season ----
# explore correlation and multicollinearity patterns
predictor_variables_50_season19_all <- c(
  # free-air temperatures
  "station_base_daily_mean_temp", "station_base_daily_min_temp", "station_base_daily_max_temp",
  # abiotic plot variables
  "elevation", "slope", "sri_season19", "topo_prim_num", "tms_moist_vol_mean_scaled", "cov_rocks_50", "cov_bare_50", 
  # biotic plot variables
  "cov_shrubs_50", "cov_bryophytes_50", "cov_lichen_50", "cov_litter_50", "veg_height_avg_50", 
  # potentially confounding veg-at-TMS variables
  "veg_height_avg_tms", "cover_tms_top", "cover_tms_low", "cover_tms_ground")

# create basic correlation matrix
cor_mat_season19 <- disko_data_complete_season19 %>% 
  dplyr::select(all_of(predictor_variables_50_season19_all)) %>% 
  corrr::correlate(diagonal = 1) %>% 
  # drop all values < .4 to increase readability
  mutate_if(is.numeric, ~ ifelse(abs(.) < .4, NA, .)) %T>% View()
# => high correlation with many other variables in shrub cover, but central for hypothesis -> keep!
# => tms measures highly correlated with other variables, esp. with shrub cover -> drop
# => bare ground (-0.683) & litter (.590) highly correlated w/ shrub cover  -> drop
# => free-air variables highly correlated -> doesn't matter as not included simultaneously

# define predictors for mean, min max temperatures
predictor_variables_50_season19_vif <- list(
  setdiff(predictor_variables_50_season19_all, c("station_base_daily_min_temp", "station_base_daily_max_temp")), # incl free-air MEAN temperatures
  setdiff(predictor_variables_50_season19_all, c("station_base_daily_mean_temp", "station_base_daily_max_temp")), # incl free-air MIN temperatures
  setdiff(predictor_variables_50_season19_all, c("station_base_daily_mean_temp", "station_base_daily_min_temp")) # incl free-air MAX temperatures
)

# define correlated variables to be removed
vars_to_remove_season19 <- disko_data_complete_season19 %>% dplyr::select(contains("_tms"), cov_bare_50, cov_litter_50) %>% names()

# check VIF
predictor_variables_50_season19_vif %>% 
  purrr::map(~ disko_data_complete_season19 %>% 
               dplyr::select(all_of(.x), -all_of(vars_to_remove_season19)) %>% 
               as.data.frame() %>% 
               usdm::vif())

# all VIF < 2.4 -> OK! >> extract predictors:
predictor_variables_50_season19 <- list(
  setdiff(predictor_variables_50_season19_all, c("station_base_daily_min_temp", "station_base_daily_max_temp", # incl free-air MEAN temperatures
                                                 vars_to_remove_season19)), 
  setdiff(predictor_variables_50_season19_all, c("station_base_daily_mean_temp", "station_base_daily_max_temp", # incl free-air MIN temperatures
                                                 vars_to_remove_season19)),
  setdiff(predictor_variables_50_season19_all, c("station_base_daily_mean_temp", "station_base_daily_min_temp", # incl free-air MAX temperatures
                                                 vars_to_remove_season19))
)


# ¨¨¨¨ 2019/20 winter season ----
# explore correlation and multicollinearity patterns
predictor_variables_50_ndjfm1920_all <- c(
  # free-air temperatures
  "station_base_daily_mean_temp", "station_base_daily_min_temp", "station_base_daily_max_temp",
  # abiotic plot variables
  "elevation", "slope", "sri_ndjfm1920", "topo_prim_num", "ndays_snowcover_ndjfm", "cov_rocks_50", "cov_bare_50", 
  # biotic plot variables
  "cov_shrubs_50", "veg_height_avg_50", 
  # potentially confounding veg-at-TMS variables
  "veg_height_avg_hobo", "cover_hobo_ground")

# create basic correlation matrix
cor_mat_ndjfm1920 <- disko_data_complete_ndjfm1920 %>% 
  dplyr::select(all_of(predictor_variables_50_ndjfm1920_all)) %>% 
  corrr::correlate(diagonal = 1) %>% 
  # drop all values < .4 to increase readability
  mutate_if(is.numeric, ~ ifelse(abs(.) < .4, NA, .)) %T>% View()
# => high correlation with many other variables in shrub cover, but central for hypothesis -> keep!
# => hobo veg measures highly correlated with shrub cover & avg veg height -> drop
# => slope & SRI(winter) highly correlated (0.83) -> drop slope, as SRI holds more ecologically relevant information
# => bare ground (-0.683) highly correlated w/ shrub cover  -> drop
# => free-air variables highly correlated -> doesn't matter as not included simultaneously

# define predictors for mean, min max temperatures
predictor_variables_50_ndjfm1920_vif <- list(
  setdiff(predictor_variables_50_ndjfm1920_all, c("station_base_daily_min_temp", "station_base_daily_max_temp")), # incl free-air MEAN temperatures
  setdiff(predictor_variables_50_ndjfm1920_all, c("station_base_daily_mean_temp", "station_base_daily_max_temp")), # incl free-air MIN temperatures
  setdiff(predictor_variables_50_ndjfm1920_all, c("station_base_daily_mean_temp", "station_base_daily_min_temp")) # incl free-air MAX temperatures
)

# define correlated variables to be removed
vars_to_remove_ndjfm1920 <- disko_data_complete_ndjfm1920 %>% dplyr::select(contains("_hobo"), slope, cov_bare_50) %>% names()

# check VIF
predictor_variables_50_ndjfm1920_vif %>% 
  purrr::map(~ disko_data_complete_ndjfm1920 %>% 
               dplyr::select(all_of(.x), -all_of(vars_to_remove_ndjfm1920)) %>% 
               as.data.frame() %>% 
               usdm::vif())

# all VIF < 2 -> OK! >> extract predictors:
predictor_variables_50_ndjfm1920 <- list(
  setdiff(predictor_variables_50_ndjfm1920_all, c("station_base_daily_min_temp", "station_base_daily_max_temp", # incl free-air MEAN temperatures
                                                 vars_to_remove_ndjfm1920)), 
  setdiff(predictor_variables_50_ndjfm1920_all, c("station_base_daily_mean_temp", "station_base_daily_max_temp", # incl free-air MIN temperatures
                                                 vars_to_remove_ndjfm1920)),
  setdiff(predictor_variables_50_ndjfm1920_all, c("station_base_daily_mean_temp", "station_base_daily_min_temp", # incl free-air MAX temperatures
                                                 vars_to_remove_ndjfm1920))
)

# >> scale predictor variables and remove NAs ----
disko_data_scaled_50_season19 <- disko_data_complete_season19 %>% 
  
  mutate_at(all_of(predictor_variables_50_season19_all), ~ scale(.x, scale = TRUE, center = TRUE)) %>% 
  
  drop_na(tms_moist_vol_mean_scaled) %>% # drop rows with NAs in soil moisture: all (moist) values removed from LDI_020 & 063, 
                                                                                    # plus 14 - 16-07-2019 for LDI_070 and 19 - 23-07-2019 for LDI_081
  
  mutate(plot_id_num = as.numeric(str_extract(plot_id, "\\d{2}$"))) # n(unique) = 88, as all (moist) values removed from LDI_020 & 063

disko_data_scaled_50_ndjfm1920 <- disko_data_complete_ndjfm1920 %>% 
  
  mutate_at(all_of(predictor_variables_50_ndjfm1920_all), ~ scale(.x, scale = TRUE, center = TRUE)) %>% 
  
  drop_na(ndays_snowcover_ndjfm) %>%    # drop rows with NAs in snow cover: complete record for LDI_078
  
  mutate(plot_id_num = as.numeric(str_extract(plot_id, "\\d{2}$"))) # n(unique) = 83, as no soil temp data for LDI_


# >> [a] 50 cm circles: canopy-level temperatures ----

# define responses
response_variables_T3 <- c("tms_T3_mean", "tms_T3_min", "tms_T3_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_T3_50 <- mapply(model_function_mcmc,
                                response_variables_T3, 
                                predictor_variables_50_season19,
                                MoreArgs = list(data = disko_data_scaled_50_season19),
                                SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_T3_50,
#      file = file.path("model_outputs", "model_output_T3_50.Rdata"))
# load(file.path("model_outputs", "model_output_T3_50.Rdata"))

# check model convergence
plot(model_list_mcmc_T3_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_T3_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_T3_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_T3_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.061


# >> [b] 50 cm circles: near-surface temperatures ----
# define responses
response_variables_T2 <- c("tms_T2_mean", "tms_T2_min", "tms_T2_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_T2_50 <- mapply(model_function_mcmc,
                                response_variables_T2, 
                                predictor_variables_50_season19,
                                MoreArgs = list(data = disko_data_scaled_50_season19),
                                SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_T2_50,
#      file = file.path("model_outputs", "model_output_T2_50.Rdata"))
# load(file.path("model_outputs", "model_output_T2_50.Rdata"))

# check model convergence
plot(model_list_mcmc_T2_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_T2_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_T2_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_T2_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < .0.053


# >> [c] 50 cm circles: soil temperatures (summer, TMS T1) ----
# define responses
response_variables_T1 <- c("tms_T1_mean", "tms_T1_min", "tms_T1_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_T1_50 <- mapply(model_function_mcmc,
                                response_variables_T1, 
                                predictor_variables_50_season19,
                                MoreArgs = list(data = disko_data_scaled_50_season19),
                                SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_T1_50,
#      file = file.path("model_outputs", "model_output_T1_50.Rdata"))
# load(file.path("model_outputs", "model_output_T1_50.Rdata"))

# check model convergence
plot(model_list_mcmc_T1_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_T1_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_T1_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_T1_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.057


# >> [d] 50 cm circles: soil temperatures (winter, HOBO) ----

# define responses
response_variables_hobo <- c("hobo_temp_mean", "hobo_temp_min", "hobo_temp_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_hobo_50 <- mapply(model_function_mcmc,
                                  response_variables_hobo, 
                                  predictor_variables_50_ndjfm1920,
                                  MoreArgs = list(data = disko_data_scaled_50_ndjfm1920),
                                  SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_hobo_50,
#      file = file.path("model_outputs", "model_output_hobo_ndjfm_50.Rdata"))
# load(file.path("model_outputs", "model_output_hobo_ndjfm_50.Rdata"))

# check model convergence
plot(model_list_mcmc_hobo_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_hobo_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_hobo_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_hobo_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.06


# >> extract mean effect sizes for all predictors, strata and temp vars ----

# load model outputs
lapply(paste0("model_outputs/", list.files("model_outputs", pattern = paste0("^model_output_", c("T\\d", "hobo"), ".*", collapse = "|"))),
       load,
       .GlobalEnv)

# extract solutions for all offset models
(solutions_summary_means_tot <- bind_rows(lapply(model_list_mcmc_T3_50, extract_model_solutions, radius = 50) %>% 
                                            bind_rows(),
                                          lapply(model_list_mcmc_T2_50, extract_model_solutions, radius = 50) %>% 
                                            bind_rows(),
                                          lapply(model_list_mcmc_T1_50, extract_model_solutions, radius = 50) %>% 
                                            bind_rows(),
                                          lapply(model_list_mcmc_hobo_50, extract_model_solutions, radius = 50) %>% 
                                            bind_rows()) %>% 
    
    # change factor level order for parameters
    mutate(parameter = fct_relevel(parameter,
                                   c("post.mean",
                                     "l95",
                                     "u95"))) %>% 
    # filter for means only
    filter(parameter == "post.mean") %>% 
    
    # calculate means of solution parameters
    group_by(variable, radius, parameter) %>% 
    
    summarise(mean_value = mean(abs(value))) %>% ungroup() %>% 
    
    # arrange by descending mean value for each group
    group_by(parameter) %>% 
    arrange(desc(mean_value), .by_group = TRUE) %>% ungroup())

# output: for r = 200 and r = 564 only dT3T1 models included!

# filter for 50 cm circles only
(solutions_summary_means_50 <-  solutions_summary_means_tot %>% 
    
    filter(radius == 50))


# >> [e] 50 cm circles: soil - canopy (dT3T1) ----

# define responses
response_variables_dT3T1 <- c("tms_dT3T1_mean", "tms_dT3T1_min", "tms_dT3T1_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_dT3T1_50 <- mapply(model_function_mcmc,
                                   response_variables_dT3T1, 
                                   predictor_variables_50_season19,
                                   MoreArgs = list(data = disko_data_scaled_50_season19),
                                   SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT3T1_50,
#      file = file.path("model_outputs", "model_output_dT3T1_50.Rdata"))
# load(file.path("model_outputs", "model_output_dT3T1_50.Rdata"))

# check model convergence
plot(model_list_mcmc_dT3T1_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT3T1_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.084


# >> [f] 50 cm circles: ground - canopy (dT3T2) ----

# define responses
response_variables_dT3T2 <- c("tms_dT3T2_mean", "tms_dT3T2_min", "tms_dT3T2_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_dT3T2_50 <- mapply(model_function_mcmc,
                                   response_variables_dT3T2, 
                                   predictor_variables_50_season19,
                                   MoreArgs = list(data = disko_data_scaled_50_season19),
                                   SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT3T2_50,
#      file = file.path("model_outputs", "model_output_dT3T2_50.Rdata"))
# load(file.path("model_outputs", "model_output_dT3T2_50.Rdata"))

# check model convergence
# check traceplots
plot(model_list_mcmc_dT3T2_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T2_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T2_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT3T2_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.064


# >> [g] 50 cm circles: soil - ground (dT2T1) ----
# define responses
response_variables_dT2T1 <- c("tms_dT2T1_mean", "tms_dT2T1_min", "tms_dT2T1_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_dT2T1_50 <- mapply(model_function_mcmc,
                                   response_variables_dT2T1, 
                                   predictor_variables_50_season19,
                                   MoreArgs = list(data = disko_data_scaled_50_season19),
                                   SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT2T1_50,
#      file = file.path("model_outputs", "model_output_dT2T1_50.Rdata"))
# load(file.path("model_outputs", "model_output_dT2T1_50.Rdata"))

# check model convergence
plot(model_list_mcmc_dT2T1_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT2T1_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT2T1_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT2T1_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.046


# >> [h] 50 cm circles: soil - free-air (winter, dT4hobo) ----

# define responses
response_variables_dT4hobo_ndjfm <- c("hobo_dT4hobo_mean", "hobo_dT4hobo_min", "hobo_dT4hobo_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_dT4hobo_ndjfm_50 <- mapply(model_function_mcmc,
                                           response_variables_dT4hobo_ndjfm, 
                                           predictor_variables_50_ndjfm1920,
                                           MoreArgs = list(data = disko_data_scaled_50_ndjfm1920),
                                           SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT4hobo_ndjfm_50,
#      file = file.path("model_outputs", "model_output_dT4hobo_ndjfm_50.Rdata"))
# load(file.path("model_outputs", "model_output_dT4hobo_ndjfm_50.Rdata"))

# check model convergence
plot(model_list_mcmc_dT4hobo_ndjfm_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT4hobo_ndjfm_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT4hobo_ndjfm_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT4hobo_ndjfm_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.051


# >> [i] 50 cm circles: canopy - free-air (dT4T3) ----

# define responses
response_variables_dT4T3 <- c("tms_dT4T3_mean", "tms_dT4T3_min", "tms_dT4T3_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_dT4T3_50 <- mapply(model_function_mcmc,
                                   response_variables_dT4T3, 
                                   predictor_variables_50_season19,
                                   MoreArgs = list(data = disko_data_scaled_50_season19),
                                   SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT4T3_50,
#      file = file.path("model_outputs", "model_output_dT4T3_50.Rdata"))
# load(file.path("model_outputs", "model_output_dT4T3_50.Rdata"))

# check model convergence
plot(model_list_mcmc_dT4T3_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT4T3_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT4T3_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT4T3_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.07


# >> [j] 50 cm circles: soil - free-air (dT4T1) ----

# define responses
response_variables_dT4T1 <- c("tms_dT4T1_mean", "tms_dT4T1_min", "tms_dT4T1_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_dT4T1_50 <- mapply(model_function_mcmc,
                                   response_variables_dT4T1, 
                                   predictor_variables_50_season19,
                                   MoreArgs = list(data = disko_data_scaled_50_season19),
                                   SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT4T1_50,
#      file = file.path("model_outputs", "model_output_dT4T1_50.Rdata"))
# load(file.path("model_outputs", "model_output_dT4T1_50.Rdata"))

# check model convergence
plot(model_list_mcmc_dT4T1_50[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT4T1_50[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT4T1_50[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT4T1_50, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.044


# >> extract mean effect sizes for all predictors, strata and temp vars ----

# load model outputs
lapply(paste0("model_outputs", "/", list.files("model_outputs", pattern = "*dT\\dT\\d_[0-6]{2,3}.Rdata|*dT4hobo.*.Rdata")),
       load,
       .GlobalEnv)

# extract solutions for all offset models
(solutions_summary_means_tot <- bind_rows(
  # lapply(model_list_mcmc_dT4T3_50, extract_model_solutions, radius = 50) %>% 
  #   bind_rows(),
  # lapply(model_list_mcmc_dT4T1_50, extract_model_solutions, radius = 50) %>% 
  #   bind_rows(),
  lapply(model_list_mcmc_dT3T1_50, extract_model_solutions, radius = 50) %>% 
    bind_rows(),
  lapply(model_list_mcmc_dT3T2_50, extract_model_solutions, radius = 50) %>% 
    bind_rows(),
  lapply(model_list_mcmc_dT2T1_50, extract_model_solutions, radius = 50) %>% 
    bind_rows()#,
  # lapply(model_list_mcmc_dT4hobo_ndjfm_50, extract_model_solutions, radius = 50) %>% 
  #   bind_rows()
                                          ) %>% 
    
    # change factor level order for parameters
    mutate(parameter = fct_relevel(parameter,
                                   c("post.mean",
                                     "l95",
                                     "u95"))) %>% 
    # filter for means only
    filter(parameter == "post.mean") %>%  # filter for temp vars with temp_var == "mean|min|max"
  
    # calculate means of solution parameters
    group_by(variable, radius, parameter) %>% 
    
    summarise(mean_value = mean(abs(value))) %>% ungroup() %>% 
    
    # arrange by descending mean value for each group
    group_by(parameter) %>% 
    arrange(desc(mean_value), .by_group = TRUE) %>% ungroup())



### 3) Circle size effects for topography and vegetation effects on T offsets ----

# load data
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))

# >> [a] 200 cm circles: soil - canopy (dT3T1) ----

# >> select predictors ---- 
# explore correlation and multicollinearity patterns
predictor_variables_200_season19_all <- c(
  # free-air temperatures
  "station_base_daily_mean_temp", "station_base_daily_min_temp", "station_base_daily_max_temp",
  # abiotic plot variables
  "elevation", "slope", "sri_season19", "topo_prim_num", "tms_moist_vol_mean_scaled", "cov_rocks_200", "cov_bare_200", 
  # biotic plot variables
  "cov_shrubs_200", "cov_bryophytes_200", "cov_lichen_200", "cov_litter_200", "veg_height_avg_200", 
  # potentially confounding veg-at-TMS variables
  "veg_height_avg_tms", "cover_tms_top", "cover_tms_low", "cover_tms_ground")

# create basic correlation matrix
cor_mat_200 <- disko_data_complete_season19 %>% 
  dplyr::select(all_of(predictor_variables_200_season19_all)) %>% 
  corrr::correlate(diagonal = 1) %>% 
  # drop all values < .4 to increase readability
  mutate_if(is.numeric, ~ ifelse(abs(.) < .4, NA, .)) %T>% View()
# => high correlation with many other variables in shrub cover, but central for hypothesis -> keep!
# => bare ground (-0.687) & litter (.610) highly correlated w/ shrub cover  -> drop
# => shrub cover highly correlated with avg veg height, but both central for hypotheses -> keep
# => veg-at-TMS variables highly correlated with avg veg height or shrub cover -> drop

# define predictors for mean, min max temperatures
predictor_variables_200_season19_vif <- list(
  setdiff(predictor_variables_200_season19_all, c("station_base_daily_min_temp", "station_base_daily_max_temp")), # incl free-air MEAN temperatures
  setdiff(predictor_variables_200_season19_all, c("station_base_daily_mean_temp", "station_base_daily_max_temp")), # incl free-air MIN temperatures
  setdiff(predictor_variables_200_season19_all, c("station_base_daily_mean_temp", "station_base_daily_min_temp")) # incl free-air MAX temperatures
)

# define correlated variables to be removed
vars_to_remove_200 <- disko_data_complete_season19 %>% dplyr::select(contains("_tms"), cov_bare_200, cov_litter_200) %>% names()

# check VIF
predictor_variables_200_season19_vif %>% 
  purrr::map(~ disko_data_complete_season19 %>% 
               dplyr::select(all_of(.x), -all_of(vars_to_remove_200)) %>% 
               as.data.frame() %>% 
               usdm::vif())

# all VIF < 3.1 -> OK! >> extract predictors:
predictor_variables_200_season19 <- list(
  setdiff(predictor_variables_200_season19_all, c("station_base_daily_min_temp", "station_base_daily_max_temp", # incl free-air MEAN temperatures
                                                 vars_to_remove_200)), 
  setdiff(predictor_variables_200_season19_all, c("station_base_daily_mean_temp", "station_base_daily_max_temp", # incl free-air MIN temperatures
                                                 vars_to_remove_200)),
  setdiff(predictor_variables_200_season19_all, c("station_base_daily_mean_temp", "station_base_daily_min_temp", # incl free-air MAX temperatures
                                                 vars_to_remove_200))
)

# >> scale predictor variables and remove NAs ----
disko_data_scaled_200_season19 <- disko_data_complete_season19 %>% 
  
  mutate_at(all_of(predictor_variables_200_season19_all), ~ scale(.x, scale = TRUE, center = TRUE)) %>% 
  
  drop_na(tms_moist_vol_mean_scaled) %>% # drop rows with NAs in soil moisture: all (moist) values removed from LDI_020 & 063, 
                                                                                    # plus 14 - 16-07-2019 for LDI_070 and 19 - 23-07-2019 for LDI_081
  
  mutate(plot_id_num = as.numeric(str_extract(plot_id, "\\d{2}$"))) # n(unique) = 88, as all (moist) values removed from LDI_020 & 063


# >> run models ----

# define responses
response_variables_dT3T1 <- c("tms_dT3T1_mean", "tms_dT3T1_min", "tms_dT3T1_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# run models
model_list_mcmc_dT3T1_200 <- mapply(model_function_mcmc,
                                    response_variables_dT3T1, 
                                    predictor_variables_200_season19,
                                    MoreArgs = list(data = disko_data_scaled_200_season19),
                                    SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT3T1_200,
#      file = file.path("model_outputs", "model_output_dT3T1_200.Rdata"))
# load(file.path("model_outputs", "model_output_dT3T1_200.Rdata"))

# check model convergence
plot(model_list_mcmc_dT3T1_200[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_200[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_200[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT3T1_200, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.086


# >> [b] 564 cm circles: soil - canopy (dT3T1) ----

# >> select predictors ---- 
# explore correlation and multicollinearity patterns
predictor_variables_564_season19_all <- c(
  # free-air temperatures
  "station_base_daily_mean_temp", "station_base_daily_min_temp", "station_base_daily_max_temp",
  # abiotic plot variables
  "elevation", "slope", "sri_season19", "topo_prim_num", "tms_moist_vol_mean_scaled", "cov_rocks_564", "cov_bare_564", 
  # biotic plot variables
  "cov_shrubs_564", "cov_bryophytes_564", "cov_lichen_564", "cov_litter_564", "veg_height_avg_564", 
  # potentially confounding veg-at-TMS variables
  "veg_height_avg_tms", "cover_tms_top", "cover_tms_low", "cover_tms_ground")

# create basic correlation matrix
cor_mat_564 <- disko_data_complete_season19 %>% 
  dplyr::select(all_of(predictor_variables_564_season19_all)) %>% 
  corrr::correlate(diagonal = 1) %>% 
  # drop all values < .4 to increase readability
  mutate_if(is.numeric, ~ ifelse(abs(.) < .4, NA, .)) %T>% View()
# => high correlation with many other variables in shrub cover, but central for hypothesis -> keep!
# => bare ground (-0.663) & litter (.578) highly correlated w/ shrub cover  -> drop
# => veg-at-TMS variables all highly correlated with avg veg height or shrub cover -> drop

# define predictors for mean, min max temperatures
predictor_variables_564_season19_vif <- list(
  setdiff(predictor_variables_564_season19_all, c("station_base_daily_min_temp", "station_base_daily_max_temp")), # incl free-air MEAN temperatures
  setdiff(predictor_variables_564_season19_all, c("station_base_daily_mean_temp", "station_base_daily_max_temp")), # incl free-air MIN temperatures
  setdiff(predictor_variables_564_season19_all, c("station_base_daily_mean_temp", "station_base_daily_min_temp")) # incl free-air MAX temperatures
)

# define correlated variables to be removed
vars_to_remove_564 <- disko_data_complete_season19 %>% dplyr::select(contains("_tms"), cov_bare_564, cov_litter_564) %>% names()

# check VIF
predictor_variables_564_season19_vif %>% 
  purrr::map(~ disko_data_complete_season19 %>% 
               dplyr::select(all_of(.x), -all_of(vars_to_remove_564)) %>% 
               as.data.frame() %>% 
               usdm::vif())

# all VIF < 3.3 -> OK! >> extract predictors:
predictor_variables_564_season19 <- list(
  setdiff(predictor_variables_564_season19_all, c("station_base_daily_min_temp", "station_base_daily_max_temp", # incl free-air MEAN temperatures
                                                  vars_to_remove_564)), 
  setdiff(predictor_variables_564_season19_all, c("station_base_daily_mean_temp", "station_base_daily_max_temp", # incl free-air MIN temperatures
                                                  vars_to_remove_564)),
  setdiff(predictor_variables_564_season19_all, c("station_base_daily_mean_temp", "station_base_daily_min_temp", # incl free-air MAX temperatures
                                                  vars_to_remove_564))
)

# >> scale predictor variables and remove NAs ----
disko_data_scaled_564_season19 <- disko_data_complete_season19 %>% 
  
  mutate_at(all_of(predictor_variables_564_season19_all), ~ scale(.x, scale = TRUE, center = TRUE)) %>% 
  
  drop_na(tms_moist_vol_mean_scaled) %>% # drop rows with NAs in soil moisture: all (moist) values removed from LDI_020 & 063, 
                                                                                    # plus 14 - 16-07-2019 for LDI_070 and 19 - 23-07-2019 for LDI_081
  drop_na(veg_height_avg_564) %>%              # drop rows with NAs in avg veg height: all values removed for LDI_038 & 076
  
  mutate(plot_id_num = as.numeric(str_extract(plot_id, "\\d{2}$"))) # n(unique) = 86, as all (moist) values removed from LDI_020 & 063
                                                                                       # plus no veg height data for LDI_038 & 076


# >> run models ----

# define responses
response_variables_dT3T1 <- c("tms_dT3T1_mean", "tms_dT3T1_min", "tms_dT3T1_max")

# run models
model_list_mcmc_dT3T1_564 <- mapply(model_function_mcmc,
                                    response_variables_dT3T1, 
                                    predictor_variables_564_season19,
                                    MoreArgs = list(data = disko_data_scaled_564_season19),
                                    SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT3T1_564,
#      file = file.path("model_outputs", "model_output_dT3T1_564.Rdata"))
# load(file.path("model_outputs", "model_output_dT3T1_564.Rdata"))

# check model convergence
plot(model_list_mcmc_dT3T1_564[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_564[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_564[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT3T1_564, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.175 !!!


# >> extract mean effect sizes for all predictors, strata and temp vars ----

# load model outputs
lapply(paste0("model_outputs/", list.files("model_outputs", pattern = "*dT3T1_\\d{2,3}.Rdata")),
       load,
       .GlobalEnv)

# extract solutions for offset models across circle sizes
(solutions_summary_means_tot <- bind_rows(
  lapply(model_list_mcmc_dT3T1_50, extract_model_solutions, radius = 50) %>% 
    bind_rows(),
  lapply(model_list_mcmc_dT3T1_200, extract_model_solutions, radius = 200) %>%
    bind_rows(),
  lapply(model_list_mcmc_dT3T1_564, extract_model_solutions, radius = 564) %>%
    bind_rows()
) %>% 
    
    # change factor level order for parameters
    mutate(parameter = fct_relevel(parameter,
                                   c("post.mean",
                                     "l95",
                                     "u95"))) %>% 
    # filter for means only
    filter(parameter == "post.mean") %>%  # filter for temp vars with temp_var == "mean|min|max"
    
    # calculate means of solution parameters
    group_by(variable, radius, parameter) %>% 
    
    summarise(mean_value = mean(abs(value))) %>% ungroup() %>% 
    
    # arrange by descending mean value for each group
    group_by(parameter) %>% 
    arrange(desc(mean_value), .by_group = TRUE) %>% ungroup())

# output: for r = 200 and r = 564 only dT3T1 models included!


# >> extract x intercepts for mean T offset predictions ----

x_icpt_df_50 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_50[[1]],
                                      predictor1 = "shrubs",
                                      predictor2 = "bryophytes",
                                      radius = 50)
x_icpt_df_200 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_200[[1]],
                                      predictor1 = "shrubs",
                                      predictor2 = "bryophytes",
                                      radius = 200)
x_icpt_df_564 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_564[[1]],
                                      predictor1 = "shrubs",
                                      predictor2 = "bryophytes",
                                      radius = 564)

# combine dfs
(x_icpts <- bind_rows(x_icpt_df_50,
                      x_icpt_df_200,
                      x_icpt_df_564))



# >> [c] Correlation test for bryophyte vs shrub cover across circle sizes ----
(bryo_shrub_height_cor <- disko_plotdata_complete %>% 
   # select relevant columns
   tidylog::select(contains("bryophytes"), 
          contains("shrubs"), 
          matches("veg_height_avg_\\d+"),
          -contains("_10")) %>% 
   drop_na() %>% 
   # run correlation
   cor() %>% 
   # extract essential part of the correlation matrix
   as_tibble() %>% 
   mutate(var = colnames(.)) %>% 
   #filter(str_detect(var, "bryophytes")) %>% 
   tidylog::select(var, contains("cov"), contains("veg")))


# 4) Compare HOBO and TMS T1 sensors ----

# growing season 2019
disko_soiltemp_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv")) %>% 
  
  select(plot_id, date,
         starts_with("tms_T1_m"),
         starts_with("hobo_temp"))

soiltemp_comparison_lm_summary <- c("mean", "min", "max") %>% 
  
  purrr::map(~ disko_soiltemp_season19 %>% select(plot_id, date, ends_with(.x))) %>% 
  
  purrr::map(rename_at, 3, ~"tms") %>% 
  purrr::map(rename_at, 4, ~"hobo") %>% 
  
  purrr::map(~ lme4::lmer(hobo ~ tms + (1|plot_id), data = .x)) %>% 
  purrr::map(summary)
    

# 5) Check study area on CAVM ----
  # (source: Reynolds et al 2019, https://doi.org/10.17632/c4xj5rv6kv.2 )

pacman::p_load(terra,
               sf)

cavm_disko <- rast("C:/Users/au630524/Downloads/Raster CAVM GIS data/raster_cavm_v1.tif") %>% 
  # crop to rough extent
  crop(ext(1.7e6, 2e6, 1.2e6, 1.5e6))

plot(cavm_disko)

# define area of interest in raster CRS
aoi <- c(xmin = -53.56, xmax = -53.41, ymin = 69.26, ymax = 69.297) %>% 
  st_bbox(crs = "epsg:4326") %>% 
  st_as_sfc() %>% 
  st_transform(crs = crs(cavm_disko)) %>% 
  vect() %>% ext()

# crop to study area
cavm_aoi <- cavm_disko %>% 
  crop(aoi)

plot(cavm_aoi)

# extract values (frequency)
table(values(cavm_aoi))

# 3 31 32 33 92 93 
# 4 13 16 10 11  2 


# 6) Explore extrapolation of soil - canopy dT from remote sensing data ----
# >> prepare data ----

# load packages
pacman::p_load(terra,
               rgdal,
               sf)

# Sentinel-2 scene path
sentinel_files_2019 <- "I:/C_Write/_Proj/Greenland_NormandVegDyn_au150176/Disko/2019/sampling_design/Sentinel/S2A_MSIL1C_20190729T152911_N0208_R111_T21WXS_20190729T203427.SAFE/GRANULE/L1C_T21WXS_A021415_20190729T153229/IMG_DATA"

# define bbox
bbox_aoi <- rgdal::readOGR(dsn = "../disko2019/data/gee_sampling_design/Disko2019_SamplingArea.kml", 
                           require_geomType = "wkbPolygon") %>% 
  st_as_sf() %>% 
  st_transform("epsg:32621") %>% 
  ext()

# ¨¨¨¨ reflectance data ----
# ¨¨¨¨ [a] NDVI ----
ndvi_aoi_2019 <- list.files(sentinel_files_2019, pattern = ".*_B04|.*_B08") %>% 
  paste0(sentinel_files_2019, "/", .) %>% 
  terra::rast() %>% 
  setNames(c("RED", "NIR")) %>% 
  crop(bbox_aoi) %>% 
  
  # calculate NDVI
  ndvi()

# plot raster
plot(ndvi_aoi_2019)

# ¨¨¨¨ [b] kNDVI ----
  # calculate simplified kNDVI (Camps-Valls et al. 2021 Sci Adv, https://doi.org/10.1126/sciadv.abc7447 )
  # kNDVI = tanh(NDVI^2)

  # # function: 
  # kndvi <- function(img){
  #   ndvi_layer <- img[["NDVI"]]
  #   kndvi_layer <- tanh((ndvi_layer)^2)
  #   names(kndvi_layer) <- "kNDVI"
  #   return(kndvi_layer)
  # }

kndvi_aoi_2019 <- ndvi_aoi_2019 %>% 
  kndvi()

      # # alternative calculation, adapting code from Camps-Valls et al., appendix S10.2:
      # kndvi.alt <- function(img){
      #   red_band <- img[["RED"]]
      #   nir_band <- img[["NIR"]]
      #   
      #   sigma <- 1   # suggested in text though is sigma <- 0.5*(nir_band + red_band)
      #   knr <- exp(-(nir_band-red_band)^2/(2*sigma^2))
      #   kndvi <- (1-knr) / (1+knr)
      #   
      #   # kndvi_layer <- (nir_band - red_band) / (nir_band + red_band)
      #   names(kndvi) <- "kNDVI_alt"
      #   return(kndvi)
      # }
      # 
      # kndvi_aoi_2019_alt <- list.files(sentinel_files_2019, pattern = ".*_B04|.*_B08") %>% 
      #   paste0(sentinel_files_2019, "/", .) %>% 
      #   terra::rast() %>% 
      #   setNames(c("RED", "NIR")) %>% 
      #   crop(bbox_aoi) %>% 
      #   
      #   # calculate NDVI
      #   kndvi.alt()
      # 
      # # compare
      # c(kndvi_aoi_2019, kndvi_aoi_2019_alt) %>% plot()

# stack kNDVI and NDVI
ndvi_kndvi_aoi_2019 <- c(kndvi_aoi_2019, ndvi_aoi_2019)

# plot raster
plot(ndvi_kndvi_aoi_2019)

# ¨¨¨¨ [c] NDWI ----
# calculate NDWI for masking water bodies
sentinel_b11_aoi_2019 <- list.files(sentinel_files_2019, pattern = ".*_B11") %>% 
  paste0(sentinel_files_2019, "/", .) %>% 
  terra::rast()

ndwi_mask_aoi_2019 <- list.files(sentinel_files_2019, pattern = ".*_B08") %>% 
  paste0(sentinel_files_2019, "/", .) %>% 
  terra::rast() %>% 
  resample(sentinel_b11_aoi_2019) %>% 
  c(sentinel_b11_aoi_2019) %>% 
  setNames(c("NIR", "SWIR")) %>% 
  crop(bbox_aoi) %>% 
  
  # resample to match double resolution of NDVI layers
  resample(ndvi_kndvi_aoi_2019,
           method = "bilinear") %>% 
  
  # calculate NDWI
  ndwi()

# filter for water bodies
ndwi_mask_aoi_2019[ndwi_mask_aoi_2019 > 0.3] <- NA

# ¨¨¨¨ [d] NDSI ----
# calculate NDSI for masking water bodies
ndsi_mask_aoi_2019 <- list.files(sentinel_files_2019, pattern = ".*_B03") %>% 
  paste0(sentinel_files_2019, "/", .) %>% 
  terra::rast() %>% 
  resample(sentinel_b11_aoi_2019) %>% 
  c(sentinel_b11_aoi_2019) %>% 
  setNames(c("VIR", "SWIR")) %>% 
  crop(bbox_aoi) %>% 
  
  # resample to match double resolution of NDVI layers
  resample(ndvi_kndvi_aoi_2019,
           method = "bilinear") %>% 
  
  # calculate NDSI
  ndsi()

# filter for snow cover
ndsi_mask_aoi_2019[ndsi_mask_aoi_2019 > 0] <- NA

# ¨¨¨¨ mask layers ----
# stack all layers
kndvi_ndvi_aoi_2019_masked <- ndvi_kndvi_aoi_2019 %>% 
  
  # mask layers for water bodies, i.e. high NDWI (> 0.3)
  mask(ndwi_mask_aoi_2019) %>% 
  
  # mask layers for snow, i.e. high NDSI (> 0)
  mask(ndsi_mask_aoi_2019)

# # plot kNDVI - NDVI relationship
# qplot(x = values(kndvi_ndvi_aoi_2019_masked[[1]]), y = values(kndvi_ndvi_aoi_2019_masked[[2]]), xlab = "kNDVI", ylab = "NDVI")

# # save rasters
# writeRaster(kndvi_ndvi_aoi_2019_masked,
#             "data/TEMP_DATA/Disko_190729_Sentinel2_NDVI_kNDVI.tif"
#             # , overwrite = TRUE
# )
# kndvi_ndvi_aoi_2019_masked <- rast("data/TEMP_DATA/Disko_190729_Sentinel2_NDVI_kNDVI.tif")

# >> sample plot polygons ----
# ¨¨¨¨ [a] create polygons for large plots ----
ldi_564_plots <- read_csv(file.path("data", "location_data", "LDI_locations.csv")) %>% 
  
  select(plot_id = PlotID,
         long = Longitude, lat = Latitude) %>% 
  
  st_as_sf(coords = c("long", "lat"),
           crs = 4326) %>% 
  
  filter(plot_id %in% c(paste0("LDI_00", 1:9),
                        paste0("LDI_0", 10:90))) %>% 
  
  # transform CRS to polar stereographic
  st_transform("epsg:32621") %>% 
  
  # create circles of ~ 5.64m radius (100m2 area)
  st_buffer(dist = sqrt(100/pi)) %>% vect()

# ¨¨¨¨ [b] extract (k)NDVI values for polygons ----
ldi_564_greenness <- kndvi_ndvi_aoi_2019_masked %>% 
  
  terra::extract(ldi_564_plots,
                 fun = "mean",  # or compute from weights?
                 weights = TRUE,
                 exact = TRUE) %>% 
  
  as_tibble() %>% 
  
  mutate(ID = paste0("LDI_",
                     str_pad(ID, width = 3, side = "left", pad = "0"))) %>% 
  
  rename(plot_id = ID,
         kndvi_564 = kNDVI,
         ndvi_564 = NDVI)

# ¨¨¨¨ [c] join with complete data ----
disko_data_season19_greenness <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv")) %>% 
  
  left_join(ldi_564_greenness,
            by = "plot_id") %>% 
  
  select(plot_id, date,
         starts_with("tms_dT3T1"),
         contains("ndvi")) %>%    # drop rows with NAs in snow cover: complete record for LDI_078
  
  mutate(plot_id_num = as.numeric(str_extract(plot_id, "\\d{2}$"))) # numeric plot ID for random effect

write_csv(disko_data_season19_greenness,
          file = file.path("data", "plot_data", "processed", "microclim_plot_data_greenness_season19.csv"))

# # quick plot of relationships
# disko_data_season19_greenness %>% pivot_longer(cols = contains("ndvi"),
#                                                names_to = "greenness_var",
#                                                values_to = "greenness_value") %>% 
#   pivot_longer(cols = contains("dT3T1"),
#                names_to = "temp_var",
#                names_prefix = "tms_dT3T1_",
#                values_to = "dT3T1") %>% 
#   mutate(temp_var = factor(temp_var,
#                            levels = c("mean", "min", "max"))) %>% 
#   ggplot(aes(x = greenness_value,
#              y = dT3T1)) +
#   geom_point(pch = 21,
#              colour = "grey45",
#              fill = "grey85",
#              size = 2.5) +
#   geom_smooth(method = "lm",
#               colour = "darkred",
#               size = 1.5) +
#   facet_grid(rows = vars(greenness_var),
#              cols = vars(temp_var)) +
#   theme_cowplot()


# >> run & evaluate models ----

response_variables_dT3T1 <- c("tms_dT3T1_mean", "tms_dT3T1_min", "tms_dT3T1_max")

# define prior
a <- 1e5
prior <- list(R = list(V = diag(1), 
                       nu = 1), 
              G = list(G1 = list(V = diag(1), 
                                 nu = 1, 
                                 alpha.mu = c(0), 
                                 alpha.V = diag(1)*a)))

# define random variable
random <- "plot_id_num"

# ¨¨¨¨ [a] dT3T1 vs kNDVI ----
model_list_mcmc_dT3T1_564_kndvi <- mapply(model_function_mcmc,
                                          response_variable = response_variables_dT3T1, 
                                          predictors = "kndvi_564",
                                          MoreArgs = list(data = disko_data_season19_greenness),
                                          SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT3T1_564_kndvi,
#      file = file.path("model_outputs", "model_output_dT3T1_kndvi.Rdata"))
# load(file.path("model_outputs", "model_output_dT3T1_kndvi.Rdata"))

# check model convergence
plot(model_list_mcmc_dT3T1_564_kndvi[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_564_kndvi[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_564_kndvi[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT3T1_564_kndvi, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.045


# ¨¨¨¨ [b] dT3T1 vs NDVI ----
model_list_mcmc_dT3T1_564_ndvi <- mapply(model_function_mcmc,
                                         response_variable = response_variables_dT3T1, 
                                         predictors = "ndvi_564",
                                         MoreArgs = list(data = disko_data_season19_greenness),
                                         SIMPLIFY = FALSE)

# # save/load model output
# save(model_list_mcmc_dT3T1_564_ndvi,
#      file = file.path("model_outputs", "model_output_dT3T1_ndvi.Rdata"))
# load(file.path("model_outputs", "model_output_dT3T1_ndvi.Rdata"))

# check model convergence
plot(model_list_mcmc_dT3T1_564_ndvi[[1]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_564_ndvi[[2]]$model$Sol)     # all chains converged
plot(model_list_mcmc_dT3T1_564_ndvi[[3]]$model$Sol)     # all chains converged

# check autocorrelation for lag 10
lapply(model_list_mcmc_dT3T1_564_ndvi, extract_max_autocorr) %>% bind_rows() # all absolute autocorrelation values for Lag 10 < 0.023


# 7) Check correlation between mean/min/max moisture ----
ldi_moist_calib %>% 
  
  select(plot_id, time_WGST, SWC) %>% 
  
  left_join(disko_plotdata_complete %>% 
              select(plot_id, slope, elev_band),
            by = "plot_id") %>% 
  
  mutate(date = format(time_WGST, "%Y-%m-%d")) %>% 
  
  # clean time series for known disturbances
  mutate(SWC =  
           # >> 081 & 070 had been exposed completely
           # Remove moisture values from LDI_081 for 20/21/22-07-2019 +- 1 day, just in case
           case_when(plot_id == "LDI_081" & 
                       date >= "2019-07-19" & date <="2019-07-23" ~ NA_real_,
                     # Remove moisture values from LDI_070 for 15-07-2019 +- 1 day, just in case
                     plot_id == "LDI_070" & 
                       date >= "2019-07-14" & date <="2019-07-16" ~ NA_real_,
                     # >> TMS -513 (LDI_063) & -515 (LDI_020) have low, fuzzy values (bad contact with substrate?) ->> remove
                     plot_id %in% paste0("LDI_0", c(20, 63)) ~ NA_real_,
                     TRUE ~ SWC)) %>% 
  
  ### normalise SWC values between 0 and 1 ###
  mutate(SWC_scaled = normalise(SWC)) %>% 
  
  group_by(plot_id) %>% 
  summarise(moist_mean = mean(SWC_scaled, na.rm = T),
            moist_median = median(SWC_scaled, na.rm = T),
            moist_l90 = quantile(SWC_scaled, 0.05, na.rm = T),
            moist_l80 = quantile(SWC_scaled, 0.1, na.rm = T),
            moist_u80 = quantile(SWC_scaled, 0.9, na.rm = T),
            moist_u90 = quantile(SWC_scaled, 0.95, na.rm = T)) %>% 
  
  select(starts_with("moist")) %>% 
  tidylog::drop_na() %>% 
  cor()


# 8) Check correlation between NDVI and NDWI in plots ----

  pacman::p_load(terra,
                 rgdal,
                 sf,
                 tidyverse)

# calculate NDVI
ndvi <- function(img){
  red_band <- img[["RED"]]
  nir_band <- img[["NIR"]]
  ndvi_layer <- (nir_band - red_band) / (nir_band + red_band)
  names(ndvi_layer) <- "NDVI"
  return(ndvi_layer)
}
# calculate NDWI
ndwi <- function(img){
  nir_band <- img[["NIR"]]
  swir_band <- img[["SWIR"]]
  ndwi_layer <- (nir_band - swir_band) / (nir_band + swir_band)
  names(ndwi_layer) <- "NDWI"
  return(ndwi_layer)
}

### >> prepare data ----

# Sentinel-2 scene path
  # sentinel_files_2018 <- "I:/C_Write/_Proj/Greenland_NormandVegDyn_au150176/Disko/2019/sampling_design/Sentinel/S2A_MSIL1C_20180730T154911_N0206_R054_T21WXS_20180730T194330.SAFE/GRANULE/L1C_T21WXS_A016210_20180730T154905/IMG_DATA"
  sentinel_files_2019 <- "I:/C_Write/_Proj/Greenland_NormandVegDyn_au150176/Disko/2019/sampling_design/Sentinel/S2A_MSIL1C_20190729T152911_N0208_R111_T21WXS_20190729T203427.SAFE/GRANULE/L1C_T21WXS_A021415_20190729T153229/IMG_DATA"

# define bbox
bbox_aoi <- rgdal::readOGR(dsn = "../disko2019/data/gee_sampling_design/Disko2019_SamplingArea.kml", 
                           require_geomType = "wkbPolygon") %>% 
  st_as_sf() %>% 
  st_transform("epsg:32621") %>% 
  ext()

bbox_aoi_latlon <- rgdal::readOGR(dsn = "../disko2019/data/gee_sampling_design/Disko2019_SamplingArea.kml", 
                                  require_geomType = "wkbPolygon") %>% 
  st_as_sf() %>% 
  ext()

# ¨¨¨¨ reflectance data ----
# ¨¨¨¨ [a] NDVI ----
ndvi_aoi_2019 <- list.files(sentinel_files_2019, pattern = ".*_B04|.*_B08") %>% 
  paste0(sentinel_files_2019, "/", .) %>% 
  terra::rast() %>% 
  setNames(c("RED", "NIR")) %>% 
  crop(bbox_aoi) %>% 
  
  # calculate NDVI
  ndvi()

# ¨¨¨¨ [b] NDWI ----
# calculate NDWI for masking water bodies
sentinel_b11_aoi_2019 <- list.files(sentinel_files_2019, pattern = ".*_B11") %>% 
  paste0(sentinel_files_2019, "/", .) %>% 
  terra::rast()
ndwi_aoi_2019 <- list.files(sentinel_files_2019, pattern = ".*_B08") %>% 
  paste0(sentinel_files_2019, "/", .) %>% 
  terra::rast() %>% 
  resample(sentinel_b11_aoi_2019) %>% 
  c(sentinel_b11_aoi_2019) %>% 
  setNames(c("NIR", "SWIR")) %>% 
  crop(bbox_aoi) %>% 
  
  # resample to match double resolution of NDVI layers
  resample(ndvi_aoi_2019,
           method = "bilinear") %>% 
  
  # calculate NDWI
  ndwi()

plot(ndwi_aoi_2019)

c(ndvi_aoi_2019, ndwi_aoi_2019)

# >> create polygons for large plots ----
ldi_564_plots <- read_csv(file.path("data", "location_data", "LDI_locations.csv")) %>% 
  
  select(plot_id = PlotID,
         long = Longitude, lat = Latitude) %>% 
  
  st_as_sf(coords = c("long", "lat"),
           crs = 4326) %>% 
  
  filter(plot_id %in% c(paste0("LDI_00", 1:9),
                        paste0("LDI_0", 10:90))) %>% 
  
  # transform CRS to polar stereographic
  st_transform("epsg:32621") %>% 
  
  # create circles of ~ 5.64m radius (100m2 area)
  st_buffer(dist = sqrt(100/pi)) %>% vect()


### >> extract and correlate indices ----
ndvi_ndwi_564 <- c(ndvi_aoi_2019, ndwi_mask_aoi_2019) %>% 
  terra::extract(ldi_564_plots, fun = "mean", weights = T, exact = T)

ndvi_ndwi_564 %>% .[,c("NDVI", "NDWI")] %>% cor()

# NDVI      NDWI
# NDVI 1.0000000 0.6410991
# NDWI 0.6410991 1.0000000

### ______________________________ ----

### End of file ----