### Shrubs, bryophytes and snow influence microclimate across topographic and moisture gradients in the Arctic tundra
### von Oppen J, et al. 2022

### Data cleaning and preparation

### data from field campaign on Disko Island, Greenland, 2019, led by Signe Normand, Vegetation Dynamics Group, Aarhus University
### Code by Jonathan von Oppen, Aarhus University, jonathan.vonoppen@bio.au.dk, 20 May 2020 - 16 Dec 2021



### 0) Dependencies ----

# >> [a] packages ----

if(!require(pacman)){       # provides p_load() as wrapper for require() and library()
  install.packages("pacman")
  library(pacman)
}
pacman::p_load(readr,       # import of delimited files into tibble
               tidyverse,   # for multiple data wrangling packages
               tidylog,     # to log operations in pipes
               lubridate,   # to wrangle dates and times
               GeoLight, insol,  # to be used in Solar Radiation Index calculation
               broom,       # to convert statistical output to tibbles
               stringr,     # for string wrangling
               cowplot,     # for flexible plotting & combining graphs
               skimr)       # to conveniently skim & summarise data frames


# >> [b] functions ----
source(file.path("scripts", "functions.R"))

# pre-empty conflicted functions
if("tidylog" %in% (.packages())) select <- tidylog::select else select <- dplyr::select  # prefer tidylog function over dplyr over raster etc.


# 1) TMS temperature and moisture data ----

# ¨¨¨¨ load & clean moisture data ----
disko_tms <- read_csv("../disko2019/data/microclim/tms_data/disko_tms_2019.csv") %>% 
  
  # join with lookup table
  left_join(read_csv("data/plot_data/LDI_lookup_table.csv") %>% 
              rename_all(tolower) %>% 
              select(logger_id, tms_serial),
            by = "tms_serial") %>% 
  
  # join with start/end date from metadata
  left_join(read_csv("data/plot_data/processed/microclim_plot_data_complete.csv") %>% 
              select(plot_id, 
                     date_setup,
                     date_tms_retrieval) %>% 
              mutate_at(vars(starts_with("date_")), ~ as.POSIXct(., tz = "America/Nuuk")),
            by = c("logger_id" = "plot_id")) %>% 
  
  # rename logger_id to plot_id
  rename(plot_id = logger_id) %>% 
  
  # Convert time strings into a time object and filter for fieldwork period
  mutate(time_UTC = as.POSIXct(time_UTC, tz = "UTC"), 
         time_WGST = as.POSIXct(time_WGST, tz = "America/Nuuk")) %>% 
  filter(time_WGST >= (date_setup + lubridate::days(1)) 
         & time_WGST < date_tms_retrieval) %>% 
  
  
  # Remove T3 data for faulty loggers
  mutate(T3 = ifelse(tms_serial %in% c(94194584,
                                       94194512, 
                                       94194563, 
                                       94194555),
                     NA, T3)) %>% 
  
  # # split date into year/month/day/time
  # mutate(year = lubridate::year(time_UTC),
  #        month = lubridate::month(time_UTC),
  #        day = lubridate::day(time_UTC),
  #        time = format(time_UTC, "%H:%M"),    # add :%S for seconds
  #        time_zone = "UTC") %>% 
  
  # select relevant columns
  select(plot_id,
         tms_serial,
         read_index,
         time_WGST, 
         matches("T\\d"),
         raw_moist) 

# create microclimate_data directory if not existing already
if(!dir.exists(file.path("data", "microclimate_data"))) dir.create(file.path("data" ,"microclimate_data"))
if(!dir.exists(file.path("data", "microclimate_data", "processed"))) dir.create(file.path("data" ,"microclimate_data", "processed"))
# write.csv(disko_tms,
#           file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019_tms_data_cleaned.csv"),
#           row.names = FALSE)


# ¨¨¨¨ calibrate TMS moisture data----

# get soil classification for samples
ldi_soil_classes <- read_csv(file.path("data", "plot_data", "LDI_soil_particle_fractions.csv")) %>% 
  add_tomst_soil_class(soil_data = ., id_col = "plot_id")

# calibrate soil moisture
ldi_moist_calib <- disko_tms %>% 
  # run soil moisture calibration
  calib_tomst_soil_moist(tms_data = .,
                         soil_class_data = ldi_soil_classes,
                         raw_moist_col = "raw_moist",
                         calib = "specific")

# # QA: check for systematic errors in calibration
# ldi_moist_calib %>% 
#   # normalise raw and calibrated moisture
#   mutate(raw_moist_scaled = normalise(raw_moist),
#          calib_moist_scaled = normalise(SWC)) %>% 
#   pivot_longer(cols = c(raw_moist_scaled, calib_moist_scaled),
#                names_to = "variable",
#                values_to = "moist_value_scaled") %>%
#   mutate(variable = fct_relevel(variable, c("raw_moist_scaled",
#                                             "calib_moist_scaled"))) %>% 
#   ggplot(aes(x = TOMST_class)) +
#   geom_boxplot(aes(fill = variable,
#                    y = moist_value_scaled)) +
#   geom_text(data = ldi_moist_calib %>% 
#               group_by(TOMST_class) %>% 
#               summarise(n_plots = n_distinct(plot_id)), 
#             aes(label = n_plots, y = -0.05)) +
#   labs(x = "TOMST soil class")

# calculate daily means
tms_moisture_daily <- ldi_moist_calib %>% 
  
  mutate(time_WGST = as.POSIXct(time_WGST)) %>% 
  
  mutate(date = format(time_WGST, "%Y-%m-%d")) %>% 
  
  # clean time series for known disturbances
  mutate_at(vars(contains("moist"), starts_with("SWC")), 
            # >> 081 & 070 had been exposed completely
            # Remove moisture values from LDI_081 for 20/21/22-07-2019 +- 1 day, just in case
            ~ case_when(plot_id == "LDI_081" & 
                          date >= "2019-07-19" & date <="2019-07-23" ~ NA_real_,
                        # Remove moisture values from LDI_070 for 15-07-2019 +- 1 day, just in case
                        plot_id == "LDI_070" & 
                          date >= "2019-07-14" & date <="2019-07-16" ~ NA_real_,
                        # >> TMS -513 (LDI_063) & -515 (LDI_020) have low, fuzzy values (bad contact with substrate?) ->> remove
                        plot_id %in% paste0("LDI_0", c(20, 63)) ~ NA_real_,
                        TRUE ~ .)) %>% 
  
  # calculate daily averages
  group_by(plot_id, date, TOMST_class) %>% 
  summarise(tms_moist_vol_daily_mean = mean(SWC, na.rm = TRUE),
            tms_moist_vol_daily_min = min(SWC, na.rm = TRUE),
            tms_moist_vol_daily_max = max(SWC, na.rm = TRUE),
            tms_moist_vol_daily_amp = tms_moist_vol_daily_max - tms_moist_vol_daily_min) %>% ungroup() %>% 
  # change -Inf's to NA
  mutate_at(vars(contains("moist_vol_daily")), ~ case_when(is.infinite(.)|is.nan(.) ~ NA_real_,
                                                           TRUE ~ .))

# # quick QA
# # identify plots with negative values
# tms_moisture_daily %>% 
#   group_by(plot_id) %>% 
#   filter(!all(tms_moist_vol_daily_mean > 0)) %>% 
#   pull(plot_id) %>% unique()
# 
# # Quick plots for QA
# qa_plots_moist <- lapply(colnames(tms_moisture_daily)[3:6], function(x) {
#   ggplot(tms_moisture_daily, aes(x = date, y = get(x), 
#                               group = plot_id, colour = plot_id)) + 
#     geom_line() +
#     ylab(x) +
#     theme(legend.position = "none",
#           axis.text.x = element_text(angle = 90))})
# (qa_plots_moist_grid <- cowplot::plot_grid(plotlist = qa_plots_moist))
# 
#   # =>> suspicious plateau in daily max moist during 18-21/07/2019 (rainy period)
#   # detailed plot of rainy period values
#   ldi_moist_calib %>% 
#     filter(plot_id %in% (tms_moisture_daily %>% 
#                            filter(tms_moist_vol_daily_max>.7) %>% 
#                            pull(plot_id) %>% unique()),
#            time_WGST %within% interval(start = "2019-07-18",
#                                    end = "2019-07-21")) %>% 
#     ggplot(aes(x = time_WGST, y = SWC, 
#                colour = plot_id)) +
#     geom_line() +
#     theme(axis.text.x = element_text(angle = 90))

# ¨¨¨¨ scale moisture values ----
tms_moisture_daily_scaled <- ldi_moist_calib %>% 
  
  mutate(time_WGST = as.POSIXct(time_WGST)) %>% 
  
  mutate(date = format(time_WGST, "%Y-%m-%d")) %>% 
  
  # clean time series for known disturbances
  mutate_at(vars(contains("moist"), starts_with("SWC")), 
            # >> 081 & 070 had been exposed completely
            # Remove moisture values from LDI_081 for 20/21/22-07-2019 +- 1 day, just in case
            ~ case_when(plot_id == "LDI_081" & 
                          date >= "2019-07-19" & date <="2019-07-23" ~ NA_real_,
                        # Remove moisture values from LDI_070 for 15-07-2019 +- 1 day, just in case
                        plot_id == "LDI_070" & 
                          date >= "2019-07-14" & date <="2019-07-16" ~ NA_real_,
                        # >> TMS -513 (LDI_063) & -515 (LDI_020) have low, fuzzy values (bad contact with substrate?) ->> remove
                        plot_id %in% paste0("LDI_0", c(20, 63)) ~ NA_real_,
                        TRUE ~ .)) %>% 
  
  ### normalise SWC values between 0 and 1 ###
  mutate(SWC_scaled = normalise(SWC)) %>% 
  
  # calculate daily averages
  group_by(plot_id, date, TOMST_class) %>% 
  summarise(tms_moist_vol_daily_mean_scaled = mean(SWC_scaled, na.rm = TRUE),
            tms_moist_vol_daily_min_scaled = min(SWC_scaled, na.rm = TRUE),
            tms_moist_vol_daily_max_scaled = max(SWC_scaled, na.rm = TRUE),
            tms_moist_vol_daily_amp_scaled = tms_moist_vol_daily_max_scaled - tms_moist_vol_daily_min_scaled) %>% ungroup() %>% 
  # change -Inf's to NA
  mutate_at(vars(contains("moist_vol_daily")), ~ case_when(is.infinite(.)|is.nan(.) ~ NA_real_,
                                                           TRUE ~ .)) %>% 
  
  # join with non-scaled values
  right_join(tms_moisture_daily,
             by = c("plot_id", "date", "TOMST_class")) %>% 
  rename(soil_class_TOMST = TOMST_class)

# # save
# write_csv(tms_moisture_daily_scaled,
#           file.path("data", "microclimate_data", "processed", "disko_microclim_2019_tms_moisture_data_daily.csv"))


# ¨¨¨¨ daily stats ----
# Calculate daily stats
disko_tms_daily <- disko_tms %>%
  
  mutate(time_WGST = as.POSIXct(time_WGST)) %>% 
  
  mutate(date = format(time_WGST, "%Y-%m-%d")) %>% 
  
  group_by(plot_id, date) %>% summarise(T1_mean = mean(T1),
                                        T1_min = min(T1),
                                        T1_max = max(T1),
                                        T1_amp = T1_max - T1_min,
                                        T2_mean = mean(T2),
                                        T2_min = min(T2),
                                        T2_max = max(T2),
                                        T2_amp = T2_max - T2_min,
                                        T3_mean = mean(T3),
                                        T3_min = min(T3),
                                        T3_max = max(T3),
                                        T3_amp = T3_max - T3_min) %>% 
  ungroup() %>% 
  droplevels()

# Quick plots for quality assessment
qa_plots <- lapply(colnames(disko_tms_daily)[3:14], function(x) {
  ggplot(disko_tms_daily, aes(x = date, y = get(x), 
                              group = plot_id, colour = plot_id)) + 
    geom_line() +
    ylab(x) +
    theme(legend.position = "none",
          axis.text.x = element_text(angle = 90))})
(qa_plots_grid <- plot_grid(plotlist = qa_plots))

# save_plot(qa_plots_grid, filename = "scripts/jonathan/plots/TMS_daily_complete_QA_cleaned.png",
#          base_height = 12, base_aspect_ratio = 1.6)

# Two loggers got really hot for the soil measurement, 
# another one has a high amplitude on the last day.
disko_tms_daily[which(disko_tms_daily$T1_max > 30),]#$plot_id # LDI_081
disko_tms_daily[which(disko_tms_daily$T1_amp > 15),]#$plot_id # LDI_081, 070

# >> 081 & 070 had been exposed completely

disko_tms_daily <- disko_tms_daily %>% 
  # Remove T1, T2, T3 values from LDI_081 for 20/21/22-07-2019 +- 1 day, just in case
  mutate_at(vars(starts_with("T")), ~ case_when(plot_id == "LDI_081" & 
                                                  date >= "2019-07-19" & date <="2019-07-23" ~ NA_real_,
                                                # Remove T1, T2, T3 values from LDI_070 for 15-07-2019 +- 1 day, just in case
                                                plot_id == "LDI_070" & 
                                                  date >= "2019-07-14" & date <="2019-07-16" ~ NA_real_,
                                                plot_id == "LDI_003" &
                                                  date == "2019-08-07" ~ NA_real_,
                                                TRUE ~ .))
# Check result
View(disko_tms_daily %>% filter(plot_id %in% c("LDI_081", "LDI_070"),
                                date >= "2019-07-13", date <="2019-07-24"))


# calculate temperature differences between sensors
disko_tms_daily <- disko_tms_daily %>% 
  
  mutate(dT2T1_mean = T1_mean - T2_mean,
         dT2T1_max = T1_max - T2_max,
         dT2T1_min = T1_min - T2_max,
         
         dT3T1_mean = T1_mean - T3_mean,
         dT3T1_max = T1_max - T3_max,
         dT3T1_min = T1_min - T3_max,
         
         dT3T2_mean = T2_mean - T3_mean,
         dT3T2_max = T2_max - T3_max,
         dT3T2_min = T2_min - T3_max) %>% 
  
  # join moisture data
  left_join(tms_moisture_daily_scaled,
            by = c("plot_id", "date"))

#  ¨¨¨¨ => save output ----
write_csv(disko_tms_daily,
          file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019_tms_temp_data_daily_summary_cleaned.csv"))


# # ¨¨¨¨ compute season summary statistics ----
# disko_tms_seasonal <- disko_tms_daily %>% ungroup() %>% 
#   # rename daily temp variables to avoid ambiguity
#   rename_at(vars(starts_with("T")), ~ paste0(., "_daily")) %>% 
#               group_by(plot_id) %>%
#   # calculate mean temperature variables
#   summarise(T1_mean = mean(T1_mean_daily, na.rm = T),
#             T1_min = mean(T1_min_daily, na.rm = T),
#             T1_max = mean(T1_max_daily, na.rm = T),
#             T1_amp = mean(T1_amp_daily, na.rm = T),
#             T1_range = max(T1_max_daily, na.rm = T) - min(T1_min_daily, na.rm = T),
#             T2_mean = mean(T2_mean_daily, na.rm = T),
#             T2_min = mean(T2_min_daily, na.rm = T),
#             T2_max = mean(T2_max_daily, na.rm = T),
#             T2_amp = mean(T2_amp_daily, na.rm = T),
#             T2_range = max(T2_max_daily, na.rm = T) - min(T2_min_daily, na.rm = T),
#             T3_mean = mean(T3_mean_daily, na.rm = T), 
#             T3_min = mean(T3_min_daily, na.rm = T),
#             T3_max = mean(T3_max_daily, na.rm = T),
#             T3_amp = mean(T3_amp_daily, na.rm = T),
#             T3_range = max(T3_max_daily, na.rm = T) - min(T3_min_daily, na.rm = T),
#             
#             T1_gdd0 = sum(T1_mean_daily[T1_mean_daily > 0]),
#             T1_gdd5 = sum(T1_mean_daily[T1_mean_daily > 5]),
#             T2_gdd0 = sum(T2_mean_daily[T2_mean_daily > 0]),
#             T2_gdd5 = sum(T2_mean_daily[T2_mean_daily > 5]),
#             T3_gdd0 = sum(T3_mean_daily[T3_mean_daily > 0]),
#             T3_gdd5 = sum(T3_mean_daily[T3_mean_daily > 5])) %>% 
#   mutate_if(is.numeric, list(~na_if(abs(.), Inf))) %>%  # replace infinite values for faulty T3 loggers with NA
#   mutate_if(is.numeric, ~ifelse(is.nan(.), NA, .)) %>%  # replace NaN values for faulty T3 loggers with NA
#   # calculate temperature differences
#   mutate(dT2T1_mean = T1_mean - T2_mean,
#          dT2T1_max = T1_max - T2_max,
#          dT2T1_min = T1_min - T2_max,
#          dT2T1_amp = T1_amp - T2_amp,
#          dT2T1_range = T1_range - T2_range,
#          dT2T1_gdd0 = T1_gdd0 - T2_gdd0,
#          dT2T1_gdd5 = T1_gdd5 - T2_gdd5,
#          
#          dT3T1_mean = T1_mean - T3_mean,
#          dT3T1_max = T1_max - T3_max,
#          dT3T1_min = T1_min - T3_max,
#          dT3T1_amp = T1_amp - T3_amp,
#          dT3T1_range = T1_range - T3_range,
#          dT3T1_gdd0 = T1_gdd0 - T3_gdd0,
#          dT3T1_gdd5 = T1_gdd5 - T3_gdd5,
#          
#          dT3T2_mean = T2_mean - T3_mean,
#          dT3T2_max = T2_max - T3_max,
#          dT3T2_min = T2_min - T3_max,
#          dT3T2_amp = T2_amp - T3_amp,
#          dT3T2_range = T2_range - T3_range,
#          dT3T2_gdd0 = T2_gdd0 - T3_gdd0,
#          dT3T2_gdd5 = T2_gdd5 - T3_gdd5)
#   
#   # # ¨¨¨¨ => save output ----
#   # write.csv(disko_tms_seasonal,
#   #           file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019_tms_temp_data_season_summary_cleaned.csv"),
#   #           row.names = FALSE)


# >> HOBO data ----

####
# NOTE: This section was left in for transparency, but underlying data is too large to be shared.
# Workflow continues with cleaned daily temperature data below (L526 ff).
####

# # ¨¨¨¨ load & clean data ----
# detach("package:tidylog", unload=TRUE)
# # load HOBO temperature data
# source(file = file.path("scripts", "jonathan", "ExtractHOBOData.R"))
# # load HOBO disturbance log data
# logger_issues_hobo <- read.csv(file.path("data", "microclimate_data", "issues_logbook.csv")) %>% 
#   filter(type_issue == "HOBO") %>% 
#   rename_all(tolower)
# 
# library(tidylog, warn.conflicts = FALSE)
# 
# 
# # clean data
# disko_hobo <- HOBO_data %>% 
#   
#   # join with lookup table
#   left_join(read.csv("data/microclimate_data/LDI_lookup_table.csv") %>% 
#               rename_all(tolower) %>% 
#               select(logger_id, hobo_short),
#             by = c("hobo_id" = "hobo_short")) %>% 
#   
#   # join with start/end date from metadata
#   left_join(read.csv("data/plot_data/processed/microclim_plot_data_complete.csv") %>% 
#               select(plot_id, 
#                      date_setup,
#                      date_tms_retrieval,
#                      date_hobo_retrieval) %>% 
#               mutate_at(vars(starts_with("date_")), ~ as.POSIXct(.)),
#             by = c("logger_id" = "plot_id")) %>% 
#   
#   # rename logger_id to plot_id
#   rename(plot_id = logger_id) %>% 
#   
#   # filter for fieldwork period
#   filter(time_WGST > date_setup + lubridate::days(1) & time_WGST < date_hobo_retrieval) %>% 
#   
#   # check for number of NAs in temp records 
#   # disko_hobo %>% summarise_all(~ sum(is.na(.)))
#   # disko_hobo_nas <- disko_hobo %>% filter(is.na(temp)) %>%
#   # group_by(plot_id) %>% summarise(n_na = n()) %>% arrange(desc(n_na))
#   # -> 450 at LDI_037 (dug up, stopped logging in 12/19), others when activated during read-out times
# 
#   # extract daily date from time_WGST
#   mutate(date = date(time_WGST)) %>% 
#   
#   # remove values from periods where loggers were out of ground
#   # view cases: logger_issues_hobo %>% filter(str_detect(comment_issue, "dug up")) %>% View()
#   mutate(temp = case_when(
#     
#   # cases observed during 2019 season: remove data from observation date and two previous days
#     # >> 045 was found exposed completely on 19/07/2019
#       plot_id == "LDI_045" & date %in% paste0("2019-07-", 17:19) ~ NA_integer_,
#       
#     # >> 068 was found exposed completely on 15/07/2019
#       plot_id == "LDI_068" & date %in% paste0("2019-07-", 13:15) ~ NA_integer_,
#       
#     # >> 070 was found exposed completely on 15/07/2019
#       plot_id == "LDI_070" & date %in% paste0("2019-07-", 13:15) ~ NA_integer_,
#   
#     # >> 083 was found exposed completely on 12/07/2019
#       plot_id == "LDI_083" & date %in% paste0("2019-07-", 10:12) ~ NA_integer_,
#   
#   
#   # cases observed during 2020 season: remove data from after readout date (2019 TMS retrieval)
#     # >> 037 was found exposed completely on 20/08/2020
#       plot_id == "LDI_037" & date > date_tms_retrieval ~ NA_integer_,
#   
#     # >> 045 was found exposed completely on 19/08/2020
#       plot_id == "LDI_045" & date > date_tms_retrieval ~ NA_integer_,
#     
#     # >> 059 was found exposed completely on 20/08/2020
#       plot_id == "LDI_059" & date > date_tms_retrieval ~ NA_integer_,
#     
#     # >> 060 was found exposed completely on 22/08/2020
#       plot_id == "LDI_060" & date > date_tms_retrieval ~ NA_integer_,
#     
#     # >> 062 was found exposed completely on 27/08/2020
#       plot_id == "LDI_062" & date > date_tms_retrieval ~ NA_integer_,
#   
#     # >> 063 was found exposed completely on 27/08/2020
#       plot_id == "LDI_063" & date > date_tms_retrieval ~ NA_integer_,
#   
#     TRUE ~ temp)) %>% 
#     
#   # select relevant columns
#   select(plot_id,
#          hobo_id,
#          date,
#          time_WGST,
#          time_UTC, 
#          temp) %>%
#   
#   # sort by plot ID
#   arrange(plot_id) %>% 
#   
#   # drop NA temp values
#   drop_na(temp)
#   
# 
# # #  ¨¨¨¨ => save output ----
# # write.csv(disko_hobo,
# #           file = file.path("I:", "C_Write", "_User", "JonathanVonOppen_au630524", "Project", "B_Disko_MicroClim", "Data", "HoboData", "processed", "disko_microclim_2019-20_hobo_temp_data_cleaned.csv"),
# #           row.names = FALSE)
# 
# 
# # ¨¨¨¨ daily stats ----
# # # load data
disko_hobo <- read_csv(file = file.path("I:", "C_Write", "_User", "JonathanVonOppen_au630524", "Project", "B_Disko_MicroClim", "Data", "HoboData", "processed", "disko_microclim_2019-20_hobo_temp_data_cleaned.csv"))

# Calculate daily stats
disko_hobo_daily <- disko_hobo %>%
  
  group_by(plot_id, date) %>% summarise(temp_mean = mean(temp),
                                        temp_min = min(temp),
                                        temp_max = max(temp),
                                        temp_amp = temp_max - temp_min) %>%
  # clean up
  ungroup() %>% droplevels()

# Quick plots for quality assessment
qa_plots <- lapply(colnames(disko_hobo_daily)[3:6], function(x) {
  ggplot(disko_hobo_daily, aes(x = date, y = get(x),
                               group = plot_id, colour = plot_id)) +
    geom_line() +
    labs(y = paste0(x, " [°C]"),
         title = (x)) +
    scale_x_date(date_breaks = "1 month", date_labels = "%d %b %y") +
    theme(legend.position = "none",
          axis.title.x = element_blank(),
          axis.text.x = element_text(angle = 90))})
(qa_plots_grid <- plot_grid(plotlist = qa_plots))

# save_plot(qa_plots_grid,
#           filename = "scripts/jonathan/plots/HOBO_daily_complete_QA.png",
#           base_height = 12,
#           base_aspect_ratio = 1.6)

# load logger issues log
logger_issues <- read_csv(file.path("data", "plot_data", "issues_logbook.csv"))

# ¨¨¨¨ clean daily data ----

disko_hobo_daily <- disko_hobo_daily %>%
  
  # make temperature values numeric
  mutate_at(vars(starts_with("temp")), ~ as.numeric(.)) %>%
  
  # Mean temp: no clear outliers
  
  mutate_at(vars(starts_with("temp")), ~ case_when(
    
    # Min temp: no clear outliers
    
    # Max temp:
    # some loggers with suspiciously high temp max, also inflating temp amplitude
    # overview of cases:
    # disko_hobo_daily %>%
    #   filter(temp_max > 30) %>%
    #   group_by(plot_id) %>%
    #   summarise(n_suspicious = n()) %>%
    #   arrange(desc(n_suspicious)) %>% View()
    # LDI_078 with 45 days above 30°C and 73 days > 25°C
    # check with issues log:
    # logger_issues %>% filter(plot_ID == "LDI_078")
    # -> was buried quite shallow >> remove
    # otherwise mostly plots w/ +- S aspect -> seems realistic
    
    plot_id == "LDI_078" ~ NA_real_,
    
    # Temp amplitude: no clear outliers after removing temp max extremes
    
    # keep all other values
    TRUE ~ .))

# #  ¨¨¨¨ => save output ----
# write.csv(disko_hobo_daily,
#           file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019-20_hobo_temp_data_daily_summary_cleaned.csv"),
#           row.names = FALSE)


# plot cleaned daily data
qa_plots <- lapply(colnames(disko_hobo_daily)[3:6], function(x) {
  ggplot(disko_hobo_daily, aes(x = date, y = get(x),
                               group = plot_id, colour = plot_id)) +
    geom_line() +
    labs(y = paste0(x, " [°C]"),
         title = (x)) +
    scale_x_date(date_breaks = "1 month", date_labels = "%d %b %y") +
    theme(legend.position = "none",
          axis.title.x = element_blank(),
          axis.text.x = element_text(angle = 90))})
(qa_plots_grid <- plot_grid(plotlist = qa_plots))

# save_plot(qa_plots_grid,
#           filename = "scripts/jonathan/plots/HOBO_daily_complete_QA_cleaned.png",
#           base_height = 12,
#           base_aspect_ratio = 1.6)


# ¨¨¨¨ calculate number of snow-covered days ----
# threshold: daily amplitude < 2° during NDJFM (Zhang et al. 1997, https://doi.org/10.1002/(SICI)1099-1530(199701)8:1%3C45::AID-PPP240%3E3.0.CO;2-K )

# load data
disko_hobo_daily <- read_csv(file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019-20_hobo_temp_data_daily_summary_cleaned.csv"))

snow_cover_duration <- disko_hobo_daily %>% 
  
  # get number of days in Oct - April  with amp < 2 for each plot
  group_by(plot_id) %>% 
  filter(date %within% interval(ymd("2019-11-01"), ymd("2020-03-31"))) %>% 
  filter(temp_amp < 2) %>% 
  summarise(ndays_snowcover_ndjfm = n())


# ¨¨¨¨ compute summary stats for different time periods ----

# # load data
# disko_hobo_daily <- read_csv(file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019-20_hobo_temp_data_daily_summary_cleaned.csv"))


# extract HOBO data for same logging period as TMS
disko_hobo_season19 <- disko_hobo_daily %>% 
  
  # add tms logging period info
  left_join(read.csv("data/plot_data/processed/microclim_plot_data_complete.csv") %>% 
              select(plot_id, 
                     date_setup,
                     date_tms_retrieval) %>% 
              mutate_at(vars(starts_with("date_")), ~ as.POSIXct(.))) %>% 
  
  # filter for HOBO records within TMS logging period
  filter(date %within% interval(date_setup, date_tms_retrieval - days(1))) %>% 
  
  group_by(plot_id) %>%
  
  # calculate temperature variables
  summarise(
    # overall means
    mean_season19 = mean(temp_mean, na.rm = TRUE),
    min_season19 = mean(temp_min, na.rm = TRUE),
    max_season19 = mean(temp_max, na.rm = TRUE),
    amp_season19 = mean(temp_amp, na.rm = TRUE),
    
    # # overall range
    # range_season19 = max(temp_mean) - min(temp_mean),
    # min_range_season19 = max(temp_min) - min(temp_min),
    # max_range_season19 = max(temp_max) - min(temp_max),
    # amp_range_season19 = max(temp_amp) - min(temp_amp),
    
    # growing degree days
    gdd0_season19 = sum(temp_mean[temp_mean > 0]),
    gdd5_season19 = sum(temp_mean[temp_mean > 5]))


# # create seasonal summary statistics
# 
# disko_hobo_seasonal <- disko_hobo_daily %>% 
#   
#   # filter for winter period
#   filter(date %within% interval(ymd("2019-11-01"), ymd("2020-03-31"))) %>% 
#   
#   # create new column with season string
#   mutate(season = "ndjfm1920") %>% 
#   
#   group_by(plot_id, season) %>%
#   
#   # calculate temperature variables
#   summarise(
#     
#     # means
#     mean = mean(temp_mean, na.rm = TRUE),
#     min = mean(temp_min, na.rm = TRUE),
#     max = mean(temp_max, na.rm = TRUE),
#     amp = mean(temp_amp, na.rm = TRUE),
#     
#     # # ranges
#     # range = max(temp_mean) - min(temp_mean),
#     # min_range = max(temp_min) - min(temp_min),
#     # max_range = max(temp_max) - min(temp_max),
#     # amp_range = max(temp_amp) - min(temp_amp),
#     
#     # growing / freezing degree days
#     gdd0 = sum(temp_mean[temp_mean > 0]),
#     gdd5 = sum(temp_mean[temp_mean > 5]),
#     fdd = abs(sum(temp_mean[temp_mean < 0]))
#   ) %>% 
#   
#     ungroup() %>% 
#   
#   # recode NaN values in LDI_078 means columns to NA
#   mutate_at(vars(contains(".mean")), ~ case_when(!is.nan(.) ~ .)) %>% 
#   
#   # pivot wider: one column per variable and season, one row per plot
#   pivot_wider(names_from = season,
#               values_from = mean:fdd) %>% 
#   
#   # merge with 2019 season-only records
#   left_join(disko_hobo_season19) %>% 
# 
#   # reorder columns
#   relocate(ends_with("ndjfm1920"), .after = last_col()) %>% 
#   
#   # rename HOBO columns
#   rename_with(.cols = -plot_id, .fn = ~ paste0("hobo_", .x)) %>% 
#   
#   # add seasonal weather station data -- run source call below or see L845
#     # # determine closest station by elevation for comparison, and summary stats for corresponding time periods
#     # source(file.path("scripts", "corresp_stations_elevation.R"))
# 
#   left_join(disko_corresp_station_seasonal %>% 
#                        select(plot_id,
#                               matches("geobase_.*_ndjfm1920"))) %>% 
# 
#   # calculate differences between station (free-air) & HOBO (soil) temperatures
#   mutate(hobo_dT4hobo_mean_ndjfm1920 = hobo_mean_ndjfm1920 - geobase_mean_daily_mean_temp_ndjfm1920,
#          hobo_dT4hobo_max_ndjfm1920 = hobo_max_ndjfm1920 - geobase_mean_daily_max_temp_ndjfm1920,
#          hobo_dT4hobo_min_ndjfm1920 = hobo_min_ndjfm1920 - geobase_mean_daily_min_temp_ndjfm1920,
#          hobo_dT4hobo_gdd0_ndjfm1920 = hobo_gdd0_ndjfm1920 - geobase_gdd0_ndjfm1920,
#          hobo_dT4hobo_gdd5_ndjfm1920 = hobo_gdd5_ndjfm1920 - geobase_gdd5_ndjfm1920,
#          hobo_dT4hobo_fdd_ndjfm1920 = hobo_fdd_ndjfm1920 - geobase_fdd_ndjfm1920) %>% 
#   
#   # remove station temp columns -- will be added from TMS dataset
#   select(-starts_with("geobase"))
#   
# # 
# # ¨¨¨¨ => save output ----
# # write_csv(disko_hobo_seasonal,
# #           file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019-20_hobo_temp_data_cleaned_season_summary.csv"))


# >> GeoBasis weather station data ----

# define path for weather station data
station_data_path <- file.path("..", "disko2019", "data", "geobasis_weather_stations", "raw")
# # create directories if not already existing
# if(!dir.exists(file.path("data", "geobasis_weather_stations"))) 
#   dir.create(file.path("data", "geobasis_weather_stations"))
# if(!dir.exists(station_data_path)) 
#   dir.create(station_data_path)
# if(!dir.exists(file.path("data", "geobasis_weather_stations", "processed")))
#   dir.create(file.path("data", "geobasis_weather_stations", "processed"))

# download data from https://data.g-e-m.dk/log-in/data-tables/ (requires login)
# -> GeoBasis Disko
# -> Meteorology
# for stations AWS2, AWS3, AWS4, T1, T2, T3, T4
# into station_data_path directory

# ¨¨¨¨ load & clean data ----
station_data_files <- list.files(station_data_path,
                                 pattern = ".txt")

station_locations <- read_csv(file.path("data", "location_data", "station_locations.csv"))

# compile and clean data
geobase_data <- lapply(station_data_files, 
                       read_clean_geobase_data) %>% 
  # bind list elements
  bind_rows()

# # save cleaned data
# write_csv(geobase_data,
#           file = file.path(station_data_path, "..", "processed", "GeoBasisDisko_weather_station_data_20190625_20200831.csv"))


# ¨¨¨¨ daily stats for all GeoBase time series ----
# # load cleaned data
# geobase_data <- read_csv(file = file.path(station_data_path, "..", "processed", "GeoBasisDisko_weather_station_data_20190625_20200831.csv"))

disko_geobase_daily <- geobase_data %>% 
  
  # extract date from date_time string
  mutate(date = lubridate::date(date_time_UTCm3)) %>% 
  
  group_by(station_id,
           sensor,
           elevation,
           lat,
           long,
           date) %>% 
  
  summarise(daily_mean_temp = mean(temperature, na.rm = TRUE),
            daily_min_temp = min(temperature, na.rm = TRUE),
            daily_max_temp = max(temperature, na.rm = TRUE)) %>% ungroup()


# >> calculate differences between closest station and TMS sensors ----

# determine closest station by elevation for comparison, and summary stats for corresponding time periods
# load elevations
station_elevations <- read_csv(file.path("data", "location_data", "station_locations.csv")) %>% 
  # drop AWS2 station, no data available
  filter(!station_id == "AWS2") %>% 
  # select station ID and elevation
  select(station_id,
         elevation_geo = asl) %>% 
  # pivot wide
  pivot_wider(names_from = station_id,
              names_glue = "{station_id}_elev",
              values_from = elevation_geo)

plot_station_elevation_diffs <- read_csv(file.path("data", "location_data", "LDI_locations.csv")) %>% 
  # select plot ID and elevation
  select(plot_id = PlotID,
         elevation_ldi = Elevation) %>%
  # add geobase station elevations
  bind_cols(station_elevations) %>% 
  # calculate elevation difference to plot
  mutate_at(vars(starts_with("AWS"), starts_with("T")), ~ abs(elevation_ldi - .x)) %>% 
  rename_at(vars(starts_with("AWS"), starts_with("T")), ~ paste0("geobase_", .x, "_diff")) %>% 
  
  # identify col with min elevation difference & paste col name into new col
  # create new column with name of highest-correlated air temp series for each plot
  rowwise() %>% 
  mutate(min_diff_station = str_extract(names(.[-c(1:2)])[which.min(c_across(cols = contains("elev_diff")))],
                                        "[A-Z]{1,3}\\d"),
         min_elev_diff = min(c_across(cols = contains("elev_diff")))) %T>% 
  
  # save for closest station map
  write_rds(file = file.path("data", "plot_data", "processed", "disko_microclim_plot_station_elevation_differences.rds"))


# join TMS, HOBO and station data for growing season 2019
disko_tms_hobo_stations_season19 <- disko_tms_daily %>% 
  
  # drop amplitude columns
  select(-ends_with("_amp")) %>% 
  
  # make sure date column is formatted as date
  mutate(date = as.Date(date)) %>% 
  
  # rename TMS temperature variables
  rename_at(vars(matches("T\\d_*")), ~ paste0("tms_", .x)) %>% 
  
  # join HOBO data
  left_join(disko_hobo_daily %>% 
              select(-temp_amp) %>% 
              rename_at(vars(starts_with("temp_")), ~ paste0("hobo_", .x)),
            by = c("plot_id", "date")) %>% 
  
  # join closest station ID
  left_join(plot_station_elevation_diffs %>% 
              select(plot_id, min_diff_station)) %>% 
  
  # add daily station data
  left_join(disko_geobase_daily %>% 
              
              filter(sensor == "air") %>% 
              select(station_id,
                     date,
                     ends_with("_temp")) %>% 
              rename_at(vars(ends_with("_temp")), ~ paste0("station_pair_", .x)),
            by = c("min_diff_station" = "station_id",
                   "date" = "date")) %>% 
  
  # add temperatures from lowest-elevation station as base temperature for detrending daily microclimate
  left_join(disko_geobase_daily %>% 
              filter(sensor == "air") %>% 
              filter(station_id == "AWS3") %>%  # lowest-elevation station in Blæsedalen
              select(date,
                     ends_with("_temp")) %>%
              rename_at(vars(ends_with("_temp")), ~ paste0("station_base_", .x)),
            by = "date") %>% 
  
  # calculate differences between free-air temperatures and
    # 2019 growing season soil temperatures (T1)
  mutate(dT4T1_mean = tms_T1_mean - station_pair_daily_mean_temp,
         dT4T1_max = tms_T1_max - station_pair_daily_max_temp,
         dT4T1_min = tms_T1_min - station_pair_daily_min_temp,
         # 2019 growing season canopy temperatures (T3)
         dT4T3_mean = tms_T3_mean - station_pair_daily_mean_temp,
         dT4T3_max = tms_T3_max - station_pair_daily_max_temp,
         dT4T3_min = tms_T3_min - station_pair_daily_min_temp) %>% 
  
  rename_at(vars(starts_with("dT4T")), ~ paste0("tms_", .x))

# # save temperature data
# write_csv(disko_tms_hobo_stations_season19,
#           file.path("data", "microclimate_data", "processed", "disko_microclim_2019_tms_hobo_station_temp_moist_data_daily.csv"))


# join HOBO and station data for winter 2019-20
disko_hobo_stations_ndjfm1920 <- disko_hobo_daily %>% 
  
  mutate(date = as.Date(date)) %>% 
  
  # filter for winter period
  filter(date %within% interval(start = as.Date("2019-11-01"),
                                end = as.Date("2020-03-31"))) %>% 
  
  # rename HOBO temperature variables
  rename_at(vars(matches("temp_*")), ~ paste0("hobo_", .x)) %>% 
  
  # drop amplitude variable
  select(-hobo_temp_amp) %>% 
  
  # join closest station ID
  left_join(plot_station_elevation_diffs %>% 
              select(plot_id, min_diff_station)) %>% 
  
  # add daily station data
  left_join(disko_geobase_daily %>% 
              
              filter(sensor == "air") %>% 
              select(station_id,
                     date,
                     ends_with("_temp")) %>% 
              rename_at(vars(ends_with("_temp")), ~ paste0("station_pair_", .x)),
            by = c("min_diff_station" = "station_id",
                   "date" = "date")) %>% 
  
  # add temperatures from lowest-elevation station as base temperature for detrending daily microclimate
  left_join(disko_geobase_daily %>% 
              filter(sensor == "air") %>% 
              filter(station_id == "AWS3") %>%  # lowest-elevation station in Blæsedalen
              select(date,
                     ends_with("_temp")) %>% 
              rename_at(vars(ends_with("_temp")), ~ paste0("station_base_", .x)),
            by = "date") %>% 
  
  # calculate differences between free-air temperatures and
    # 2019/20 winter season soil temperatures (hobo)
  mutate(dT4hobo_mean = hobo_temp_mean - station_pair_daily_mean_temp,
         dT4hobo_max = hobo_temp_max - station_pair_daily_max_temp,
         dT4hobo_min = hobo_temp_min - station_pair_daily_min_temp) %>% 
  
  rename_at(vars(starts_with("dT4hobo")), ~ paste0("hobo_", .x))

# # save temperature data
# write_csv(disko_hobo_stations_ndjfm1920,
#           file.path("data", "microclimate_data", "processed", "disko_microclim_201920_hobo_station_temp_data_daily.csv"))




# # >> merge all temperature data (TMS + HOBO) ----
# 
# disko_temp_complete <- disko_stations_tms_season19 %>% 
#   
#   # unify column naming
#   rename_with(.cols = -c(plot_id,
#                          min_diff_station,
#                          starts_with("geobase")), 
#               .fn = ~ paste0("tms_", .x)) %>% 
#   rename_with(.cols = starts_with("geobase"), 
#               .fn = ~ paste0("station_", .x)) %>% 
#   
#   # join with TMS & GeoBase stations data
#   left_join(disko_hobo_seasonal,
#              by = "plot_id") %>% 
#   
#   relocate(min_diff_station, .after = plot_id) %>% 
#   relocate(starts_with("station"), .after = last_col())
# 
# # ¨¨¨¨ => save output ----
# # write.csv(disko_temp_complete,
# #           file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019-20_temp_data_cleaned_season_summary.csv"),
# #           row.names = FALSE)



# 2) plot data ----

# load species richness data
species_div <- read.csv(file.path("data", "plot_data", "processed", "LDI_speciesdiv_per_plot_wide.csv"))

# load veg metadata, calculate mean soil depth, extract relevant columns
plot_level_data <- read_csv(file.path("data", "plot_data", "LDI_plot_level_data.csv")) %>%  
  
  # rename variables to lower case
  rename_all(tolower) %>% 
  
  # >> location & elevation data from dGPS ----

# remove imprecise location data
  select(-c(lon, lat, elevation)) %>% 
  
  # add precise locations
  left_join(read_csv(file.path("data", "location_data", "LDI_locations.csv")) %>% 
              select(plot_id = PlotID,
                     lat = Latitude,
                     lon = Longitude,
                     elevation = Elevation),
            by = "plot_id") %>% 
  relocate(c(lat, lon, elevation), .after = hobo_id) %>% 
  
  # >> cover values ----
# recode cover values to mean of respective span (e.g., 10 (= 10-20) -> 15, + (= 0-5) -> 2.5)
  mutate_at(vars(starts_with("cov")), ~ as.character(.)) %>%         
  mutate_at(vars(starts_with("cov")), ~ recode(., "+" = "2.5",
                                               "5" = "7.5",
                                               "10" = "15",
                                               "20" = "25",
                                               "30" = "35",
                                               "40" = "45",
                                               "50" = "55",
                                               "60" = "65",
                                               "70" = "75",
                                               "80" = "85",
                                               "90" = "95")) %>%
  mutate_at(vars(starts_with("cov")), ~ as.numeric(.)) %>% 
  
  # rename forb cover columns
  rename_at(vars(starts_with("cover_forbs")), ~ str_remove(., "er")) %>% 
  
  # aggregate group cover values for every circle
  mutate(cov_vascular_10 = cov_shrubs_10 + cov_gramin_10 + cov_forbs_10,  
         cov_open_10 = cov_rocks_10 + cov_bare_10) %>% 
  mutate(cov_vascular_50 = cov_shrubs_50 + cov_gramin_50 + cov_forbs_50,   
         cov_open_50 = cov_rocks_50 + cov_bare_50) %>% 
  mutate(cov_vascular_200 = cov_shrubs_200 + cov_gramin_200 + cov_forbs_200,   
         cov_open_200 = cov_rocks_200 + cov_bare_200) %>% 
  mutate(cov_vascular_564 = cov_shrubs_564 + cov_gramin_564 + cov_forbs_564,   
         cov_open_564 = cov_rocks_564 + cov_bare_564) %>% 
  
  # >> dates & times ----  
# fix faulty / missing values

  mutate_at(vars(starts_with("date")), list(~ as.character(.))) %>% 
  
  # plot_level_data %>% filter(date_setup == "28/09/2019") %>% select(plot_id, date_setup) %>% print()
  # > 28/09 instead of 28/06 for LDI_018 & 079
  mutate(date_setup = ifelse(plot_id %in% c("LDI_018", "LDI_079"), "28/06/2019", date_setup)) %>% 
  
  # plot_level_data %>% filter(date_setup == "26/06/2019") %>% select(plot_id, date_setup) %>% print()
  # > 26/06 instead of 27/06 for LDI_075
  mutate(date_setup = ifelse(plot_id == "LDI_075", "27/06/2019", date_setup)) %>% 
  
  # plot_level_data %>% filter(is.na(date_tms_retrieval)) %>% select(plot_ID, date_tms_retrieval) %>% print()
  # > missing value for LDI_035
  mutate(date_tms_retrieval = ifelse(plot_id == "LDI_035" , "13/08/2019", date_tms_retrieval)) %>% 
  
  # plot_level_data %>% filter(date_tms_retrieval == "08/08/2016") %>% select(plot_id, date_tms_retrieval) %>% print()
  # > 08/08/2016 instead of 2019 for LDI_023
  mutate(date_tms_retrieval = ifelse(plot_id == "LDI_023", "08/08/2019", date_tms_retrieval)) %>% 
  
  # plot_level_data %>% filter(date_tms_retrieval == "09/08/2016") %>% select(plot_id, date_tms_retrieval) %>% print()
  # > 09/08/2016 instead of 2019 for LDI_013 & 077
  mutate(date_tms_retrieval = ifelse(plot_id %in% c("LDI_013", "LDI_077"), "09/08/2019", date_tms_retrieval)) %>% 
  
  # plot_level_data %>% filter(date_tms_retrieval == "09/09/2019") %>% select(plot_id, date_tms_retrieval) %>% print()
  # > 09/09/2019 instead of 09/08 for LDI_004 & 005
  mutate(date_tms_retrieval = ifelse(plot_id %in% c("LDI_004", "LDI_005"), "09/08/2019", date_tms_retrieval)) %>% 
  
  # create start/end columns
  mutate_at(vars(starts_with("date")), ~ as.POSIXct(., format = "%d/%m/%Y", tz = "America/Godthab")) %>% 
  
  # plot_level_data %>% filter(str_detect(time_tms_retrieval, "\\.")) %>% select(plot_id, time_tms_retrieval) %>% print()
  # > replace "." with ":" in time string for LDI_035, 039 & 041
  mutate(time_tms_retrieval = str_replace(time_tms_retrieval, "\\.", "\\:")) %>% 
  
  # >> logger information ----
# create manufacturer/model columns
  mutate(tms_logger_make = "TOMST",
         tms_logger_model = "TMS-4 standard",
         hobo_logger_make = "Onset",
         hobo_logger_model = case_when(hobo_id == 792 ~ "MX2202",
                                     TRUE ~ "MX2201")) %>% 
  
  # create sensor height/depth columns
  mutate(tms_T1_depth = -6,
         tms_T2_height = 2,
         tms_T3_height = 15,
         hobo_depth = -6) %>% 
  
  
  # >> general ----

# rename "region" to "sector" (e1:5 / w1:5 / c1:5)
  rename(sector = region) %>% 
  
  # calculate mean soil depth
  mutate(soil_depth_avg = (soil_depth_a + soil_depth_b + soil_depth_c + soil_depth_d)/4,
         
         # calculate mean TMS shield height
         tms_shield_height_avg = (shield_height_1 + shield_height_2 + shield_height_3 + shield_height_4)/4,
         
         # extract region (core = c, east = e, west = w)
         region = factor(str_extract(sector, "[:alpha:]")),
         
         # extract elevation bands 1:5
         elev_band = factor(str_extract(sector, "[:digit:]")),
         
         # order topography categories and create numeric version
         topo_prim = fct_relevel(topo_prim, 
                                 "snowbed", "depression", "flat", "slope", "ridge"),
         topo_prim_num = as.numeric(topo_prim)) %>% 
  
  # add vascular plant species diversity
  left_join(species_div, by = "plot_id") %>% 
  
  # add length of snow cover period (derived from HOBO record)
  left_join(snow_cover_duration, by = "plot_id") %>% 
  
  # add "phen" prefix to phenology columns
  rename_at(vars(betnan:castet), list(~paste0("phen_", .))) %>% 
  
  # filter for actual MicroClim plots
  filter(str_detect(plot_id, "LDI_\\d")) %>%
  
  # filter out variables from 10 cm circles
  select(-ends_with("_10")) %>% 
  droplevels() %>% 
  
  # >> calculate Solar Radiation Index ----
# Code adapted from S. Schøler Nielsen and N. Chardon (sri_calcuation.R in https://gitlab.com/nathaliechardon/gl_microclim)
# Based on Keating et al. 2007. Journal of Wildlife Management, 71:1344-1348

  mutate(sri_season19 = mapply(sri,
                               mode = "integrated",
                               start_date = max(date_setup),
                               end_date = min(date_tms_retrieval),
                               lon = lon,
                               lat = lat,
                               slope = slope,
                               aspect = aspect),
         sri_ndjfm1920 = mapply(sri,
                                mode = "integrated",
                                start_date = "01-11-2019",
                                end_date = "31-03-2020",
                                lon = lon,
                                lat = lat,
                                slope = slope,
                                aspect = aspect)) 
  
  
# # >> add moisture values ----
  # # calculate daily means
  # tms_moisture_daily <- disko_tms %>% 
  #   
  #   mutate(time_UTC = as.POSIXct(time_UTC)) %>% 
  #   
  #   mutate(date = format(time_UTC, "%Y-%m-%d")) %>% 
  #   
  #   # >> 081 & 070 had been exposed completely
  # 
  #   # Remove moisture values from LDI_081 for 20/21/22-07-2019 +- 1 day, just in case
  #   mutate_at(vars(contains("moist")), ~ as.numeric(.x)) %>% 
  #   mutate_at(vars(contains("moist")), ~ case_when(plot_id == "LDI_081" & 
  #                                                    date >= "2019-07-19" & date <="2019-07-23" ~ NA_real_,
  #   # Remove moisture values from LDI_070 for 15-07-2019 +- 1 day, just in case
  #                                                  plot_id == "LDI_070" & 
  #                                                   date >= "2019-07-14" & date <="2019-07-16" ~ NA_real_,
  #   # TMS -513 (LDI_063) & -515 (LDI_020) have low, fuzzy values (bad contact with substrate?) ->> remove
  #                                                  plot_id %in% paste0("LDI_0", c(20, 63)) ~ NA_real_,
  #                                                  TRUE ~ .)) %>% 
  #   
  #   # calculate daily averages
  #   group_by(plot_id, date) %>% 
  #   summarise(tms_moist_vol_daily_mean = mean(moist_vol, na.rm = TRUE),
  #             tms_moist_vol_daily_min = min(moist_vol, na.rm = TRUE),
  #             tms_moist_vol_daily_max = max(moist_vol, na.rm = TRUE),
  #             tms_moist_vol_daily_amp = tms_moist_vol_daily_max - tms_moist_vol_daily_min) %>% ungroup() %>% 
  #   # change -Inf's to NA
  #   mutate_at(vars(contains("moist_vol_daily")), ~ case_when(is.infinite(.)|is.nan(.) ~ NA_real_,
  #                                                        TRUE ~ .))
  # 
  # # # ¨¨¨¨ => save output
  # # write_csv(tms_moisture_daily,
  # #           file = file.path("data", "microclimate_data", "processed", "disko_microclim_2019_tms_moisture_daily_summary_cleaned.csv"))


  # calculate season19 averages
tms_moisture_season19 <- tms_moisture_daily_scaled %>%
  group_by(plot_id) %>%
  summarise(tms_moist_vol_mean_scaled = mean(tms_moist_vol_daily_mean_scaled, na.rm = TRUE),
            tms_moist_vol_min_scaled = mean(tms_moist_vol_daily_min_scaled, na.rm = TRUE),
            tms_moist_vol_max_scaled = mean(tms_moist_vol_daily_max_scaled, na.rm = TRUE),
            tms_moist_vol_amp_scaled = mean(tms_moist_vol_daily_amp_scaled, na.rm = TRUE)) %>%
  ungroup() %>% droplevels()

# add to plot data
plot_level_data <- plot_level_data %>%

  left_join(tms_moisture_season19) %>%

# rearrange columns, drop separate measurements of soil_depth & shield_height
select(plot_id:sector, region, elev_band,                # location / geographical variables
       aspect, slope, starts_with("sri"), starts_with("topo"),          # topography
       starts_with("tms_moist_vol_"),                  # seasonal scaled soil moisture
       ndays_snowcover_ndjfm,                          # approx. duration of snow cover during winter
       soil_depth_avg, peg_height, tms_shield_height_avg,    
       tms_substrate, starts_with("cover_tms_"), veg_height_avg_tms, veg_height_max_tms, # vars measured directly at TMS
       cover_hobo_ground, veg_height_avg_hobo, veg_height_max_hobo, # vars measured directly above HOBO
       ends_with("_setup"),               # installation metadata
       ends_with("_survey"),              # survey metadata
       ends_with("tms_retrieval"),        # TMS retrieval metadata
       ends_with("hobo_retrieval"),       # HOBO retrieval metadata
       starts_with("cov_"),               # plot-level cover of functional groups
       starts_with("veg_height"),         # estimated average vegetation height/density over plot
       starts_with("plant_div_"),         # vascular plant species diversity per plot
       # contains("phen"),                  # phenology observations at installation
       # contains("senesc"),                # senescence observations at retrieval
       # contains("teabag"),                # teabag data
       ends_with("logger_make"),          # logger manufacturers, = "TOMST" / "Onset"
       ends_with("logger_model"),         # logger models, = "TMS-4" / "MX2201 / MX2202
       tms_T1_depth, tms_T2_height,       # sensor positions
       tms_T3_height, hobo_depth)                    

# skim output
skimr::skim(plot_level_data)
# >> looking good

# # >> => save output ----
# write_csv(plot_level_data, file = file.path("data", "plot_data", "processed", "ldi_plot_level_data_cleaned.csv"))


# >> calculate daily Solar Radiation Index ----

# growing season
disko_sri_season19 <- disko_tms_hobo_stations_season19 %>%

  select(plot_id, date) %>%

  left_join(plot_level_data %>% select(plot_id,
                                       lon, lat, slope, aspect)) %>%

  group_by(plot_id) %>%
  mutate(sri_daily = sri(mode = "daily",
                         start_date = min(date),
                         end_date = max(date),
                         lon = unique(lon),
                         lat = unique(lat),
                         slope = unique(slope),
                         aspect = unique(aspect))) %>%

  select(plot_id, date, sri_daily)

# winter season
disko_sri_ndjfm1920 <- disko_hobo_stations_ndjfm1920 %>%

  select(plot_id, date) %>%

  left_join(plot_level_data %>% select(plot_id,
                                       lon, lat, slope, aspect)) %>%

  group_by(plot_id) %>%
  mutate(sri_daily = sri(mode = "daily",
                         start_date = min(date),
                         end_date = max(date),
                         lon = unique(lon),
                         lat = unique(lat),
                         slope = unique(slope),
                         aspect = unique(aspect))) %>%

  select(plot_id, date, sri_daily)


# 3) merge plot-level and temp data into seasonal datasets ----
# merge growing-season temperature & moisture data and plot-level data by plot ID
disko_data_complete_season19 <- disko_tms_hobo_stations_season19 %>% 
  
  left_join(plot_level_data,
            by = "plot_id") %>%
  
  left_join(disko_sri_season19,
            by = c("plot_id", "date")) %>%
  
  # reorder variables
  select(plot_id, date, 
         tms_id:comment_hobo_retrieval, tms_logger_make:hobo_depth,          # topographic & metadata
         starts_with("cov_"),                      # vegetation cover variables
         matches("veg_height_avg_\\d{2,3}"),       # vegetation height
         starts_with("plant_div_"),                # species diversity variables
         tms_T1_mean:tms_T3_max,                   # TMS temperatures
         hobo_temp_mean:hobo_temp_max,             # HOBO soil temperatures
         min_diff_station,                         # GeoBasis station with least elevational distance
         starts_with("station_pair_daily_"),       # closest GeoBasis station air temperatures
         starts_with("station_base_daily_"),       # lowest GeoBasis station air temperatures
         matches(".*dT\\d.*"),                     # temperature differences
         soil_class_TOMST,                         # TOMST soil class used for moisture calibration
         contains("moist"),                        # TMS moisture 
         sri_daily,                                # daily noon Solar Radiation Index
         -sri_ndjfm1920                             # drop winter-integrated SRI
  ) %>%
  
  relocate(sri_daily, .after = sri_season19)

# # save
# write_csv(disko_data_complete_season19,
#           file = file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))


# merge winter HOBO data and plot-scale data by plot ID
disko_data_complete_ndjfm1920 <- disko_hobo_stations_ndjfm1920 %>% 
  
  left_join(plot_level_data,
            by = "plot_id") %>% 
  
  left_join(disko_sri_ndjfm1920,
            by = c("plot_id", "date")) %>% 
  
  # reorder variables
  select(plot_id, date, 
         hobo_id:comment_hobo_retrieval, hobo_logger_make:hobo_depth,          # topographic & metadata
         starts_with("cov_"),                      # vegetation cover variables
         matches("veg_height_avg_\\d{2,3}"),       # vegetation height
         starts_with("plant_div_"),                # species diversity variables
         hobo_temp_mean:hobo_temp_max,             # HOBO soil temperatures
         min_diff_station,                         # GeoBasis station with least elevational distance
         starts_with("station_pair_daily_"),            # correlated GeoBasis station air temperatures
         starts_with("station_base_daily_"),       # lowest GeoBasis station air temperatures
         matches(".*dT\\d.*"),                     # temperature differences 
         sri_daily,                                # daily noon Solar Radiation Index
         -sri_season19,                             # drop growing-season-integrated SRI
         -contains("tms")                           # drop TMS-related columns
  ) %>% 
  
  relocate(sri_daily, .after = sri_ndjfm1920)

# # save
# write_csv(disko_data_complete_ndjfm1920,
#           file = file.path("data", "plot_data", "processed", "microclim_plot_data_complete_ndjfm1920.csv"))



# ____________________________----

# end of script