### Shrubs, bryophytes and snow influence microclimate across topographic and moisture gradients in the Arctic tundra
### von Oppen J, et al. 2022

### Figures

### Code by Jonathan von Oppen, Aarhus University, jonathan.vonoppen@bio.au.dk, February 2020 - January 2022
### sections 2, 3, 4, 5, 6 based on code by Jakob Assmann, j.assmann@bio.au.dk



### 0) Dependencies ----

  # >> [a] packages ----
  
    # load pacman package from the repository, if you do not already have it
    if(!require(pacman)){       # provides p_load() as wrapper for require() and library()
      install.packages("pacman")
      library(pacman)
    }
    pacman::p_load(raster,      # for preparing spatial data
                   sf,
                   rgdal,
                   tidyverse,   # for multiple data wrangling & visualisation packages
                   # tidylog,     # to log operations in pipes
                   magrittr,    # for piping functions
                   ggnewscale,  # for several fill scales within one plot (points, raster)
                   ggtext, glue,# for flexible text labels in plots
                   ggforce,     # for additional geoms in ggplot
                   ggbeeswarm,
                   ggspatial,   # for spatial ggplot functionality, e.g. scalebars
                   cowplot,     
                   patchwork)   # to combine plots in panels
  
  
  # >> [b] functions ----
  
    # load model and plotting functions
    source(file = file.path("scripts", "functions.R"))
  
    # pre-empty conflicted functions
    if("tidylog" %in% (.packages())) select <- tidylog::select else select <- dplyr::select  # prefer tidylog function over dplyr over raster etc.
    
  
  # >> [c] colour scheme ----
    
    # maps
    theme_darkgreen <- "#355d00"
    theme_darkred <- "#7c3f3f"
    theme_forestgreen <- "#3d8225"
    theme_grey <- "#EDEDEDFF"
    
    # effect sizes plot - T means
    theme_violet <- "#a177e0"
    theme_green <- "#58bb5b"
    theme_brown <- "#9e5f3f"
    theme_turquoise <- "#28BECB"
  
    # effect sizes plots - T differences
    theme_purple <- "#8757B3"
    theme_darkblue <- "#4f5faf"
    theme_lightblue <- "#5995c5"
    theme_yellow <- "#ffcc00"
    theme_orange <- "#c87e1f"
    theme_red <- "#a44748"
    
    # prediction plots
    theme_blueblack <- "#223769"
    theme_bluegreen <- "#4384ad"
    theme_gold <- "#de9e04"
    theme_brightgold <- "#ffd700"
    theme_darkred <- "#7c3f3f"
    theme_lightred <- "#ca6162"
    theme_darkgreen <- "#355d00"
    theme_forestgreen <- "#3d8225"
    theme_lightgreen <- "#56c94a"
  
  
  # >> [d] directories ----
  
    # figures
    if(!dir.exists("figures")) dir.create("figures")



#________________________________----
# MAIN TEXT FIGURES ----
# _______________________________----

### Figure 1: study design overview ----

# >> [a] study area ----

# # get coastline
# disko_coast <- mapview::mapview() %>%
#   # initiate interactive drawing tool
#   mapedit::editMap()
# st_write(disko_coast$finished,
#          dsn = "data/geo_features",
#          layer = "disko_inverse_coastline",
#          driver = "ESRI Shapefile",
#          delete_layer = TRUE)
disko_coast <- st_read(dsn = "data/geo_features", 
                       layer = "disko_inverse_coastline")

# load ArcticDEM 
arctic_dem_disko <- raster("I:/C_Write/_Proj/Greenland_NormandVegDyn_au150176/Disko/2019/ArcticDEM/tiles/18_37_2_2_2m_v3.0/18_37_2_2_2m_v3.0_reg_dem.tif") %>% 
  
  # crop for study area
  raster::crop(extent(-338000, -331400, -2247000, -2240000)) %>% 
  
  # convert to long/lat
  projectRaster(crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs") 

# mask ocean area
arctic_dem_disko_land_raster <- arctic_dem_disko %>% 
  mask(disko_coast, inverse = TRUE)

# convert to df
arctic_dem_disko_land <- arctic_dem_disko_land_raster %>% 
  
  as("SpatialPixelsDataFrame") %>% 
  raster::as.data.frame() %>% 
  
  rename(elev = "X18_37_2_2_2m_v3.0_reg_dem") %>% 
  
  mutate(elev_band = case_when(elev < 160 ~ "1",
                               elev %in% c(161:320) ~ "2",
                               elev %in% c(321:480) ~ "3",
                               elev %in% c(481:640) ~ "4",
                               elev > 640 ~ "5",
                               TRUE ~ NA_character_))

# get contour lines
disko_elev_bands_major <- arctic_dem_disko_land_raster %>% 
  #cut() %>% 
  rasterToContour(levels = seq(160, 640, 160)) %>% 
  fortify()
disko_elev_bands_minor <- arctic_dem_disko_land_raster %>% 
  #cut() %>% 
  rasterToContour(levels = seq(0, 840, 20)) %>% 
  fortify()

# create elevation band labels
elev_band_labels <- tibble(
  band = as.character(c(1, rep(2:5, 2))),
  x = c(-53.475, -53.465, -53.457, -53.448, -53.431, 
        -53.5, -53.516, -53.545, -53.542),
  y = c(69.2775, 69.283, 69.2875, 69.289, 69.286,
        69.291, 69.29, 69.2825, 69.296)
)


# # load complete sampling area
# sampling_area <- readOGR(dsn = "data/geo_features/Disko2019_SamplingArea.kml", 
#                          require_geomType = "wkbPolygon") %>% st_as_sf() %>% 
#   st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.26, ymax = 69.297))


# load plot locations
ldi_coord <- read_csv(file.path("data", "location_data", "LDI_locations.csv")) %>% 
  
  select(plot_id = PlotID, 
         long = Longitude, lat = Latitude) %>% 
  
  st_as_sf(coords = c("long", "lat"),
           crs = 4326) %>% 
  
  filter(plot_id %in% c(paste0("LDI_00", 1:9),
                        paste0("LDI_0", 10:90))) %>% 
  
  mutate(core_area = case_when(plot_id %in% paste0("LDI_0", 61:90) ~ TRUE,
                               TRUE ~ FALSE))

# load weather station locations 
# available at Greenland Ecosystem Monitoring, https://g-e-m.dk/
station_coord <- read_csv(file.path("data", "location_data", "station_locations.csv")) %>% 
  filter(!station_id == "AWS2") %>% 
  mutate(symbol_size = case_when(station_id == "AWS3" ~ 3.25,
                                 TRUE ~ 2))

# load hydrology features (digitised by JvO through mymaps.google.com)

# morænesø in/outflow
moraeneso_in_out <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/moraeneso_in_out.kml", 
                            layer = "moraeneso_in_out", 
                            require_geomType = "wkbLineString") %>% st_as_sf()

# morænesø lake area
moraeneso <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/moraeneso_lake.kml", 
                     layer = "moraeneso_lake", 
                     require_geomType = "wkbPolygon") %>% st_as_sf()

# Røde Elv - main channels
rode_elv_main <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/rode_elv_main.kml", 
                         layer = "rode_elv_main", 
                         require_geomType = "wkbLineString") %>% st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.26, ymax = 69.297))

# Røde Elv - side channels
rode_elv_braids <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/rode_elv_braids.kml", 
                         layer = "rode_elv_braids", 
                         require_geomType = "wkbLineString") %>% st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.26, ymax = 69.297))

# Lyngmarksfjeld rivers
lyngmark_rivers_1 <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmarks_baek.kml", 
                               layer = "lyngmarks_baek", 
                               require_geomType = "wkbLineString") %>% 
  st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.26, ymax = 69.297))

lyngmark_rivers_2 <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmarks_baek2.kml", 
                             layer = "lyngmarks_baek2", 
                             require_geomType = "wkbLineString") %>% st_as_sf()

lyngmark_rivers_3 <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmarks_baek3.kml", 
                             layer = "lyngmarks_baek3", 
                             require_geomType = "wkbLineString") %>% st_as_sf()

lyngmark_rivers_4 <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmarks_baek4.kml", 
                             layer = "lyngmarks_baek4", 
                             require_geomType = "wkbLineString") %>% st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.26, ymax = 69.297))

# Lyngmarksfjeld lakes
lyngmark_lakes <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmark_lakes.kml", 
                          layer = "lyngmark_lakes", 
                          require_geomType = "wkbPolygon") %>% st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.26, ymax = 69.297))

# Skarvefjeld rivers
skarvefjeld_rivers <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/skarvefjeld_baek.kml", 
                         layer = "skarvefjeld_baek", 
                         require_geomType = "wkbLineString") %>% st_as_sf()

# # # save/load previous shapes as digitised through mapview()
# # load(file.path("data", "geo_features", "disko_water_shapes.Rdata"))


# plot map
(elev_map <- ggplot() +
    
    # plot elevation raster
    geom_raster(data = arctic_dem_disko_land,
                aes(x = x,
                    y = y,
                    fill = elev)) +
    scale_fill_gradientn(colours = terrain.colors(10)) +
    new_scale_fill() +
    
    # plot contour lines
    geom_path(data = disko_elev_bands_minor,
              aes(x = long,
                  y = lat,
                  group = group),
              colour = "grey65",
              size = 0.25) +
    geom_path(data = disko_elev_bands_major,
                 aes(x = long,
                     y = lat,
                     group = group),
              colour = "grey25",
              size = 0.25) +
    
    # # plot sampling area
    # geom_sf(data = sampling_area,
    #         fill = NA,
    #         colour = "grey20", 
    #         linetype = "dotdash") +
    
    # annotate elevation bands
    geom_text(data = elev_band_labels,
              aes(label = band,
                  x = x,
                  y = y),
              fontface = "bold") +
    
    # plot lake in/outflow
    geom_sf(data = moraeneso_in_out,
            colour = "#2F91D0") +
    
    # plot morænesø lake
    geom_sf(data = moraeneso,
            colour = NA,
            fill = "#2F91D0") +
    
    # plot main river
    geom_sf(data = rode_elv_main,
            colour = "#2F91D0",
            size = 1) +
    
    # plot main river braids
    geom_sf(data = rode_elv_braids,
            colour = "#2F91D0",
            size = 0.5) +
    
    # plot slope rivers
    geom_sf(data = skarvefjeld_rivers,
            colour = "#2F91D0") +
    geom_sf(data = lyngmark_rivers_1,
            colour = "#2F91D0") +
    geom_sf(data = lyngmark_rivers_2,
            colour = "#2F91D0") +
    geom_sf(data = lyngmark_rivers_3,
            colour = "#2F91D0") +
    geom_sf(data = lyngmark_rivers_4,
            colour = "#2F91D0") +
    
    # plot Lyngmark lakes
    geom_sf(data = lyngmark_lakes,
            colour = NA,
            fill = "#2F91D0") +
    
    # plot locations
    geom_sf(data = ldi_coord,
            aes(fill = core_area),
            colour = "grey15",
            size = 3,
            shape = 21) +
    scale_fill_manual(values = c("grey75", "grey25")) +
    
    # station locations
    geom_point(data = station_coord,
               aes(x = long, y = lat,
                   size = symbol_size),
               shape = 25,
               colour = "grey15",
               fill = "white") +
    scale_size_identity() +
    
    # set axes ranges
    xlim(-53.56, -53.41) +
    ylim(69.26, 69.297) +
    
    # blank theme
    theme_nothing() #+
    # theme(panel.border = element_rect(fill = NA,
    #                                   size = 1))
    )

# add scalebar
# library(ggspatial)
(elev_map_scale <- elev_map +         # map to add to
    annotation_scale(location = "br",
                     bar_cols = c("grey15", "white"),
                     pad_x = unit(1.2, "cm"),
                     pad_y = unit(0.8, "cm"),
    ) +
    
    annotation_north_arrow(style = north_arrow_orienteering,
                           location = "br",
                           pad_x = unit(1, "cm"),
                           pad_y = unit(2, "cm")))
    

# # save map
# save_plot(file = file.path("figures", "study_area_overview_map.png"),
#           plot = elev_map_scale,
#           base_height = 8,
#           base_aspect_ratio = 1.3)


# >> [b] Greenland map ----
# based on https://www.r-bloggers.com/2019/04/zooming-in-on-maps-with-sf-and-ggplot2/
# define centre zoom point
zoom_to <- c(-53.5, 69.275)

# define target CRS
target_crs <- sprintf('+proj=6063 +lon_0=%f +lat_0=%f',
                      zoom_to[1], zoom_to[2])

# get coastline from greenland outline (source: https://github.com/ropensci/rnaturalearthhires )
inset_map_data <- rnaturalearth::ne_countries(scale = "large",
                                              returnclass = "sf") %>%
  #retain only name and geometry
  dplyr::select(name,
                geometry) %>% 
  # filter for relevant countries
  filter(name %in% c("Greenland", "Canada", "Iceland")) %>% 
  # transform CRS
  st_transform(crs = 6063) # GR96 CRS, https://epsg.io/6063

# define zoom level and ranges
zoom_level <- 3.7

C <- 40075016.686   # ~ circumference of Earth in meters
x_span <- C / 2^zoom_level
y_span <- C / 2^(zoom_level)

# convert central point to target CRS
zoom_to_xy <- st_sfc(st_point(zoom_to), crs = 4326) %>% 
  st_transform(crs = 6063)

# calculate lon and lat ranges for display window by subtracting/adding the half of the above ranges from/to the zoom center coordinates respectively.
disp_window <- st_sfc(
  st_point(st_coordinates(zoom_to_xy - c(x_span / 2, y_span / 2))),
  st_point(st_coordinates(zoom_to_xy + c(x_span / 2, y_span / 2))),
  crs = 6063)

# plot map
(inset_map <- ggplot() +
    geom_sf(data = inset_map_data,
            fill = "white") +
    geom_sf(data = zoom_to_xy,
            colour = "red",
            size = 2) +
    coord_sf(xlim = st_coordinates(disp_window)[,'X'],
             ylim = st_coordinates(disp_window)[,'Y'],
             crs = 6063) +
    theme_nothing() +
    theme(panel.grid.major = element_line(colour = "grey85"),
          panel.background = element_rect(fill = "grey95"),
          panel.border = element_rect(colour = "grey15",
                                      fill = NA)))
  

# combine maps
(disko_map <- ggdraw(elev_map_scale) +
    
    draw_plot(inset_map,
              halign = 0,
              valign = 0.09,
              scale = 0.31))
  
  
# >> [c] plot layout ----

# create circles for different radii
centre_point <- st_point(c(0,0))
tms_point <- st_point(c(0,10))
hobo_point <- st_point(c(0,-10))
arrow_50 <- data.frame(x = c(0, 25), 
                       y = c(0, -25))
arrow_200 <- data.frame(x = c(0, 123),
                        y = c(0, 40))
arrow_564 <- data.frame(x = c(0, -275),
                        y = c(0, -45))

labels <- tibble(
  circle = c("50", "200", "564"),
  x = c(25, 42, -210),
  y = c(-77, 75, 10),
  label = c(glue("**small**<br/>*r* = 0.50 m<br/>*A* = 0.79 m<sup>2</sup>"),
            glue("**medium**<br/>*r* = 2.00 m<br/>*A* = 12.57 m<sup>2</sup>"),
            glue("**large**<br/>*r* = 5.64 m<br/>*A* = 99.93 m<sup>2</sup>"))
) 

(circle_plot <- ggplot() +
    
    # arrows
    geom_path(data = arrow_50,
              aes(x = x, y = y),
              arrow = arrow(length = unit(0.20, "cm"), ends = "last", type = "closed"),
              colour = "grey30",
              size = 1) +
    geom_path(data = arrow_200,
              aes(x = x, y = y),
              arrow = arrow(length = unit(0.20, "cm"), ends = "last", type = "closed"),
              colour = "grey60",
              size = 1) +
    geom_path(data = arrow_564,
              aes(x = x, y = y),
              arrow = arrow(length = unit(0.20, "cm"), ends = "last", type = "closed"),
              colour = "grey60",
              size = 1) + 
    # centre point
    geom_point(aes(x = 0, y = 0),
               pch = 18,
               size = 2.5) +
    # logger points
    geom_sf(data = st_point(c(0,10)), # TMS position
            colour = "#1F9B44",
            size = 3) +
    geom_sf(data = st_point(c(0,-10)), # HOBO position
            colour = theme_lightblue,
            size = 3) +
    # circles
    geom_sf(data = st_buffer(st_centroid(centre_point), 
                             50*0.75), 
            colour = "black", 
            fill = NA,
            size = 1.1,
            linetype = "solid") +
    geom_sf(data = st_buffer(st_centroid(centre_point), 
                             200*2/3), 
            colour = "grey30", 
            fill = NA,
            size = 0.9,
            linetype = "solid") +
    geom_sf(data = st_buffer(st_centroid(centre_point), 
                             564*0.5), 
            colour = "grey30", 
            fill = NA,
            size = 0.9,
            linetype = "solid") + 
    # circle labels
    geom_richtext(data = labels,
                  aes(x = x, y = y,
                      label = label),
                  size = 3,
                  fill = NA,
                  label.colour = NA) +
    # labelling curve
    geom_curve(aes(x = 8, y = -19, 
                   xend = 15, yend = -42),
               curvature = 0.3,
               colour = "grey20",
               size = 0.7) +
    theme_nothing()
)


# >> [d] temperature loggers ----
all_loggers <- png::readPNG(file.path("figures", "drawings", "microclim_all_loggers.png"))

(logger_plot <- plot_grid(ggdraw() +
                            draw_image(file.path("figures", "drawings", "microclim_all_loggers_offsets_bw.png"),
                                       scale = 1),
                          ggdraw() +
                            draw_label("free-air\n(+ 2 m)",
                                       colour = theme_darkblue,
                                       x = -1.55,
                                       y = 0.88,
                                       size = 10,
                                       fontface = "bold") +
                            draw_label("canopy layer\n   (+ 15 cm)",
                                       colour = theme_violet,
                                       x = 0.25,
                                       y = 0.585,
                                       size = 10,
                                       fontface = "bold") +
                            draw_label("near-surface\n   (+ 2 cm)",
                                       colour = theme_green,
                                       x = 0.35,
                                       y = 0.28,
                                       size = 10,
                                       fontface = "bold") +
                            draw_label("soil\n(- 6 cm)",
                                       colour = theme_brown,
                                       x = 0.4,
                                       y = 0.12,
                                       size = 10,
                                       fontface = "bold"),
                          ncol = 2,
                          rel_widths = c(.7, .15)))
                         

# >> compile figure ----
(overview_figure <- plot_grid(disko_map,
                              plot_grid(circle_plot,
                                        logger_plot,
                                        nrow = 1,
                                        rel_widths = c(1.15, 1),
                                        labels = c("(b)", "(c)")),
                              ncol = 1,
                              rel_heights = c(1.5, 1),
                              labels = c("(a)", " "),
                              vjust = 3))

# save figure
save_plot(file = file.path("figures", "microclim_offsets_figure1_study_overview.png"),
          plot = overview_figure,
          # dpi = 600,
          base_height = 10,
          base_aspect_ratio = 0.8)


### Figure 2: daily temperatures across time ----

# >> prepare data ----
# growing season 2019
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))
# winter 2019-20
disko_data_complete_ndjfm1920 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_ndjfm1920.csv"))

# combine data
disko_gsT_long <- disko_data_complete_season19 %>% 
  
  tidylog::select(plot_id, date,
                  starts_with("station_base"),
                  starts_with("tms_T"), -ends_with("depth"), -ends_with("height"),
                  starts_with("hobo_temp")) %>% 
  pivot_longer(cols = starts_with("station")|starts_with("tms_T")|starts_with("hobo"),
               names_to = "temp_var",
               names_prefix = "tms_",
               values_to = "temp_value") %>% 
  mutate(temp_var = str_remove(temp_var, "_temp"),
         temp_var = str_remove(temp_var, "_base_daily"),
         season = "growing season")

disko_winterT_long <- disko_data_complete_ndjfm1920 %>% 
  
  tidylog::select(plot_id, date,
                  starts_with("station_base"),
                  starts_with("hobo_temp")) %>% 
  
  pivot_longer(cols = starts_with("station")|starts_with("hobo"),
               names_to = "temp_var",
               values_to = "temp_value") %>% 
  mutate(temp_var = str_remove(temp_var, "_temp"),
         temp_var = str_remove(temp_var, "_base_daily"),
         season = "winter")

# combine for amplitude plots
temp_amp_data <- disko_gsT_long %>% 
  bind_rows(disko_winterT_long) %>% 
  mutate(sensor = str_extract(temp_var, "[:alnum:]+"),
         temp_var = str_remove(temp_var, "[:alnum:]+_")) %>% 
  group_by(season, date, sensor, temp_var) %>% 
  summarise(mean_temp_value = mean(temp_value, na.rm = TRUE)) %>% ungroup() %>% 
  pivot_wider(names_from = temp_var,
              values_from = mean_temp_value) %>% 
  
  mutate(sensor = factor(sensor),
         sensor2 = fct_relevel(sensor, c("station", "T3", "T2", "hobo", "T1"))) %>% 
  
  mutate(season_layer = case_when(season == "growing season" & sensor == "station" ~ "growing-season free-air",
                                  season == "growing season" & sensor == "T3" ~ "growing-season canopy-level",
                                  season == "growing season" & sensor == "T2" ~ "growing-season near-surface",
                                  season == "growing season" & sensor %in% c("T1", "hobo") ~ "growing-season soil",
                                  season == "winter" & sensor == "station" ~ "winter free-air",
                                  season == "winter" & sensor == "hobo" ~ "winter soil"),
         season_layer = fct_relevel(season_layer, c("growing-season free-air",
                                                    "growing-season canopy-level",
                                                    "growing-season near-surface",
                                                    "growing-season soil",
                                                    "winter free-air",
                                                    "winter soil")),
         layer = season_layer %>% str_extract("(?<=\\s).+$"),
         theme_colour = case_when(sensor == "station" ~ theme_darkblue,
                                  sensor == "T3" ~ theme_purple,
                                  sensor == "T2" ~ theme_green,
                                  sensor == "T1" ~ theme_brown,
                                  sensor == "hobo" ~ theme_lightblue)) %>% 
  # calculate axis range per layer group
  group_by(layer) %>% 
  mutate(y_min = min(min, na.rm = TRUE),
         y_max = max(max, na.rm = TRUE)) %>% ungroup() %>% 
  
  # group & split by season and layer
  arrange(season_layer) %>% 
  group_by(season_layer) %>% 
  group_split()

# >> build plot ----

temp_amp_plot_list <- lapply(temp_amp_data,  function(dat){
    sensor <- dat %>% pull(sensor) %>% as.character() %>% unique()
    layer <- dat %>% pull(layer) %>% as.character() %>% unique()
    season <- dat %>% pull(season) %>% as.character() %>% unique()
    
    # y_min <- dat %>% pull(y_min) %>% unique()
    # y_max <- dat %>% pull(y_max) %>% unique()
    
    y_min <- -26.5
    y_max <- 24.5
    
    x_axis_text_display <- "element_blank()"
    if(layer == "soil") x_axis_text_display <- "element_text(size = rel(0.9))"
    
    y_axis_display <- "element_line()"
    if(season == "winter") y_axis_display <- "element_blank()"
    if(season == "winter") y_axis_text_display <- "element_blank()"
    
    y_axis_breaks = c(-20, -10, 0, 10, 20)
    # if(all(sensor %in% c("T3", "T2"))) y_axis_breaks <- seq(0, 20, 5)
    
    temp_amp_plot <- ggplot(data = dat,
                            aes(x = date,
                                colour = theme_colour,
                                fill = theme_colour)) +
      geom_ribbon(aes(ymin = min,
                      ymax = max),
                  # linetype = "dashed",
                  # fill = "grey90",
                  colour = NA,
                  alpha = .4) +
      geom_line(aes(y = mean),
                size = 1.5) +
      labs(x = "",
           y = "") +
      scale_colour_identity() +
      scale_fill_identity() +
      # {if(length(sensor) > 1)
      # scale_colour_manual("sensor", 
      #                     values = c(theme_turquoise, theme_brown, theme_green, theme_violet),
      #                     breaks = levels(disko_temp_amp_data2$sensor)) +
      # scale_fill_manual("sensor",
      #                   values = c(theme_turquoise, theme_brown, theme_green, theme_violet),
      #                   breaks = levels(disko_temp_amp_data2$sensor)) +}
      scale_x_date(breaks = as.Date(c("2019-07-01", "2019-07-15", "2019-08-01",
                                      "2019-11-01", "2019-12-01", "2020-01-01", "2020-02-01", "2020-03-01", "2020-03-31")),
                   date_labels = "%d %b") +
      scale_y_continuous(limits = c(y_min, y_max),
                         breaks = y_axis_breaks) +
      guides(colour = "none",
             fill = "none") +
      theme_cowplot() +
      
      # x axis text display
      {if(layer != "soil") theme(axis.line.x = element_blank(),
                                 axis.ticks.x = element_blank(),
                                 axis.text.x = element_blank())} +
      
      # y axis text display
      {if(season == "winter") theme(axis.line.y = element_blank(),
                                    axis.ticks.y = element_blank(),
                                    axis.text.y = element_blank())} +
      
      theme(axis.title = element_blank())
    
    
    return(temp_amp_plot)
  })
  
temp_amp_plot_grid <- plot_grid(plotlist = list(temp_amp_plot_list[[1]],
                                                temp_amp_plot_list[[2]],
                                                temp_amp_plot_list[[3]],
                                                temp_amp_plot_list[[4]],
                                                temp_amp_plot_list[[5]],
                                                NULL,
                                                NULL,
                                                temp_amp_plot_list[[6]]),
                                # labels = c(paste0(letters[1:5], ")"), "", "", "f)"),
                                # label_fontface = "bold", 
                                align = "hv",
                                ncol = 2,
                                byrow = FALSE)

left_label <- 
  plot_grid(plot_grid(plot_grid(ggdraw() +
                                  draw_label("free-air reference",
                                             colour = theme_darkblue,
                                             y = 0.6,
                                             angle = 90,
                                             size = 16,
                                             fontface = "bold"),
                                ggdraw() +
                                  draw_image(file.path("figures", "drawings", "microclim_station_summer_winter.png"),
                                             scale = 0.8,
                                             y = 0.1),
                                rel_widths = c(0.3, 1)),
                      plot_grid(ggdraw() +
                                  draw_label("canopy-layer",
                                             colour = theme_violet,
                                             y = 0.6,
                                             angle = 90,
                                             size = 16,
                                             fontface = "bold"),
                                ggdraw() +
                                  draw_image(file.path("figures", "drawings", "microclim_tms_T3.png"),
                                             scale = 0.8,
                                             y = 0.1),
                                rel_widths = c(0.3, 1)),
                      plot_grid(ggdraw() +
                                  draw_label("near-surface",
                                             colour = theme_green,
                                             y = 0.6,
                                             angle = 90,
                                             size = 16,
                                             fontface = "bold"),
                                ggdraw() +
                                  draw_image(file.path("figures", "drawings", "microclim_tms_T2.png"),
                                             scale = 0.8,
                                             y = 0.1),
                                rel_widths = c(0.3, 1)),
                      plot_grid(ggdraw() +
                                  draw_label("soil",
                                             colour = theme_brown,
                                             y = 0.6,
                                             angle = 90,
                                             size = 16,
                                             fontface = "bold"),
                                ggdraw() +
                                  draw_image(file.path("figures", "drawings", "microclim_tms_hobo_winter.png"),
                                             scale = 0.8,
                                             y = 0.1),
                                rel_widths = c(0.3, 1)),
                      ncol = 1,
                      rel_heights = c(1, 1, 1, 1)))

bottom_label <- ggdraw() +
  draw_label("date",
             x = .585,
             size = 17,
             fontface = "bold")

plot_temp_amp <- plot_grid(plot_grid(left_label,
                                     ggdraw() +
                                       draw_label("\ndaily mean ± max. and min. temperature [°C] across all plots\n",
                                                  x = .5,
                                                  size = 17,
                                                  angle = 90,
                                                  fontface = "bold"),
                                     temp_amp_plot_grid,
                                     nrow = 1,
                                     rel_widths = c(0.15, 0.04, 1)),
                           bottom_label,
                           ncol = 1,
                           rel_heights = c(1, .08))

# save
save_plot(filename = file.path("figures", "microclim_offsets_figure2_daily_temp_var_yrange_aligned.png"),
          plot = plot_temp_amp,
          base_height = 10,
          base_asp = 1.5,
          dpi = 600)


### Figure 3: mean/min/max T (50 cm) ----

# load model outputs
lapply(paste0("model_outputs/", list.files("model_outputs", pattern = "*_T\\d_|*_hobo_ndjfm_50\\.Rdata*")),
       load,
       .GlobalEnv)

# load plotting functions
source(file = file.path("scripts", "functions.R"))

# >> [a,b,c] TMS T3 ----

# compile & save plots
mcmc_plot_list_T3_50 <- lapply(model_list_mcmc_T3_50, mcmc_plot_function, labels_display = "left")

# >> [d,e,f] TMS T2 ----
# compile & save plots
mcmc_plot_list_T2_50 <- lapply(model_list_mcmc_T2_50, mcmc_plot_function, labels_display = "left")

# >> [g,h,i] TMS T1 ----
# compile & save plots
mcmc_plot_list_T1_50 <- lapply(model_list_mcmc_T1_50, mcmc_plot_function, labels_display = "left")

# >> [j,k,l] HOBO (winter) ----

# compile & save plots
mcmc_plot_list_hobo_50 <- lapply(model_list_mcmc_hobo_50, mcmc_plot_function, labels_display = "left")


# >> combine panels ----
(plot_grid_meanT <- 
   plot_grid(ggdraw() +
               draw_label("\n growing season (Jun - Aug)\n",
                          colour = "grey50",
                          x = 0.625,
                          size = 15,
                          fontface = "bold"),
             plot_grid(plot_grid(ggdraw() +
                                   draw_label("canopy layer",
                                              colour = theme_violet,
                                              y = 0.6,
                                              angle = 90,
                                              size = 16,
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_image(file.path("figures", "drawings", "microclim_tms_T3.png"),
                                              scale = 1,
                                              y = 0.1),
                                 nrow = 1),
                       plot_grid(plotlist = mcmc_plot_list_T3_50,
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(0.4, 0.3, 0.3),
                                 labels = c("(a)", "(b)", "(c)"),
                                 label_fontface = "bold",
                                 label_size = 15,
                                 hjust = c(-6.3, -1.6, -1.6),
                                 vjust = c(0, 0, 0)),
                       nrow = 1,
                       rel_widths = c(0.15, 1)),
             plot_grid(plot_grid(ggdraw() +
                                   draw_label("near-surface",
                                              colour = theme_green,
                                              y = 0.6,
                                              angle = 90,
                                              size = 16,
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_image(file.path("figures", "drawings", "microclim_tms_T2.png"),
                                              scale = 1,
                                              y = 0.1),
                                 nrow = 1),
                       plot_grid(plotlist = mcmc_plot_list_T2_50,
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(0.4, 0.3, 0.3),
                                 labels = c("(d)", "(e)", "(f)"),
                                 label_fontface = "bold",
                                 label_size = 15,
                                 hjust = c(-6.1, -1.7, -2.1),
                                 vjust = c(0, 0, 0)),
                       nrow = 1,
                       rel_widths = c(0.15, 1)),
             plot_grid(plot_grid(ggdraw() +
                                   draw_label("soil (summer)",
                                              colour = theme_brown,
                                              y = 0.6,
                                              angle = 90,
                                              size = 16,
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_image(file.path("figures", "drawings", "microclim_tms_T1.png"),
                                              scale = 1,
                                              y = 0.1),
                                 nrow = 1),
                       plot_grid(plotlist = mcmc_plot_list_T1_50,
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(0.4, 0.3, 0.3),
                                 labels = c("(g)", "(h)", "(i)"),
                                 label_fontface = "bold",
                                 label_size = 15,
                                 hjust = c(-6.1, -1.6, -2.1),
                                 vjust = c(0, 0, 0)),
                       nrow = 1,
                       rel_widths = c(0.15, 1)),
             ggdraw() +
               draw_label("\n winter (Nov - Mar)\n",
                          colour = "grey50",
                          x = 0.625,
                          size = 15,
                          fontface = "bold"),
             plot_grid(plot_grid(ggdraw() +
                                   draw_label("soil (winter)",
                                              colour = theme_turquoise,
                                              y = 0.6,
                                              angle = 90,
                                              size = 16,
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_image(file.path("figures", "drawings", "microclim_hobo_winter.png"),
                                              scale = 1,
                                              y = 0.1),
                                 nrow = 1),
                       plot_grid(plotlist = mcmc_plot_list_hobo_50,
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(0.4, 0.3, 0.3),
                                 labels = c("(j)", "(k)", "(l)"),
                                 label_fontface = "bold",
                                 label_size = 15,
                                 hjust = c(-8.2, -1.7, -2.2),
                                 vjust = c(0, 0, 0)),
                       nrow = 1,
                       rel_widths = c(0.15, 1)),
             nrow = 6,
             rel_heights = c(0.4, 1, 1, 1, 0.5, 1)))

# make titles and x--axis label
top_label <- plot_grid(NULL,
                       plot_grid(ggdraw() +
                                   draw_label("daily mean\ntemperature",
                                              hjust = 0.25,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily minimum\n temperature",
                                              hjust = 0.5,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily maximum\n temperature",
                                              hjust = 0.485,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(1.5, 1, 1)),
                       nrow = 1,
                       rel_widths = c(0.15, 1))

bottom_label <- ggdraw() +
  draw_label("scaled effects on daily temperatures",
             x = .625,
             size = 17,
             fontface = "bold")

(plot_meanT <- plot_grid(top_label,
                         plot_grid_meanT,
                         bottom_label,
                         nrow = 3, ncol = 1,
                         rel_heights = c(.08, 1, .05)))

save_plot("figures/microclim_offsets_figure3_TMS_HOBO_temps_hlines.png",
          plot_meanT, base_height = 14, base_asp = 1.1, dpi = 600)



### Figure 4: influences of plot characteristics on differences in mean, min and max T ----

# load model outputs
lapply(paste0("model_outputs/", list.files("model_outputs", pattern = "^model_output_dT\\d.+_50.Rdata")),
       load,
       .GlobalEnv)

# load plotting functions
source(file = file.path("scripts", "functions.R"))

# >> [a-c] canopy - soil T offsets (dT3T1) ----

# compile & save plots
mcmc_plot_list_dT3T1_50 <- lapply(model_list_mcmc_dT3T1_50, mcmc_plot_function, labels_display = "left") 

# >> [d-f] canopy - ground T offsets (dT3T2) ----
# load(file.path("scripts", "jonathan", "model_outputs", "model_output_dT3T2_50.Rdata"))

# compile & save plots
mcmc_plot_list_dT3T2_50 <- lapply(model_list_mcmc_dT3T2_50, mcmc_plot_function, labels_display = "left")

# >> [g-i] ground - soil T offsets (dT2T1) ----
# load(file.path("scripts", "jonathan", "model_outputs", "model_output_dT2T1_50.Rdata"))

# compile & save plots
mcmc_plot_list_dT2T1_50 <- lapply(model_list_mcmc_dT2T1_50, mcmc_plot_function, labels_display = "left")

# >> [j-l] air - soil T offsets -- winter (dT4hobo) ----

# compile & save plots
mcmc_plot_list_dT4hobo_ndjfm_50 <- lapply(model_list_mcmc_dT4hobo_ndjfm_50, mcmc_plot_function, labels_display = "left") 

# >> combine panels ----
(plot_grid_deltaT <- 
    plot_grid(ggdraw() +
                draw_label("\n growing season (Jun - Aug)\n",
                           colour = "grey50",
                           x = 0.625,
                           size = 15,
                           fontface = "bold"),
              plot_grid(plot_grid(ggdraw() +
                                    draw_label("soil - canopy-level",
                                               colour = theme_yellow,
                                               y = 0.6,
                                               angle = 90,
                                               size = 16,
                                               fontface = "bold"),
                                  ggdraw() +
                                    draw_image(file.path("figures", "drawings", "microclim_tms_dT3T1.png"),
                                               scale = 1,
                                               y = 0.1),
                                  nrow = 1),
                        plot_grid(plotlist = mcmc_plot_list_dT3T1_50,
                                  nrow = 1, ncol = 3,
                                  rel_widths = c(0.4, 0.3, 0.3),
                                  labels = c("(a)", "(b)", "(c)"),
                                  label_fontface = "bold",
                                  label_size = 15,
                                  hjust = c(-6.3, -1.6, -1.6),
                                  vjust = c(0, 0, 0)),
                        nrow = 1,
                        rel_widths = c(0.15, 1)),
              plot_grid(plot_grid(ggdraw() +
                                    draw_label("near-surface - canopy",
                                               colour = theme_orange,
                                               y = 0.6,
                                               angle = 90,
                                               size = 16,
                                               fontface = "bold"),
                                  ggdraw() +
                                    draw_image(file.path("figures", "drawings", "microclim_tms_dT3T2.png"),
                                               scale = 1,
                                               y = 0.1),
                                  nrow = 1),
                        plot_grid(plotlist = mcmc_plot_list_dT3T2_50,
                                  nrow = 1, ncol = 3,
                                  rel_widths = c(0.4, 0.3, 0.3),
                                  labels = c("(d)", "(e)", "(f)"),
                                  label_fontface = "bold",
                                  label_size = 15,
                                  hjust = c(-6.1, -1.7, -2.1),
                                  vjust = c(0, 0, 0)),
                        nrow = 1,
                        rel_widths = c(0.15, 1)),
              plot_grid(plot_grid(ggdraw() +
                                    draw_label("soil - near-surface",
                                               colour = theme_red,
                                               y = 0.6,
                                               angle = 90,
                                               size = 16,
                                               fontface = "bold"),
                                  ggdraw() +
                                    draw_image(file.path("figures", "drawings", "microclim_tms_dT2T1.png"),
                                               scale = 1,
                                               y = 0.1),
                                  nrow = 1),
                        plot_grid(plotlist = mcmc_plot_list_dT2T1_50,
                                  nrow = 1, ncol = 3,
                                  rel_widths = c(0.4, 0.3, 0.3),
                                  labels = c("(g)", "(h)", "(i)"),
                                  label_fontface = "bold",
                                  label_size = 15,
                                  hjust = c(-6.1, -1.6, -2.1),
                                  vjust = c(0, 0, 0)),
                        nrow = 1,
                        rel_widths = c(0.15, 1)),
              ggdraw() +
                draw_label("\n \n winter (Nov - Mar)\n",
                           colour = "grey50",
                           x = 0.625,
                           size = 15,
                           fontface = "bold"),
              plot_grid(plot_grid(ggdraw() +
                                    draw_label("soil - free-air (winter)",
                                               colour = theme_lightblue,
                                               y = 0.65,
                                               angle = 90,
                                               size = 16,
                                               fontface = "bold"),
                                  ggdraw() +
                                    draw_image(file.path("figures", "drawings", "microclim_hobo_dT4hobo_winter.png"),
                                               scale = 1,
                                               y = 0.1),
                                  nrow = 1),
                        plot_grid(plotlist = mcmc_plot_list_dT4hobo_ndjfm_50,
                                  nrow = 1, ncol = 3,
                                  rel_widths = c(0.4, 0.3, 0.3),
                                  labels = c("(j)", "(k)", "(l)"),
                                  label_fontface = "bold",
                                  label_size = 15,
                                  hjust = c(-8.2, -1.7, -2.2),
                                  vjust = c(0, 0, 0)),
                        nrow = 1,
                        rel_widths = c(0.15, 1)),
              nrow = 6,
              rel_heights = c(0.4, rep(1, 3), 0.5, 1)))

# make titles and x--axis label
top_label <- plot_grid(NULL,
                       plot_grid(ggdraw() +
                                   draw_label("daily mean\ntemperature",
                                              hjust = 0.25,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily minimum\n temperature",
                                              hjust = 0.5,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily maximum\n temperature",
                                              hjust = 0.485,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(1.5, 1, 1)),
                       nrow = 1,
                       rel_widths = c(0.15, 1))

bottom_label <- ggdraw() +
  draw_label("scaled effects on daily temperature differences",
             x = .625,
             size = 17,
             fontface = "bold")

(plot_deltaT_main <- plot_grid(top_label,
                               plot_grid_deltaT,
                               bottom_label,
                               nrow = 3, ncol = 1,
                               rel_heights = c(.08, 1, .05)))

save_plot("figures/microclim_offsets_figure4_TMS_HOBO_offsets_hlines.png",
          plot_deltaT_main, base_height = 14, base_asp = 1.1,
          dpi = 600)



### Figure 5: predictions for shrub & bryophyte cover (& potentially other predictors) ----

# load input data
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))

# load model outputs
lapply(paste0("model_outputs/", list.files("model_outputs", pattern = "*dT3T1_\\d{2,3}.Rdata")),
       load,
       .GlobalEnv)

# load plotting functions
source(file = file.path("scripts", "functions.R"))

# >> extract x intercepts for mean T offset predictions ----

x_icpt_df_50 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_50[[1]],
                                      predictor1 = "shrubs",
                                      predictor2 = "bryophytes",
                                      radius = 50)
x_icpt_df_200 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_200[[1]],
                                       predictor1 = "shrubs",
                                       predictor2 = "bryophytes",
                                       radius = 200)
x_icpt_df_564 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_564[[1]],
                                       predictor1 = "shrubs",
                                       predictor2 = "bryophytes",
                                       radius = 564)

# combine dfs
(x_icpts <- bind_rows(x_icpt_df_50,
                      x_icpt_df_200,
                      x_icpt_df_564))

# >> [a-c] dT3T1, 50 cm ----
pred_plot_list_dT3T1_50 <- lapply(model_list_mcmc_dT3T1_50, offset_predict_plot_function_combined, 
                                  predictor1 = "shrubs", predictor2 = "bryophytes", radius = 50,
                                  add_points = FALSE, add_rect = FALSE, add_R2 = TRUE, add_arrows = TRUE)

# >> [d-f] dT3T1, 200 cm ----
pred_plot_list_dT3T1_200 <- lapply(model_list_mcmc_dT3T1_200, offset_predict_plot_function_combined, 
                                   predictor1 = "shrubs", predictor2 = "bryophytes", radius = 200,
                                   add_points = FALSE, add_rect = FALSE, add_R2 = TRUE, add_arrows = TRUE) 

# >> [g-i] dT3T1, 564 cm ----
pred_plot_list_dT3T1_564 <- lapply(model_list_mcmc_dT3T1_564, offset_predict_plot_function_combined, 
                                   predictor1 = "shrubs", predictor2 = "bryophytes", radius = 564,
                                   add_points = FALSE, add_rect = FALSE, add_R2 = TRUE, add_arrows = TRUE)

# >> combine panels ----
(pred_plot_dT3T1 <- plot_grid(plot_grid(pred_plot_list_dT3T1_50[[1]] + theme(legend.position = c(.6, .9)),
                                        pred_plot_list_dT3T1_50[[2]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_50[[3]] + theme(legend.position = "none"),
                                        nrow = 1, ncol = 3,
                                        labels = c("(a)", "(b)", "(c)"),
                                        label_fontface = "bold",
                                        label_size = 17,
                                        hjust = c(-2, -2.3, -2),
                                        vjust = c(0, 0, 0),
                                        scale = .95),
                              plot_grid(pred_plot_list_dT3T1_200[[1]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_200[[2]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_200[[3]] + theme(legend.position = "none"),
                                        nrow = 1, ncol = 3,
                                        labels = c("(d)", "(e)", "(f)"),
                                        label_fontface = "bold",
                                        label_size = 17,
                                        hjust = c(-2, -2.4, -2.5),
                                        vjust = c(0, 0, 0),
                                        scale = .95),
                              plot_grid(pred_plot_list_dT3T1_564[[1]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_564[[2]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_564[[3]] + theme(legend.position = "none"),
                                        nrow = 1, ncol = 3,
                                        labels = c("(g)", "(h)", "(i)"),
                                        label_fontface = "bold",
                                        label_size = 17,
                                        hjust = c(-2, -2.4, -2.6),
                                        vjust = c(0, 0, 0),
                                        scale = .95),
                              nrow = 3, ncol = 1))


# make titles, x- and y-axis label
top_label <- plot_grid(ggdraw() +
                         draw_label("daily mean\ntemperature",
                                    hjust = 0.7,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       ggdraw() +
                         draw_label("daily minimum\n temperature ",
                                    hjust = 0.7,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       ggdraw() +
                         draw_label("daily maximum\n temperature",
                                    hjust = 0.55,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       nrow = 1, ncol = 3,
                       rel_widths = c(1.5, 1, 1))

# make x axis labels
bottom_label <- ggdraw() +
  draw_label("cover [%]",
             x = .515,
             y = .75,
             size = 22,
             fontface = "bold")

# make y-axis label
left_label <- plot_grid(ggdraw() +
                          draw_label("soil - canopy \u0394 T [°C]",
                                     colour = theme_yellow,
                                     y = 0.5,
                                     angle = 90,
                                     size = 22,
                                     fontface = "bold"),
                        plot_grid(# ggdraw() +
                                    # draw_image(file.path("figures", "drawings", "microclim_shrub_cover.png"),
                                    #            x = 0.75,
                                    #            y = -0.2,
                                    #            scale = 1.5),
                                  ggdraw() +
                                    draw_image(file.path("figures", "drawings", "microclim_tms_dT3T1.png"),
                                               x = 0.1,
                                               scale = 1.8),
                                  # ggdraw() +
                                  #   draw_image(file.path("figures", "drawings", "microclim_bryophyte_cover.png"),
                                  #              x = 0.75,
                                  #              y = 0.2,
                                  #              scale = 1.5),
                                  ncol = 1),
                        ggdraw() +
                          draw_label(" ",
                                     angle = 90),
                        nrow = 1,
                        rel_widths = c(1, 1, .8),
                        scale = .9)

right_label <- plot_grid(plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_50.png"),
                                                #x = 0.75,
                                                y = -1,
                                                scale = 0.5),
                                   ggdraw() +
                                     draw_label("\nsmall\n(r = 0.50 m)",
                                                colour = "grey45",
                                                y = 0.15,
                                                #angle = 270,
                                                size = 20,
                                                fontface = "bold"),
                                   ncol = 1),
                         plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_200.png"),
                                                #x = 0.75,
                                                y = -0.6,
                                                scale = 0.75),
                                   ggdraw() +
                                     draw_label("\nmedium\n(r = 2.00 m)",
                                                colour = "grey45",
                                                y = 0.5,
                                                #angle = 270,
                                                size = 20,
                                                fontface = "bold"),
                                   ncol = 1),
                         plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_564.png"),
                                                #x = 0.75,
                                                y = -0.1,
                                                scale = 1),
                                   ggdraw() +
                                     draw_label("\nlarge\n(r = 5.64 m)",
                                                colour = "grey45",
                                                y = 0.9,
                                                #angle = 270,
                                                size = 20,
                                                fontface = "bold"),
                                   ncol = 1),
                         ncol = 1)

# combine all
pred_plots <- plot_grid(left_label,
                        plot_grid(top_label,
                                  pred_plot_dT3T1,
                                  bottom_label,
                                  ncol = 1,
                                  rel_heights = c(.2, 1, .1)),
                        right_label,
                        nrow = 1,
                        rel_widths = c(.2, 1, .2))

save_plot("figures/microclim_offsets_figure5_shrub_bryo_scales_LINES_R2_arrows.png",
          pred_plots, base_height = 11, base_asp = 1.6,
          dpi = 600)
  

# Figure 6: dT3T1 vs kNDVI ----

# load input data
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))

disko_data_season19_greenness <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_greenness_season19.csv"))

# load model outputs
load(file.path("model_outputs", "model_output_dT3T1_kndvi.Rdata"))

# load plotting functions
source(file = file.path("scripts", "functions.R"))

pred_plot_list_dT3T1_kndvi <- lapply(model_list_mcmc_dT3T1_564_kndvi, offset_predict_plot_function_separate, 
                                     predictor = "kndvi", 
                                     add_points = TRUE)

# >> combine panels ----
pred_plot_dT3T1_kndvi <- plot_grid(pred_plot_list_dT3T1_kndvi[[1]] + theme(legend.position = "none"),
                                   pred_plot_list_dT3T1_kndvi[[2]] + theme(legend.position = "none"),
                                   pred_plot_list_dT3T1_kndvi[[3]] + theme(legend.position = "none"),
                                   nrow = 1, ncol = 3,
                                   labels = c("(a)", "(b)", "(c)"),
                                   label_fontface = "bold",
                                   label_size = 17,
                                   hjust = c(-2.4, -2.3, -2.4),
                                   vjust = c(0, 0, 0),
                                   scale = .95)


# make titles, x- and y-axis label
top_label <- plot_grid(ggdraw() +
                         draw_label("daily mean\ntemperature",
                                    hjust = 0.7,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       ggdraw() +
                         draw_label("daily minimum\n temperature ",
                                    hjust = 0.7,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       ggdraw() +
                         draw_label("daily maximum\n temperature",
                                    hjust = 0.55,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       nrow = 1, ncol = 3,
                       rel_widths = c(1.5, 1, 1))

# make x axis labels
bottom_label <- ggdraw() +
  draw_label("kernel NDVI",
             x = .515,
             y = .5,
             size = 22,
             fontface = "bold")

# make y-axis label
left_label <- plot_grid(ggdraw() +
                          draw_label("soil - canopy \u0394 T [°C]",
                                     colour = theme_yellow,
                                     y = 0.5,
                                     angle = 90,
                                     size = 20,
                                     fontface = "bold"),
                        plot_grid(ggdraw() +
                                    draw_image(file.path("figures", "drawings", "microclim_tms_dT3T1.png"),
                                               x = 0.1,
                                               scale = 1.8),
                                  ncol = 1),
                        ggdraw() +
                          draw_label(" ",
                                     angle = 90),
                        nrow = 1,
                        rel_widths = c(1, 1, .8),
                        scale = .9)

right_label <- plot_grid(ggdraw() +
                           draw_image(file.path("figures", "drawings", "microclim_ndvi_scales.png"),
                                      #x = 0.75,
                                      y = -0.3,
                                      scale = 1.2),
                         ggdraw() +
                           draw_label(expression(a == 10*m),
                                      colour = "grey45",
                                      x = 0.4,
                                      y = 0.5,
                                      #angle = 270,
                                      size = 22,
                                      fontface = "bold"),
                         ncol = 1)

# combine all
pred_plots_kndvi <- plot_grid(left_label,
                              plot_grid(top_label,
                                        pred_plot_dT3T1_kndvi,
                                        bottom_label,
                                        ncol = 1,
                                        rel_heights = c(.35, 1, .1)),
                              right_label,
                              nrow = 1,
                              rel_widths = c(.2, 1, .2))

save_plot("figures/microclim_offsets_figure6_kndvi_dT3T1.png",
          pred_plots_kndvi, base_height = 4, base_asp = 4,
          dpi = 600)



#__________________________________________________________________________________________________________________ 
#________________________________----
# SUPPLEMENTARY FIGURES ----
# _______________________________----

### Figure S1: average vegetation heights vs. TMS logger ----

# load input data
disko_plotdata_complete <- read.csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete.csv"),
                                    header = TRUE)

# extract veg height data columns
veg_height_data <- disko_plotdata_complete %>% 
  
  select(plot_id,
         contains("height_avg"),
         starts_with("veg_height"),
         -ends_with("hobo")) %>% 
  
  # pivot to long format
  pivot_longer(cols = -plot_id,
               names_to = "scale",
               names_prefix = "veg_height_",
               values_to = "veg_height") %>% 
  
  # tidy scale level names
  mutate(scale = as_factor(scale),
         scale = fct_recode(scale, 
                            "TMS-4 logger\nshield height" = "tms_shield_height_avg",
                            "average\nat logger" = "avg_tms",
                            "maximum\nat logger" = "max_tms",
                            "average\nr = 10 cm" = "avg_10",
                            "average\n(small circle)" = "avg_50",
                            "average\n(medium circle)" = "avg_200",
                            "average\n(large circle)" = "avg_564"))


# load TMS drawing
tms_logger <- png::readPNG(file.path("figures", "drawings", "tms_logger.png"))

# build plot (if including 10 cm circles, raise all xmax/xend by 1)
(veg_height_plot <- ggplot(data = veg_height_data,
                           aes(x = scale,
                               y = veg_height,
                               fill = scale)) +
    
    # add horizontal lines and annotations for sensor positions
    # canopy-level
    geom_segment(x = 0.5, xend = 6.5,
                 y = 15, yend = 15, 
                 colour = "lightgrey",
                 linetype = "dashed",
                 size = 1.5) +
    annotate("text", 
             label = "canopy-level\n(+ 15 cm)",
             colour = theme_violet,
             size = 6,
             fontface = "bold",
             x = 6.85, y = 15.1) +
    # near-surface
    geom_segment(x = 0.5, xend = 6.5,
                 y = 2, yend = 2, 
                 colour = "lightgrey",
                 linetype = "dashed",
                 size = 1.5) +
    annotate("text", 
             label = "near-surface\n(+ 2 cm)",
             colour = theme_green,
             size = 6,
             fontface = "bold",
             x = 6.85, y = 2.2) +
    
    # add TMS drawing
    annotation_raster(tms_logger, 
                      xmin =-.7, xmax = 0.7,
                      ymin = -9, ymax = 17) +
    
    # add violins
    geom_sina(aes(colour = scale),
                #width = 1,
                alpha = 0.7,
                size = 2.5) +
    
    # fix colours
    scale_fill_manual(values = c("darkgrey", rep(theme_darkgreen, 6))) +
    scale_colour_manual(values = c("grey30", rep(theme_darkgreen, 6))) +
    
    # fix order on x axis
    scale_x_discrete(limits = c("TMS-4 logger\nshield height",
                                "average\nat logger",
                                "maximum\nat logger",
                                #"average\nr = 10 cm",
                                "average\n(small circle)",
                                "average\n(medium circle)",
                                "average\n(large circle)")) +
    
    # adjust axis labels
    labs(x = "\nvegetation height parameter",
         y = "height above surface level [cm]\n") +
    
    # appearance
    theme_cowplot(20) +
    
    coord_cartesian(xlim = c(-0.8, 7),
                    ylim = c(0, max(veg_height_data$veg_height + 1)),
                    expand = c(0, 0),
                    clip = "off") +
    
    theme(legend.position = "none",
          axis.text.x = element_text(size = 15),
          axis.title.x = element_text(hjust = 0.68,
                                      face = "bold"),
          axis.title.y = element_text(face = "bold"),
          plot.margin = margin(t = 1, r = 3, b = 6.5, l = 1, unit = "lines")))

save_plot(file.path("figures", "microclim_offsets_figureS1_vegheights_logger_comparison.png"),
          veg_height_plot,
          base_height = 9, 
          #base_asp = 1.5, # if including r = 10 cm
          base_asp = 1.4)



### Figure S2: cover value histograms ----

# prepare data
cover_groups <- c("shrubs", "forbs", "gramin", "bryophytes", "lichen", "rocks", "bare", "litter")
cover_vars <- c(paste0("cov_", cover_groups, "_50"))

hist_df_list_cov <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete.csv")) %>% 
  
  select(plot_id,
         all_of(cover_vars)) %>% 
  
  pivot_longer(cols = all_of(cover_vars),
               names_to = "group",
               values_to = "cover_value") %>% 
  
  mutate(group = factor(str_extract(group, "(?<=_)\\w*(?=_)"),
                         levels = cover_groups),
         group = forcats::fct_recode(group,
                                      "graminoids" = "gramin",
                                      "bare ground" = "bare")) %>% 
  
  group_by(group) %>% group_split()

hist_cov <- lapply(hist_df_list_cov, function(dat){
  group <- unique(dat$group)
  
  ggplot(dat) +
    geom_histogram(aes(x = cover_value),
                   colour = "grey15",
                   fill = "grey85",
                   size = 1) +
    guides(colour = "none",
           fill = "none") +
    theme_cowplot(16) +
    labs(x = "",
         y = "",
         title = group) +
    lims(x = c(0, 100))
})

hist_grid_cov <- plot_grid(plotlist = hist_cov,
                           align = "hv",
                           axis = "lb",
                           ncol = 2)

left_label <- ggdraw() +
  draw_label("count",
             y = .55,
             size = 18,
             fontface = "bold",
             angle = 90)

bottom_label <- ggdraw() +
  draw_label("cover [%]",
             x = .525,
             size = 18,
             fontface = "bold")

cov_hist_full <- plot_grid(left_label,
                            plot_grid(hist_grid_cov,
                                      bottom_label,
                                      rel_heights = c(1, 0.05),
                                      ncol = 1),
                            nrow = 1, ncol = 2,
                            rel_widths = c(.05, 1))

save_plot("figures/microclim_offsets_figureS2_cover_hist.png",
          cov_hist_full, base_height = 14, base_asp = 1)


### Figure S3: compare HOBO and TMS T1 sensors ----

# growing season 2019
disko_soiltemp_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv")) %>% 
  
  select(plot_id, date,
         starts_with("tms_T1_m"),
         starts_with("hobo_temp"))

soiltemp_comparison_lm_summary <- c("mean", "min", "max") %>% 
  
  purrr::map(~ disko_soiltemp_season19 %>% select(plot_id, date, ends_with(.x))) %>% 
  
  purrr::map(rename_at, 3, ~"tms") %>% 
  purrr::map(rename_at, 4, ~"hobo") %>% 
  
  purrr::map(~ lme4::lmer(hobo ~ tms + (1|plot_id), data = .x)) %>% 
  purrr::map(summary)

# make figure

soiltemp_gs_comp_plot <- ggplot(disko_soiltemp_season19, 
                                aes(x = tms_T1_mean, 
                                    y = hobo_temp_mean)) + 
  geom_point(pch = 21, 
             fill = "grey85", 
             colour = "grey20",
             alpha = .6) + 
  geom_abline(intercept = 0, 
              slope = 1, 
              size = 1.25,
              linetype = "dashed", 
              colour = "grey30") + 
  geom_abline(intercept = soiltemp_comparison_lm_summary[[1]]$coefficients["(Intercept)", "Estimate"], 
              slope = soiltemp_comparison_lm_summary[[1]]$coefficients["tms", "Estimate"], 
              size = 1.25,
              colour = theme_brown) + 
  labs(x = "daily mean soil temperature (TMS T1) [°C]",
       y = "daily mean soil temperature (HOBO) [°C]") +
  lims(y = c(min(disko_soiltemp_season19$hobo_temp_mean, na.rm = TRUE),
             max(disko_soiltemp_season19$hobo_temp_mean, na.rm = TRUE))) +
  annotate("text", 
           label = bquote("T"["mean (HOBO)"] == .(round(soiltemp_comparison_lm_summary[[1]]$coefficients["tms", "Estimate"], 3))~"*"~"T"["mean (TMS)"]~-~.(round(abs(soiltemp_comparison_lm_summary[[1]]$coefficients["(Intercept)", "Estimate"]), 3))),
           x = 13, y = 2.5) +
  theme_classic()

# save
save_plot(filename = file.path("figures", "microclim_offsets_figureS3_gs_soilT_comparison.png"),
          soiltemp_gs_comp_plot,
          base_height = 5,
          base_asp = 1)


### Figure S4: weather station correlations maps ----

# load map data
disko_coast <- st_read(dsn = "data/geo_features", 
                       layer = "disko_inverse_coastline") %>% vect()

# load ArcticDEM 
arctic_dem_disko <- rast("I:/C_Write/_Proj/Greenland_NormandVegDyn_au150176/Disko/2019/ArcticDEM/tiles/18_37_2_2_2m_v3.0/18_37_2_2_2m_v3.0_reg_dem.tif") %>% 
  
  # crop for study area
  terra::crop(ext(-338000, -331400, -2247000, -2240000)) %>% 
  
  # convert to long/lat
  project(y = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs") 

# mask ocean area
arctic_dem_disko_land_rast <- arctic_dem_disko %>% 
  mask(disko_coast, inverse = TRUE)

# convert to df
arctic_dem_disko_land <- arctic_dem_disko_land_rast %>% 
  
  terra::as.data.frame(xy = TRUE) %>% 
  
  rename(elev = "18_37_2_2_2m_v3.0_reg_dem") %>% 
  
  mutate(elev_band = case_when(elev < 160 ~ "1",
                               elev %in% c(161:320) ~ "2",
                               elev %in% c(321:480) ~ "3",
                               elev %in% c(481:640) ~ "4",
                               elev > 640 ~ "5",
                               TRUE ~ NA_character_))

# get contour lines
disko_elev_bands_major <- arctic_dem_disko_land_rast %>% 
  #cut() %>% 
  as.contour(levels = seq(160, 640, 160)) %>% 
  st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.25, ymax = 69.297))
disko_elev_bands_minor <- arctic_dem_disko_land_rast %>% 
  #cut() %>% 
  as.contour(levels = seq(0, 840, 20)) %>% 
  st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.25, ymax = 69.297))

# load hydrology features (digitised through mymaps.google.com)

# morænesø in/outflow
moraeneso_in_out <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/moraeneso_in_out.kml", 
                            layer = "moraeneso_in_out", 
                            require_geomType = "wkbLineString") %>% st_as_sf()

# morænesø lake area
moraeneso <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/moraeneso_lake.kml", 
                     layer = "moraeneso_lake", 
                     require_geomType = "wkbPolygon") %>% st_as_sf()

# Røde Elv - main channels
rode_elv_main <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/rode_elv_main.kml", 
                         layer = "rode_elv_main", 
                         require_geomType = "wkbLineString") %>% st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.25, ymax = 69.297))

# Røde Elv - side channels
rode_elv_braids <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/rode_elv_braids.kml", 
                           layer = "rode_elv_braids", 
                           require_geomType = "wkbLineString") %>% st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.25, ymax = 69.297))

# Lyngmarksfjeld rivers
lyngmark_rivers_1 <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmarks_baek.kml", 
                             layer = "lyngmarks_baek", 
                             require_geomType = "wkbLineString") %>% 
  st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.25, ymax = 69.297))

lyngmark_rivers_2 <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmarks_baek2.kml", 
                             layer = "lyngmarks_baek2", 
                             require_geomType = "wkbLineString") %>% st_as_sf()

lyngmark_rivers_3 <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmarks_baek3.kml", 
                             layer = "lyngmarks_baek3", 
                             require_geomType = "wkbLineString") %>% st_as_sf()

lyngmark_rivers_4 <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmarks_baek4.kml", 
                             layer = "lyngmarks_baek4", 
                             require_geomType = "wkbLineString") %>% st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.25, ymax = 69.297))

# Lyngmarksfjeld lakes
lyngmark_lakes <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/lyngmark_lakes.kml", 
                          layer = "lyngmark_lakes", 
                          require_geomType = "wkbPolygon") %>% st_as_sf() %>% 
  st_crop(y = c(xmin = -53.56, xmax = -53.41, ymin = 69.25, ymax = 69.297))

# Skarvefjeld rivers
skarvefjeld_rivers <- readOGR(dsn = "data/geo_features/disko_hydrology_jvo/skarvefjeld_baek.kml", 
                              layer = "skarvefjeld_baek", 
                              require_geomType = "wkbLineString") %>% st_as_sf()

# load plot coordinates
logger_locations <- read_csv(file.path("data", "location_data", "LDI_locations.csv")) %>% 
  
  select(plot_id = PlotID,
         long = Longitude, lat = Latitude) %>% 
  
  st_as_sf(coords = c("long", "lat"),
           crs = 4326) %>% 
  
  filter(plot_id %in% c(paste0("LDI_00", 1:9),
                        paste0("LDI_0", 10:90)))

# load weather station locations 
# available at Greenland Ecosystem Monitoring, https://g-e-m.dk/
station_coord <- read_csv("data/location_data/station_locations.csv") %>% 
  
  filter(!station_id %in% c("AWS2", "T4")) %>% 
  
  mutate(station_id = fct_relevel(station_id,
                                  c(paste0("T", 1:3),
                                    paste0("AWS", 3:4))),
         station_id = fct_recode(station_id,
                                 "GeoBasis_T1" = "T1",
                                 "GeoBasis_T2" = "T2",
                                 "GeoBasis_T3" = "T3",
                                 # "GeoBasis_T4" = "T4",  # removed - not the closest station for any plot
                                 "GeoBasis_AWS3" = "AWS3",
                                 "GeoBasis_AWS4" = "AWS4"))

# load corresponding station data
plot_station_elevation_diffs <- read_rds(file.path("data", "plot_data", "processed", "disko_microclim_plot_station_elevation_differences.rds")) %>% 
  
  select(plot_id,
         min_diff_station,
         min_elev_diff) %>% 
  # add plot_locations
  left_join(logger_locations, by = "plot_id") %>% 
  # adjust station labels
  mutate(min_diff_station = factor(min_diff_station),
         min_diff_station = fct_recode(min_diff_station,
                                       "GeoBasis_T1" = "T1",
                                       "GeoBasis_T2" = "T2",
                                       "GeoBasis_T3" = "T3",
                                       # "GeoBasis_T4" = "T4",  # removed - not the closest station for any plot
                                       # "GeoBasis_AWS2" = "AWS2",  # removed - no record
                                       "GeoBasis_AWS3" = "AWS3",
                                       "GeoBasis_AWS4" = "AWS4"),
         min_diff_station = fct_relevel(min_diff_station,
                                        paste0("GeoBasis_",
                                               c(paste0("T", 1:3),
                                                 paste0("AWS", 3:4)))))

# >> base map ----
elev_map <- ggplot() +
  
  # plot elevation raster
  geom_raster(data = arctic_dem_disko_land,
              aes(x = x,
                  y = y,
                  fill = elev)) +
  scale_fill_gradientn(colours = terrain.colors(10),
                       guide = "none") +
  new_scale_fill() +
  
  # plot contour lines
  geom_sf(data = disko_elev_bands_minor,
            colour = "grey65",
            size = 0.25) +
  geom_sf(data = disko_elev_bands_major,
            colour = "grey25",
            size = 0.25) +
  
  # plot lake in/outflow
  geom_sf(data = moraeneso_in_out,
          colour = "#2F91D0") +
  
  # plot morænesø lake
  geom_sf(data = moraeneso,
          colour = NA,
          fill = "#2F91D0") +
  
  # plot main river
  geom_sf(data = rode_elv_main,
          colour = "#2F91D0",
          size = 1) +
  
  # plot main river braids
  geom_sf(data = rode_elv_braids,
          colour = "#2F91D0",
          size = 0.5) +
  
  # plot slope rivers
  geom_sf(data = skarvefjeld_rivers,
          colour = "#2F91D0") +
  geom_sf(data = lyngmark_rivers_1,
          colour = "#2F91D0") +
  geom_sf(data = lyngmark_rivers_2,
          colour = "#2F91D0") +
  geom_sf(data = lyngmark_rivers_3,
          colour = "#2F91D0") +
  geom_sf(data = lyngmark_rivers_4,
          colour = "#2F91D0") +
  
  # plot Lyngmark lakes
  geom_sf(data = lyngmark_lakes,
          colour = NA,
          fill = "#2F91D0") +
  
  # add station locations
  geom_point(data = station_coord,
             aes(x = long,
                 y = lat,
                 fill = station_id),
             colour = "grey15",
             shape = 25,
             size = 4) +
  scale_fill_manual(values = c(theme_yellow, theme_darkblue, theme_grey, theme_orange, theme_forestgreen),
                    name = "nearest\nweather station\nfor air temperature\ncomparison") +
  
  # set axes ranges
  xlim(-53.56, -53.41) +
  ylim(69.25, 69.297) +
  
  # blank theme
  theme_map()

# >> elevation difference map ----
plot_station_elevation_diff_map <- elev_map +
  
  # add plot locations
  geom_sf(data = plot_station_elevation_diffs,
          aes(geometry = geometry,
              fill = min_diff_station),
          colour = "grey15",
          size = 4,
          shape = 21) + 
  #ggtitle("a) air vs. canopy (growing season)") +
  theme(panel.border = element_rect(fill = NA,
                                    size = 1))

# add scalebar & north arrow
plot_station_elevation_diff_map_scale <- plot_station_elevation_diff_map +         
  annotation_scale(location = "br",
                   bar_cols = c("grey15", "white"),
                   pad_x = unit(1.2, "cm"),
                   pad_y = unit(0.8, "cm"),
  ) +
  
  annotation_north_arrow(style = north_arrow_orienteering,
                         location = "br",
                         pad_x = unit(1, "cm"),
                         pad_y = unit(2, "cm"))

save_plot("figures/microclim_offsets_figureS4_closest_stations.png",
          plot_station_elevation_diff_map_scale, base_height = 11, base_asp = 1.2)



### Figure S5: offsets with free-air temp during growing season ----

# load model outputs
lapply(paste0("model_outputs/", list.files("model_outputs", pattern = "*dT4T\\d_50.Rdata")),
       load,
       .GlobalEnv)

# load plotting functions
source(file = file.path("scripts", "functions.R"))

# >> [a-c] air - canopy T offsets (dT4T3) ----

# compile & save plots
mcmc_plot_list_dT4T3_50 <- lapply(model_list_mcmc_dT4T3_50, mcmc_plot_function, labels_display = "left") 

# >> [d-f] air - soil T offsets -- summer (dT4T1) ----

# compile & save plots
mcmc_plot_list_dT4T1_50 <- lapply(model_list_mcmc_dT4T1_50, mcmc_plot_function, labels_display = "left") 

# >> combine panels ----
(plot_grid_deltaT_air <- 
   plot_grid(ggdraw() +
               draw_label("\n growing season (Jun - Aug)\n",
                          colour = "grey50",
                          x = 0.625,
                          size = 15,
                          fontface = "bold"),
             plot_grid(plot_grid(ggdraw() +
                                   draw_label("canopy - free-air",
                                              colour = theme_purple,
                                              y = 0.6,
                                              angle = 90,
                                              size = 16,
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_image(file.path("figures", "drawings", "microclim_tms_dT4T3.png"),
                                              scale = 1,
                                              y = 0.1),
                                 nrow = 1),
                       plot_grid(plotlist = mcmc_plot_list_dT4T3_50,
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(0.4, 0.3, 0.3),
                                 labels = c("(a)", "(b)", "(c)"),
                                 label_fontface = "bold",
                                 label_size = 15,
                                 hjust = c(-6.3, -1.6, -1.6),
                                 vjust = c(0, 0, 0)),
                       nrow = 1,
                       rel_widths = c(0.15, 1)),
             plot_grid(plot_grid(ggdraw() +
                                   draw_label("soil (summer) - free-air",
                                              colour = theme_darkblue,
                                              y = 0.6,
                                              angle = 90,
                                              size = 16,
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_image(file.path("figures", "drawings", "microclim_tms_dT4T1.png"),
                                              scale = 1,
                                              y = 0.1),
                                 nrow = 1),
                       plot_grid(plotlist = mcmc_plot_list_dT4T1_50,
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(0.4, 0.3, 0.3),
                                 labels = c("(d)", "(e)", "(f)"),
                                 label_fontface = "bold",
                                 label_size = 15,
                                 hjust = c(-6.1, -1.7, -2.1),
                                 vjust = c(0, 0, 0)),
                       nrow = 1,
                       rel_widths = c(0.15, 1)),
             nrow = 3,
             rel_heights = c(0.4, 1, 1)))

# make titles and x--axis label
top_label <- plot_grid(NULL,
                       plot_grid(ggdraw() +
                                   draw_label("daily mean\ntemperature",
                                              hjust = 0.25,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily minimum\n temperature",
                                              hjust = 0.5,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily maximum\n temperature",
                                              hjust = 0.485,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(1.5, 1, 1)),
                       nrow = 1,
                       rel_widths = c(0.15, 1))

bottom_label <- ggdraw() +
  draw_label("scaled effects on daily temperature differences",
             x = .625,
             size = 17,
             fontface = "bold")

(plot_deltaT_air <- plot_grid(top_label,
                              plot_grid_deltaT_air,
                              bottom_label,
                              nrow = 3, ncol = 1,
                              rel_heights = c(.08, 1, .05)))

save_plot("figures/microclim_offsets_figureS5_station_offsets.png",
          plot_deltaT_air, base_height = 7, base_asp = 2,
          dpi = 600)



### Figure S6: predictions for shrub & bryophyte cover (incl data points) ----

# load input data
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))

# load model outputs
lapply(paste0("model_outputs/", list.files("model_outputs", pattern = "*dT3T1_\\d{2,3}.Rdata")),
       load,
       .GlobalEnv)

# load plotting functions
source(file = file.path("scripts", "functions.R"))

# >> extract x intercepts for mean T offset predictions ----

x_icpt_df_50 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_50[[1]],
                                      predictor1 = "shrubs",
                                      predictor2 = "bryophytes",
                                      radius = 50)
x_icpt_df_200 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_200[[1]],
                                       predictor1 = "shrubs",
                                       predictor2 = "bryophytes",
                                       radius = 200)
x_icpt_df_564 <- offset_predict_x_icpt(model_list_mcmc_dT3T1_564[[1]],
                                       predictor1 = "shrubs",
                                       predictor2 = "bryophytes",
                                       radius = 564)

# combine dfs
(x_icpts <- bind_rows(x_icpt_df_50,
                      x_icpt_df_200,
                      x_icpt_df_564))

# >> [a-c] dT3T1, 50 cm ----
pred_plot_list_dT3T1_50 <- lapply(model_list_mcmc_dT3T1_50, offset_predict_plot_function_combined, 
                                  predictor1 = "shrubs", predictor2 = "bryophytes", radius = 50,
                                  add_points = TRUE, add_rect = FALSE, add_arrows = TRUE)

# >> [d-f] dT3T1, 200 cm ----
pred_plot_list_dT3T1_200 <- lapply(model_list_mcmc_dT3T1_200, offset_predict_plot_function_combined, 
                                   predictor1 = "shrubs", predictor2 = "bryophytes", radius = 200,
                                   add_points = TRUE, add_rect = FALSE, add_arrows = TRUE) 

# >> [g-i] dT3T1, 564 cm ----
pred_plot_list_dT3T1_564 <- lapply(model_list_mcmc_dT3T1_564, offset_predict_plot_function_combined, 
                                   predictor1 = "shrubs", predictor2 = "bryophytes", radius = 564,
                                   add_points = TRUE, add_rect = FALSE, add_arrows = TRUE)

# >> combine panels ----
(pred_plot_dT3T1 <- plot_grid(plot_grid(pred_plot_list_dT3T1_50[[1]] + theme(legend.position = c(.6, 1.1)),
                                        pred_plot_list_dT3T1_50[[2]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_50[[3]] + theme(legend.position = "none"),
                                        nrow = 1, ncol = 3,
                                        labels = c("(a)", "(b)", "(c)"),
                                        label_fontface = "bold",
                                        label_size = 17,
                                        hjust = c(-2, -2.3, -2),
                                        vjust = c(0, 0, 0),
                                        scale = .95),
                              plot_grid(pred_plot_list_dT3T1_200[[1]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_200[[2]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_200[[3]] + theme(legend.position = "none"),
                                        nrow = 1, ncol = 3,
                                        labels = c("(d)", "(e)", "(f)"),
                                        label_fontface = "bold",
                                        label_size = 17,
                                        hjust = c(-2, -2.4, -2.5),
                                        vjust = c(0, 0, 0),
                                        scale = .95),
                              plot_grid(pred_plot_list_dT3T1_564[[1]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_564[[2]] + theme(legend.position = "none"),
                                        pred_plot_list_dT3T1_564[[3]] + theme(legend.position = "none"),
                                        nrow = 1, ncol = 3,
                                        labels = c("(g)", "(h)", "(i)"),
                                        label_fontface = "bold",
                                        label_size = 17,
                                        hjust = c(-2, -2.4, -2.6),
                                        vjust = c(0, 0, 0),
                                        scale = .95),
                              nrow = 3, ncol = 1))


# make titles, x- and y-axis label
top_label <- plot_grid(ggdraw() +
                         draw_label("daily mean\ntemperature",
                                    hjust = 0.7,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       ggdraw() +
                         draw_label("daily minimum\n temperature ",
                                    hjust = 0.7,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       ggdraw() +
                         draw_label("daily maximum\n temperature",
                                    hjust = 0.55,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       nrow = 1, ncol = 3,
                       rel_widths = c(1.5, 1, 1))

# make x axis labels
bottom_label <- ggdraw() +
  draw_label("cover [%]",
             x = .515,
             y = .75,
             size = 22,
             fontface = "bold")

# make y-axis label
left_label <- plot_grid(ggdraw() +
                          draw_label("soil - canopy \u0394 T [°C]",
                                     colour = theme_yellow,
                                     y = 0.5,
                                     angle = 90,
                                     size = 22,
                                     fontface = "bold"),
                        plot_grid(# ggdraw() +
                          # draw_image(file.path("figures", "drawings", "microclim_shrub_cover.png"),
                          #            x = 0.75,
                          #            y = -0.2,
                          #            scale = 1.5),
                          ggdraw() +
                            draw_image(file.path("figures", "drawings", "microclim_tms_dT3T1.png"),
                                       x = 0.1,
                                       scale = 1.8),
                          # ggdraw() +
                          #   draw_image(file.path("figures", "drawings", "microclim_bryophyte_cover.png"),
                          #              x = 0.75,
                          #              y = 0.2,
                          #              scale = 1.5),
                          ncol = 1),
                        ggdraw() +
                          draw_label(" ",
                                     angle = 90),
                        nrow = 1,
                        rel_widths = c(1, 1, .8),
                        scale = .9)

right_label <- plot_grid(plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_50.png"),
                                                #x = 0.75,
                                                y = -1,
                                                scale = 0.5),
                                   ggdraw() +
                                     draw_label("\nsmall\n(r = 0.50 m)",
                                                colour = "grey25",
                                                y = 0.15,
                                                #angle = 270,
                                                size = 20,
                                                fontface = "bold"),
                                   ncol = 1),
                         plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_200.png"),
                                                #x = 0.75,
                                                y = -0.6,
                                                scale = 0.75),
                                   ggdraw() +
                                     draw_label("\nmedium\n(r = 2.00 m)",
                                                colour = "grey25",
                                                y = 0.5,
                                                #angle = 270,
                                                size = 20,
                                                fontface = "bold"),
                                   ncol = 1),
                         plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_564.png"),
                                                #x = 0.75,
                                                y = -0.1,
                                                scale = 1),
                                   ggdraw() +
                                     draw_label("\nlarge\n(r = 5.64 m)",
                                                colour = "grey25",
                                                y = 0.9,
                                                #angle = 270,
                                                size = 20,
                                                fontface = "bold"),
                                   ncol = 1),
                         ncol = 1)

# combine all
pred_plots <- plot_grid(left_label,
                        plot_grid(top_label,
                                  pred_plot_dT3T1,
                                  bottom_label,
                                  ncol = 1,
                                  rel_heights = c(.2, 1, .1)),
                        right_label,
                        nrow = 1,
                        rel_widths = c(.2, 1, .2))

save_plot("figures/microclim_offsets_figureS6_shrub_bryo_scales_POINTS_arrows.png",
          pred_plots, 
          base_height = 11, base_asp = 1.6,
          dpi = 600)



# Figure S7: growing season predictions for vegetation height across circle sizes ----

# load input data
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))

# load model outputs
lapply(paste0("model_outputs/", list.files("model_outputs", pattern = "*dT3T1_\\d{2,3}.Rdata")),
       load,
       .GlobalEnv)

# load plotting functions
source(file = file.path("scripts", "functions.R"))

# >> [a-c] dT3T1, 50 cm ----
pred_plot_list_dT3T1_veght_50 <- lapply(model_list_mcmc_dT3T1_50, offset_predict_plot_function_separate, 
                                        predictor = "veg_height", radius = 50,
                                        add_points = TRUE)

# >> [d-f] dT3T1, 200 cm ----
pred_plot_list_dT3T1_veght_200 <- lapply(model_list_mcmc_dT3T1_200, offset_predict_plot_function_separate, 
                                         predictor = "veg_height", radius = 200,
                                         add_points = TRUE)

# >> [g-i] dT3T1, 564 cm ----
pred_plot_list_dT3T1_veght_564 <- lapply(model_list_mcmc_dT3T1_564, offset_predict_plot_function_separate, 
                                         predictor = "veg_height", radius = 564,
                                         add_points = TRUE)

# >> combine panels ----
(pred_plot_dT3T1_veght <- plot_grid(plot_grid(pred_plot_list_dT3T1_veght_50[[1]] + theme(legend.position = "none"),
                                              pred_plot_list_dT3T1_veght_50[[2]] + theme(legend.position = "none"),
                                              pred_plot_list_dT3T1_veght_50[[3]] + theme(legend.position = "none"),
                                              nrow = 1, ncol = 3,
                                              labels = c("(a)", "(b)", "(c)"),
                                              label_fontface = "bold",
                                              label_size = 17,
                                              hjust = c(-2.4, -2.3, -2.4),
                                              vjust = c(0, 0, 0),
                                              scale = .95),
                                    plot_grid(pred_plot_list_dT3T1_veght_200[[1]] + theme(legend.position = "none"),
                                              pred_plot_list_dT3T1_veght_200[[2]] + theme(legend.position = "none"),
                                              pred_plot_list_dT3T1_veght_200[[3]] + theme(legend.position = "none"),
                                              nrow = 1, ncol = 3,
                                              labels = c("(d)", "(e)", "(f)"),
                                              label_fontface = "bold",
                                              label_size = 17,
                                              hjust = c(-2.3, -2.4, -3),
                                              vjust = c(0, 0, 0),
                                              scale = .95),
                                    plot_grid(pred_plot_list_dT3T1_veght_564[[1]] + theme(legend.position = "none"),
                                              pred_plot_list_dT3T1_veght_564[[2]] + theme(legend.position = "none"),
                                              pred_plot_list_dT3T1_veght_564[[3]] + theme(legend.position = "none"),
                                              nrow = 1, ncol = 3,
                                              labels = c("(g)", "(h)", "(i)"),
                                              label_fontface = "bold",
                                              label_size = 17,
                                              hjust = c(-2.3, -2.4, -3.1),
                                              vjust = c(0, 0, 0),
                                              scale = .95),
                                    nrow = 3, ncol = 1))


# make titles, x- and y-axis label
top_label <- plot_grid(ggdraw() +
                         draw_label("mean daily\ntemperature",
                                    hjust = 0.7,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       ggdraw() +
                         draw_label("daily minimum\n temperature ",
                                    hjust = 0.7,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       ggdraw() +
                         draw_label("daily maximum\n temperature",
                                    hjust = 0.55,
                                    vjust = 0.1,
                                    size = 20,
                                    colour = "grey25",
                                    fontface = "bold"),
                       nrow = 1, ncol = 3,
                       rel_widths = c(1.5, 1, 1))

# make x axis labels
bottom_label <- ggdraw() +
  draw_label("average vegetation height [cm]",
             x = .515,
             y = .5,
             size = 22,
             fontface = "bold")

# make y-axis label
left_label <- plot_grid(ggdraw() +
                          draw_label("soil - canopy T offset [°C]",
                                     colour = theme_yellow,
                                     y = 0.5,
                                     angle = 90,
                                     size = 22,
                                     fontface = "bold"),
                        plot_grid(ggdraw() +
                                    draw_image(file.path("figures", "drawings", "microclim_tms_dT3T1.png"),
                                               x = 0.1,
                                               scale = 1.8),
                                  ncol = 1),
                        ggdraw() +
                          draw_label(" ",
                                     angle = 90),
                        nrow = 1,
                        rel_widths = c(1, 1, .8),
                        scale = .9)

right_label <- plot_grid(plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_50.png"),
                                                #x = 0.75,
                                                y = -1,
                                                scale = 0.5),
                                   ggdraw() +
                                     draw_label("r = 0.50m",
                                                colour = "grey45",
                                                y = 0.15,
                                                #angle = 270,
                                                size = 22,
                                                fontface = "bold"),
                                   ncol = 1),
                         plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_200.png"),
                                                #x = 0.75,
                                                y = -0.6,
                                                scale = 0.75),
                                   ggdraw() +
                                     draw_label("r = 2.00m",
                                                colour = "grey45",
                                                y = 0.5,
                                                #angle = 270,
                                                size = 22,
                                                fontface = "bold"),
                                   ncol = 1),
                         plot_grid(ggdraw() +
                                     draw_image(file.path("figures", "drawings", "microclim_circle_564.png"),
                                                #x = 0.75,
                                                y = -0.1,
                                                scale = 1),
                                   ggdraw() +
                                     draw_label("r = 5.64m",
                                                colour = "grey45",
                                                y = 0.9,
                                                #angle = 270,
                                                size = 22,
                                                fontface = "bold"),
                                   ncol = 1),
                         ncol = 1)

# combine all
pred_plots_veght <- plot_grid(left_label,
                              plot_grid(top_label,
                                        pred_plot_dT3T1_veght,
                                        bottom_label,
                                        ncol = 1,
                                        rel_heights = c(.2, 1, .1)),
                              right_label,
                              nrow = 1,
                              rel_widths = c(.2, 1, .2))

save_plot("figures/microclim_offsets_figureS7_veg_height_scales.png",
          pred_plots_veght, 
          base_height = 11, base_asp = 1.6,
          dpi = 600)



### Figure S8: temperature histograms ----

# load raw data
# growing season 2019
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))
# winter 2019-20
disko_data_complete_ndjfm1920 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_ndjfm1920.csv"))

# prepare data
temp_responses <- c(paste0("station_pair_daily_", c("mean", "min", "max"), "_temp"),
                    paste0("tms_T3_", c("mean", "min", "max")),
                    paste0("tms_T2_", c("mean", "min", "max")),
                    paste0("tms_T1_", c("mean", "min", "max")),
                    paste0("hobo_temp_", c("mean", "min", "max")))

hist_df_list_temp <- disko_data_complete_season19 %>% 
  
  select(plot_id, date,
         all_of(temp_responses)) %>% 
  
  bind_rows(disko_data_complete_ndjfm1920 %>% select(plot_id, date, any_of(temp_responses))) %>% 
  
  pivot_longer(cols = all_of(temp_responses),
               names_to = "variable",
               values_to = "temp_value") %>% 
  
  drop_na(temp_value) %>% 
  
  mutate(stat_group = factor(str_extract(variable, paste0(c(paste0(c("mean", "min", "max"), "(?=_temp)"), 
                                                            paste0("(?<=T\\d_)", c("mean", "min", "max")),
                                                            paste0("(?<=hobo_temp_)", c("mean", "min", "max"))),
                                                          collapse = "|")),
                             levels = c("mean", "min", "max")),
         sensor = str_extract(variable, "station_pair|T\\d|hobo") %>% 
                    str_remove(paste0("daily_", c("mean", "min", "max"), "_temp_", 
                                      collapse = "|") %>% 
                    str_remove("mean_|min_|max_")),
         sensor = case_when(sensor == "station_pair" & date %within% interval(as.Date("2019-06-25"), as.Date("2019-08-15")) ~ "station_pair_gs",
                            sensor == "station_pair" & date %within% interval(as.Date("2019-11-01"), as.Date("2020-03-31")) ~ "station_pair_winter",
                            sensor == "hobo" & date %within% interval(as.Date("2019-06-25"), as.Date("2019-08-15")) ~ "hobo_gs",
                            sensor == "hobo" & date %within% interval(as.Date("2019-11-01"), as.Date("2020-03-31")) ~ "hobo_winter",
                            TRUE ~ sensor),
         sensor = factor(sensor),
         sensor = fct_relevel(sensor, 
                              levels = c("station_pair_gs", "T3", "T2", "T1", "hobo_gs", "station_pair_winter", "hobo_winter")),
         panel_col = case_when(sensor == "station_pair_gs" ~ theme_purple,
                               sensor == "T3" ~ theme_violet,
                               sensor == "T2" ~ theme_green,
                               sensor == "T1" ~ theme_brown,
                               sensor == "hobo_gs" ~ "grey30",
                               sensor == "station_pair_winter" ~ theme_darkblue,
                               sensor == "hobo_winter" ~ theme_turquoise)) %>% 
  
  group_by(sensor, stat_group) %>% group_split()

hist_temp <- lapply(hist_df_list_temp, function(dat){
  sensor <- unique(dat$sensor)
  stat_group <- unique(dat$stat_group)
  # set axis limits
  x_min <- -40
  x_max <- 10
  if(sensor %in% c("station_pair_gs", "T3", "T2", "T1", "hobo_gs")){
    if(stat_group == "mean"){
      x_min <- 0
      x_max <- 20
    }
    if(stat_group == "min"){
      x_min <- -4
      x_max <- 16
    }
    if(stat_group == "max"){
      x_min <- 2
      x_max <- 35
    }
    y_max <- 750
  }
  if(sensor %in% c("station_pair_winter", "hobo_winter")){
    if(stat_group == "mean"){
      x_min <- -28
      x_max <- 10
    }
    if(stat_group == "min"){
      x_min <- -30
      x_max <- 6
    }
    if(stat_group == "max"){
      x_min <- -25
      x_max <- 10
    }
    y_max <- 2700
  }
  
  ggplot(dat) +
    geom_histogram(aes(x = temp_value,
                       colour = panel_col,
                       fill = panel_col)) +
    scale_colour_identity() +
    scale_fill_identity() +
    guides(colour = "none",
           fill = "none") +
    theme_cowplot(16) +
    labs(x = "",
         y = "") +
    lims(x = c(x_min, x_max)
         , y = c(0, y_max)
         )
})

hist_grid_temp_top <- plot_grid(plotlist = hist_temp[1:12],
                                align = "hv",
                                axis = "lb",
                                nrow = 4,
                                ncol = 3)

drawings_col_top <- plot_grid(plot_grid(ggdraw() +
                                          draw_label("free air",
                                                     colour = theme_purple,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 16,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_station_summer.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              plot_grid(ggdraw() +
                                          draw_label("canopy layer",
                                                     colour = theme_violet,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 16,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_tms_T3.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              plot_grid(ggdraw() +
                                          draw_label("near-surface",
                                                     colour = theme_green,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 16,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_tms_T2.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              plot_grid(ggdraw() +
                                          draw_label("soil (summer)",
                                                     colour = theme_brown,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 16,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_tms_T1.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              ncol = 1)

hist_grid_temp_top <- plot_grid(drawings_col_top,
                                ggdraw() +
                                  draw_label("\ncount",
                                             y = 0.6,
                                             angle = 90,
                                             size = 17,
                                             fontface = "bold"),
                                hist_grid_temp_top,
                                rel_widths = c(0.2, 0.04, 1),
                                nrow = 1)

hist_grid_temp_bottom <- plot_grid(plotlist = hist_temp[16:21],
                                   align = "hv",
                                   axis = "lb",
                                   nrow = 2,
                                   ncol = 3)

drawings_col_bottom <- plot_grid(plot_grid(ggdraw() +
                                             draw_label("free-air (winter)",
                                                        colour = theme_darkblue,
                                                        y = 0.6,
                                                        angle = 90,
                                                        size = 16,
                                                        fontface = "bold"),
                                           ggdraw() +
                                             draw_image(file.path("figures", "drawings", "microclim_station_winter.png"),
                                                        scale = 1,
                                                        y = 0.1),
                                           nrow = 1),
                                 plot_grid(ggdraw() +
                                             draw_label("soil (winter)",
                                                        colour = theme_turquoise,
                                                        y = 0.6,
                                                        angle = 90,
                                                        size = 16,
                                                        fontface = "bold"),
                                           ggdraw() +
                                             draw_image(file.path("figures", "drawings", "microclim_hobo_winter.png"),
                                                        scale = 1,
                                                        y = 0.1),
                                           nrow = 1),
                                 ncol = 1)

hist_grid_temp_bottom <- plot_grid(drawings_col_bottom,
                                   ggdraw() +
                                     draw_label("\ncount\n",
                                                y = 0.6,
                                                angle = 90,
                                                size = 17,
                                                fontface = "bold"),
                                   hist_grid_temp_bottom,
                                   rel_widths = c(0.2, 0.055, 1),
                                   nrow = 1)

hist_grid_temp <- plot_grid(ggdraw() +
                              draw_label("\n growing season (Jun - Aug)\n",
                                         colour = "grey50",
                                         x = 0.61,
                                         size = 15,
                                         fontface = "bold"),
                            hist_grid_temp_top,
                            ggdraw() +
                              draw_label("\n winter (Nov - Mar)\n",
                                         colour = "grey50",
                                         x = 0.61,
                                         size = 15,
                                         fontface = "bold"),
                            hist_grid_temp_bottom,
                            rel_heights = c(0.075, 1, 0.1, 0.5),
                            ncol = 1)

# make titles and x--axis label
top_label <- plot_grid(NULL,
                       plot_grid(ggdraw() +
                                   draw_label("daily mean\ntemperature",
                                              hjust = 0.24,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily minimum\n temperature",
                                              hjust = 0.53,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily maximum\n temperature",
                                              hjust = 0.43,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(1.5, 1, 1)),
                       nrow = 1,
                       rel_widths = c(0.15, 1))

bottom_label <- ggdraw() +
  draw_label("temperature [°C]",
             x = .61,
             size = 17,
             fontface = "bold")

temp_hist_full <- plot_grid(top_label,
                            hist_grid_temp,
                            bottom_label,
                            nrow = 3, ncol = 1,
                            rel_heights = c(.08, 1, .05))

save_plot("figures/microclim_offsets_figureS8_temp_hist.png",
          temp_hist_full, base_height = 14, base_asp = 1)



### Figure S9: temperature difference histograms ----

# load raw data
# growing season 2019
disko_data_complete_season19 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_season19.csv"))
# winter 2019-20
disko_data_complete_ndjfm1920 <- read_csv(file.path("data", "plot_data", "processed", "microclim_plot_data_complete_ndjfm1920.csv"))

# prepare data
temp_diff_responses <- c(paste0("tms_dT4T3_", c("mean", "min", "max")),
                         paste0("tms_dT4T1_", c("mean", "min", "max")),
                         paste0("tms_dT3T1_", c("mean", "min", "max")),
                         paste0("tms_dT3T2_", c("mean", "min", "max")),
                         paste0("tms_dT2T1_", c("mean", "min", "max")),
                         paste0("hobo_dT4hobo_", c("mean", "min", "max")))

hist_df_list_temp_diff <- disko_data_complete_season19 %>% 
  
  select(plot_id, date,
         any_of(temp_diff_responses)) %>% 
  
  bind_rows(disko_data_complete_ndjfm1920 %>% select(plot_id, date, any_of(temp_diff_responses))) %>% 
  
  pivot_longer(cols = all_of(temp_diff_responses),
               names_to = "variable",
               values_to = "temp_value") %>% 
  
  drop_na(temp_value) %>% 
  
  mutate(stat_group = factor(str_extract(variable, "mean|min|max"),
                             levels = c("mean", "min", "max")),
         sensor_pair = factor(str_extract(variable, "dT\\d[:alnum:]+"),
                              levels = c("dT4T3", "dT4T1", "dT3T1", "dT3T2", "dT2T1", "dT4hobo")),
         sensor_pair = forcats::fct_recode(sensor_pair,
                                           "canopy - free-air" = "dT4T3",
                                           "soil (summer) - free-air" = "dT4T1",
                                           "soil - canopy" = "dT3T1",
                                           "near-surface - canopy" = "dT3T2",
                                           "soil - near-surface" = "dT2T1",
                                           "soil (winter) - free-air" = "dT4hobo"),
         #sensor_pair = as.character(sensor_pair),
         panel_col = case_when(sensor_pair == "canopy - free-air" ~ theme_purple,
                               sensor_pair == "soil (summer) - free-air" ~ theme_darkblue,
                               sensor_pair == "soil - canopy" ~ theme_yellow,
                               sensor_pair == "near-surface - canopy" ~ theme_orange,
                               sensor_pair == "soil - near-surface" ~ theme_red,
                               sensor_pair == "soil (winter) - free-air" ~ theme_lightblue)) %>% 
  
  group_by(sensor_pair, stat_group) %>% group_split()

hist_temp_diff <- lapply(hist_df_list_temp_diff, function(dat){
  sensor_pair <- unique(dat$sensor_pair)
  stat_group <- unique(dat$stat_group)
  # set axis limits
  x_min <- -30
  x_max <- 30
  if(sensor_pair %in% c("canopy - free-air",
                        "soil (summer) - free-air",
                        "soil - canopy",
                        "near-surface - canopy",
                        "soil - near-surface")){
    if(stat_group == "mean"){
      x_min <- -15
      x_max <- 10
    }
    if(stat_group == "min"){
      x_min <- -28
      x_max <- 15
    }
    if(stat_group == "max"){
      x_min <- -22
      x_max <- 18
    }
  }

  ggplot(dat) +
    geom_histogram(aes(x = temp_value,
                       colour = panel_col,
                       fill = panel_col)) +
    geom_segment(aes(x = 0, xend = 0,
                     y = -Inf, yend = Inf),
                 linetype = "dashed", size = 1, colour = "grey25") +
    scale_colour_identity() +
    scale_fill_identity() +
    guides(colour = "none",
           fill = "none") +
    theme_cowplot(16) +
    labs(x = "",
         y = "") +
    lims(x = c(x_min, x_max))
})

hist_grid_temp_diff_top <- plot_grid(plotlist = hist_temp_diff[1:15],
                                     align = "hv",
                                     axis = "lb",
                                     nrow = 5,
                                     ncol = 3)

drawings_col_top <- plot_grid(plot_grid(ggdraw() +
                                          draw_label("canopy - free-air",
                                                     colour = theme_purple,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 12,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_tms_dT4T3.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              plot_grid(ggdraw() +
                                          draw_label("soil (summer) - free-air",
                                                     colour = theme_darkblue,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 12,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_tms_dT4T1.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              plot_grid(ggdraw() +
                                          draw_label("soil - canopy-level",
                                                     colour = theme_yellow,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 12,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_tms_dT3T1.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              plot_grid(ggdraw() +
                                          draw_label("near-surface - canopy",
                                                     colour = theme_orange,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 12,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_tms_dT3T2.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              plot_grid(ggdraw() +
                                          draw_label("soil - near-surface",
                                                     colour = theme_red,
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 12,
                                                     fontface = "bold"),
                                        ggdraw() +
                                          draw_image(file.path("figures", "drawings", "microclim_tms_dT2T1.png"),
                                                     scale = 1,
                                                     y = 0.1),
                                        nrow = 1),
                              ncol = 1)

hist_grid_temp_diff_top <- plot_grid(drawings_col_top,
                                     ggdraw() +
                                       draw_label("\ncount",
                                                  y = 0.52,
                                                  angle = 90,
                                                  size = 17,
                                                  fontface = "bold"),
                                     hist_grid_temp_diff_top,
                                     rel_widths = c(0.2, 0.04, 1),
                                     nrow = 1)

hist_grid_temp_diff_bottom <- plot_grid(plotlist = hist_temp_diff[16:18],
                                        align = "hv",
                                        axis = "lb",
                                        nrow = 1,
                                        ncol = 3)

drawings_col_bottom <- plot_grid(ggdraw() +
                                   draw_label("soil - free-air (winter)",
                                              colour = theme_lightblue,
                                              y = 0.65,
                                              angle = 90,
                                              size = 12,
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_image(file.path("figures", "drawings", "microclim_hobo_dT4hobo_winter.png"),
                                              scale = 1,
                                              y = 0.1),
                                 nrow = 1)

hist_grid_temp_diff_bottom <- plot_grid(drawings_col_bottom,
                                        ggdraw() +
                                          draw_label("\ncount",
                                                     y = 0.6,
                                                     angle = 90,
                                                     size = 17,
                                                     fontface = "bold"),
                                        hist_grid_temp_diff_bottom,
                                        rel_widths = c(0.2, 0.045, 1),
                                        nrow = 1)

hist_grid_temp_diff <- plot_grid(ggdraw() +
                                   draw_label("\n growing season (Jun - Aug)\n",
                                              colour = "grey50",
                                              x = 0.62,
                                              size = 15,
                                              fontface = "bold"),
                                 hist_grid_temp_diff_top,
                                 ggdraw() +
                                   draw_label("\n winter (Nov - Mar)\n",
                                              colour = "grey50",
                                              x = 0.62,
                                              size = 15,
                                              fontface = "bold"),
                                 hist_grid_temp_diff_bottom,
                                 rel_heights = c(0.075, 1, 0.1, 0.2),
                                 ncol = 1)

# make titles and x--axis label
top_label <- plot_grid(NULL,
                       plot_grid(ggdraw() +
                                   draw_label(" daily mean\ntemperature",
                                              hjust = 0.24,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily minimum\n temperature",
                                              hjust = 0.53,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 ggdraw() +
                                   draw_label("daily maximum\n temperature",
                                              hjust = 0.43,
                                              size = 18,
                                              colour = "grey25",
                                              fontface = "bold"),
                                 nrow = 1, ncol = 3,
                                 rel_widths = c(1.5, 1, 1)),
                       nrow = 1,
                       rel_widths = c(0.15, 1))

bottom_label <- ggdraw() +
  draw_label("temperature difference [°C]",
             x = .61,
             size = 17,
             fontface = "bold")

temp_diff_hist_full <- plot_grid(top_label,
                                 hist_grid_temp_diff,
                                 bottom_label,
                                 nrow = 3, ncol = 1,
                                 rel_heights = c(.08, 1, .05))

save_plot("figures/microclim_offsets_figureS9_temp_diff_hist.png",
          temp_diff_hist_full, base_height = 14, base_asp = 1)


# Figure S10: Stratification assessment ----
# based on code by Jakob Assmann

### >> prepare data ----
# Load data
data_path <- file.path("..", "disko2019", "data")
microclim_data <- read_csv(file.path(data_path, "microclim/tms_data/processed/microclim_plot_data_complete.csv"))
ldi_coords <- read_csv(file.path(data_path, "microclim/ldi_coordinates/LDI_Coordinates_202203021706.csv")) 
strat_raster <- rast(file.path(data_path, "gee_sampling_design", "Disko2019VegMoistClasses.tif"))
intended_classes <- read_csv(file.path(data_path, "microclim/tms_data/ldi_intended_classes.csv")) %>%
  rename(intended_vegmoist_class = intended_class)

# Check whether latitude and longitude match in both data frames
full_join(select(microclim_data, plot_id, lon, lat),
          select(ldi_coords, PlotID, Longitude, Latitude),
          by = c("plot_id" = "PlotID")) %>%
  summarise(lon = all.equal(lon, Longitude),
            lat = all.equal(lat, Latitude))
# => They are identical 

# Remove ldi_coords to avoid confusion
rm(ldi_coords)

# Convert to sf
microclim_data <- microclim_data %>% st_as_sf(coords = c("lon", "lat"), crs = 4326)

# Extract classes for coordinates 
microclim_data$realised_vegmoist_class <- microclim_data %>% 
  st_transform(crs = crs(strat_raster)) %>%
  vect() %>%
  terra::extract(strat_raster, .) %>%
  .[,2]

# Add intended classes
microclim_data <- full_join(microclim_data,
                            intended_classes,
                            by = c("plot_id" = "ID"))

# Separate veg and moist classes
microclim_data <- microclim_data %>%
  mutate(
    realised_veg_class = case_when(realised_vegmoist_class %in% c(1, 2) ~ 1,
                                   realised_vegmoist_class %in% c(3, 4) ~ 2,
                                   realised_vegmoist_class %in% c(5, 6) ~ 3,
                                   TRUE ~ 0),
    realised_moist_class = case_when(realised_vegmoist_class %in% c(1, 3, 5) ~ 1,
                                     realised_vegmoist_class %in% c(2, 4, 6) ~ 2,
                                     TRUE ~ 0),
    intended_veg_class = case_when(intended_vegmoist_class %in% c(1,2) ~ 1,
                                   intended_vegmoist_class %in% c(3,4) ~ 2,
                                   intended_vegmoist_class %in% c(5,6) ~ 3),
    intended_moist_class = case_when(intended_vegmoist_class %in% c(1,3,5) ~ 1,
                                     intended_vegmoist_class %in% c(2,4, 6) ~ 2))

### >> [a] veg class vs. cover ----

# Check for normal distribution
microclim_data %>% 
  st_drop_geometry() %>% 
  ggplot(., aes(x = cov_vascular_564)) +
  geom_histogram(binwidth = 10) + 
  theme_cowplot(15) + 
  facet_wrap("realised_veg_class")

veg_vs_cov <- microclim_data %>% 
  st_drop_geometry() %>%
  select(realised_veg_class,
         cov_vascular_564) %>% 
  # convert plots in masked areas to NA and drop those (n = 2)
  mutate(realised_veg_class = case_when(realised_veg_class == 0 ~ NA_real_,
                                        TRUE ~ realised_veg_class)) %>% 
  drop_na()

# Check for homogeneity of variances
bartlett.test(cov_vascular_564 ~ realised_veg_class, veg_vs_cov)
# => not homogeneous -> non-parametric (Kruskal-Wallis test)

# Kruskal Wallis Test
(kruskal <- kruskal.test(cov_vascular_564 ~ realised_veg_class, veg_vs_cov))
# => The means are significantly different

# Run post-hoc wilcox test with adjustment for multiple testing
(pw_wilcox <- suppressWarnings(
  pairwise.wilcox.test(veg_vs_cov$cov_vascular_564, 
                       veg_vs_cov$realised_veg_class,
                       p.adjust.method = "BH")))
# => differences significant after adjustments!

# Make beautiful plot
col_low <- "#c6e9af"
col_medium <- "#71c837"
col_high <- "#447821"

(veg_vs_cov_plot <- veg_vs_cov %>% 
    arrange(realised_veg_class) %>%
    mutate(realised_veg_class = factor(realised_veg_class)) %>%
    ggplot(aes(x = realised_veg_class, 
               y = cov_vascular_564,
               group = realised_veg_class)) +
    geom_quasirandom(aes(fill = realised_veg_class),
                     colour = "grey50",
                     shape = 21,
                     size = 3,
                     width = .3,
                     alpha = .6) +
    geom_boxplot(aes(col = realised_veg_class),
                 fill = NA,
                 size = 0.9,
                 outlier.shape = NA) + 
    xlab("\nNDVI-derived vegetation class") +
    ylab(expression(Vascular~plant~cover~`[%]`~`in`~100~m^2~circle)) +
    scale_y_continuous(limits = c(0, 117), breaks = seq(0,100,25)) +
    scale_x_discrete(labels = c("low (1)", "medium (2)", "high (3)")) +
    scale_color_manual(values = c(col_low, col_medium, col_high)) +
    scale_fill_manual(values = c(col_low, col_medium, col_high)) +
    annotate("segment", x =  1, xend = 2, y = 95 + 5, yend = 95 + 5) +
    annotate("segment", x =  2, xend = 3, y = 102.5 + 7, yend = 102.5 + 7) +
    annotate("segment", x =  1, xend = 3, y = 110 +7 , yend = 110 + 7) +
    annotate("text", x = 1.5, y = 95 + 5, label = paste0("italic(p)==0.003"), parse = T, vjust = -0.4) +
    annotate("text", x = 2.5, y = 102.5 + 7 , label = paste0("italic(p)==0.039"), parse = T, vjust = -0.4) +
    annotate("text", x = 2, y = 110 + 7, label = paste0("italic(p)<~0.001"), parse = T, vjust = -0.4) +
    theme_cowplot(15) +
    theme(legend.position = "none"))


### >> [b] moist class vs moist ----

# Prep data
moist_class_vs_tms <- microclim_data %>% 
  st_drop_geometry() %>%
  select(realised_moist_class, tms_moist_vol_mean_scaled)  %>% 
  # convert plots in masked areas to NA and drop those (n = 2)
  mutate(realised_moist_class = case_when(realised_moist_class == 0 ~ NA_real_,
                                          TRUE ~ realised_moist_class)) %>% 
  drop_na()

# Compare means
moist_class_vs_tms %>%
  group_by(realised_moist_class) %>%
  summarise(moist_mean = mean(tms_moist_vol_mean_scaled))

# Look at normality
ggplot(moist_class_vs_tms, aes(x = tms_moist_vol_mean_scaled)) + 
  geom_histogram() +
  facet_wrap("realised_moist_class") + theme_cowplot(15)
# => look kinda normal (if slightly skewed for the high moisture class), 
# probably okay to use a t-test! 

model_moist <- lm(tms_moist_vol_mean_scaled ~ realised_moist_class, moist_class_vs_tms)
summary(model_moist)
# => Difference in means not significant! 

# make plot
col_dry <- "#fbd32c"
col_wet <- "#1B5F9E"

(moist_vs_swc_plot <- microclim_data %>% 
    st_drop_geometry() %>%
    arrange(realised_moist_class) %>%
    filter(realised_moist_class != 0) %>%
    mutate(realised_moist_class = factor(realised_moist_class)) %>%
    ggplot(aes(x = realised_moist_class, 
               y = tms_moist_vol_mean_scaled,
               group = realised_moist_class)) +
    geom_quasirandom(aes(fill = realised_moist_class),
                     colour = "grey50",
                     shape = 21,
                     size = 3,
                     width = .3,
                     alpha = .6) +
    geom_boxplot(aes(col = realised_moist_class),
                 fill = NA,
                 size = 0.9,
                 outlier.shape = NA) + 
    xlab("\nNDWI-derived moisture class") +
    ylab("Growing season-mean vol. soil water content\n") +
    scale_x_discrete(labels = c("low (1)", "high (2)")) +
    scale_y_continuous(limits = c(0, 0.8), breaks = seq(0, 0.8, 0.2)) +
    scale_colour_manual(values = c(col_dry, col_wet)) +
    scale_fill_manual(values = c(col_dry, col_wet)) +
    annotate("segment", x =  1, xend = 2, y = 0.77 , yend = 0.77) +
    annotate("text", x = 1.5, y = 0.78, label = paste0("n.s."), vjust = -0.4) +
    theme_cowplot(15) +
    theme(legend.position = "none"))

# >> combine plots ----
strat_assess_plot <- plot_grid(veg_vs_cov_plot + theme_cowplot(18) + theme(legend.position = "none", axis.title.y = element_text(margin = margin(r = 10, unit = "pt"))),
                               moist_vs_swc_plot + theme_cowplot(18) + theme(legend.position = "none"),
                               labels = c("(a)", "(b)"),
                               label_size = 18,
                               label_fontface = "bold",
                               nrow = 1,
                               align = "v",
                               rel_widths = c(1, 0.75)) %T>% 
  
  save_plot(filename = file.path("figures", "stratification_assessment.png"),
            plot = .,
            base_height = 7,
            base_asp = 1.8,
            dpi = 600)

### _______________________________ ----
### End of file ----