### Shrubs, bryophytes and snow influence microclimate across topographic and moisture gradients in the Arctic tundra
### von Oppen J, et al. 2022

### Custom functions

### Code by Jonathan von Oppen, Aarhus University, jonathan.vonoppen@bio.au.dk, November 2020 - December 2021
### partly based on code by Jakob Assmann, j.assmann@bio.au.dk



### 0) Dependencies ----

  # >> [a] packages ----

    # load pacman package from the repository, if you do not already have it
    if(!require(pacman)){       # provides p_load() as wrapper for require() and library()
      install.packages("pacman")
      library(pacman)
    }
    pacman::p_load(tidyverse,   # for multiple data wrangling & visualisation packages
                   MCMCglmm,    # for multi-response Bayesian GLMM
                   coda,        # to calculate autocorrelation for mcmcglmm model parameters
                   devtools,    # to enable pacman::p_load below
                   cowplot)     # to combine plots in panels
    pacman::p_load_gh("ejanalysis/analyze.stuff") # for rowMaxs function to extract max autocorrelation values for model parameters

    # pre-empty conflicted functions
    if("tidylog" %in% (.packages())) select <- tidylog::select else select <- dplyr::select  # prefer tidylog function over dplyr over raster etc.
    
    
  # >> [b] colour scheme ----
    
    # maps
    theme_darkgreen <- "#355d00"
    theme_darkred <- "#7c3f3f"
    theme_forestgreen <- "#3d8225"
    theme_grey <- "#EDEDEDFF"
    
    # effect sizes plot - T means
    theme_violet <- "#a177e0"
    theme_green <- "#58bb5b"
    theme_brown <- "#9e5f3f"
    theme_turquoise <- "#28BECB"

    # effect sizes plots - T differences
    theme_purple <- "#8757B3"
    theme_darkblue <- "#4f5faf"
    theme_lightblue <- "#5995c5"
    theme_yellow <- "#ffcc00"
    theme_orange <- "#c87e1f"
    theme_red <- "#a44748"
    
    # prediction plots
    theme_blueblack <- "#223769"
    theme_bluegreen <- "#4384ad"
    theme_gold <- "#de9e04"
    theme_brightgold <- "#ffd700"
    theme_darkred <- "#7c3f3f"
    theme_lightred <- "#ca6162"
    theme_darkgreen <- "#355d00"
    theme_forestgreen <- "#3d8225"
    theme_lightgreen <- "#56c94a"



### Determine TOMST soil class ----
    
  ## Purpose of function: Determine TOMST soil class based on Euclidean distance.
  ##
  ## Author: Stijn Van de Vondel (adapted by Jonathan von Oppen)
  ##
  ## Date Created: 2022-01-03
  ##
  ## Copyright (c) Stijn Van de Vondel, 2022
  ## Email: vandevondel.stijn@gmail.com
  ## Notes: [The original] script [used] some example data derived from real measurements.
  ##        Per ID, the sum of % sand, clay and silt approximates 100% due to
  ##        modelling based on spectroscopy data and rounding up to 2 decimals.
  ##
  ##        Using euclidean distances (here without bulk_density -> these data
  ##        were not yet available in our data), each sample is matched to a
  ##        TOMST soil class with which it shares most resemblence (lowest distance).
  ##        Other distance measures are  yet to be tested.
  ## ---------------------------#

  add_tomst_soil_class <- function(soil_data, id_col){
    # - load packages
    if (!require("pacman")) install.packages("pacman")
    pacman::p_load(dplyr, tibble)
    
    # TOMST soil classes
    soil_TOMST <- read.csv("../TOMST_cal/data/soil_TOMST_2021.csv") %>%
      filter(name != "peat") %>%
      column_to_rownames("name") %>% 
      # if fractions in proportions, convert soil classes as well
      {if(all(c(soil_data$sand, soil_data$silt, soil_data$clay) < 1))
        mutate_at(., c("clay", "silt", "sand"), ~ magrittr::multiply_by(., 0.01))
        else .}
    
    # - TOMST soil classification
    # Prepare empty matrix
    m_dist <- matrix(
      nrow = nrow(soil_data),
      ncol = nrow(soil_TOMST),
      dimnames = list(
        c(soil_data %>% pull(id_col)), row.names(soil_TOMST)),
      byrow = FALSE)
    
    # Iterate over each row (ID):
    # In each row, iterate over each column (TOMST class)
    # => calculate 3D Euclidean distance for each
    for (i in 1:nrow(soil_data)) {
      for (j in row.names(soil_TOMST)) {
        
        # Calculate Euclidean distance
        dist <- sqrt((soil_TOMST[j, "clay"] - soil_data$clay[i])^2 +
                       (soil_TOMST[j, "silt"] - soil_data$silt[i])^2 +
                       (soil_TOMST[j, "sand"] - soil_data$sand[i])^2)
        
        # Store distance in corresponding cell
        m_dist[i, j] <- dist
      }
    }
    
    # Determine TOMST class corresponding to lowest distance and add sample names
    soil_data_with_TOMST_class <- as.data.frame(m_dist) %>%
      mutate(TOMST_class = names(.)[apply(., MARGIN = 1, FUN = which.min)]) %>%
      cbind(soil_data[id_col]) %>%
      as_tibble() %>%
      select(all_of(id_col), TOMST_class) %>%
      right_join(soil_data)
    
    return(soil_data_with_TOMST_class)
    # # Export resulting dataframe
    # write.csv(TOMST_result, "output/TOMST_soil_result.csv")
  }

    
    
### Calibrate TMS soil moisture measurements ----
    
  ## Purpose of function: Calibrate TMS raw moisture signal to volumetric Soil Water
  ##                      content (SWC, %).
  ##
  ## Author: Stijn Van de Vondel
  ##
  ## Date Created: 2022-01-03
  ##
  ## Copyright (c) Stijn Van de Vondel, 2022
  ## Email: vandevondel.stijn@gmail.com
  ## Notes: See TOMST_soil_class.R for method to determining TOMST soil classes.
  ##
  ##        Additionally, measurement and soil texture data originate from different
  ##        loggers. They serve only as an example, and are not useful in terms
  ##        of actual analysis. Measurement data were obtained via TMS-4 loggers
  ##        during the summer of 2020, while soil texture data originated from other
  ##        locations in 2021.
  ##
  ##        Resulting SWC values are expressed as a fraction between 0 and 1.
  ## ---------------------------#

  calib_tomst_soil_moist <- function(tms_data,
                                     soil_class_data, 
                                     raw_moist_col,
                                     calib = "specific"){
    # - load packages
    if (!require("pacman")) install.packages("pacman")
    pacman::p_load(data.table, tibble, lubridate, dplyr)
    
    # extract column names of TMS input data
    orig_data_cols <- names(tms_data)
    
    # TOMST calibration coefficients
    TOMST_coef <- read.csv("../TOMST_cal/data/TOMST_coef.csv") %>%
      tibble::column_to_rownames("X")
    
    # - Prepare data 
    # Join soil and measurement data (raw humidity)
    df_raw <- tms_data %>%
      inner_join(soil_class_data) %>%
      select(-any_of(c("sand", "silt", "clay", "total"))) %>%
      rename(raw_moist = all_of(raw_moist_col)) %>% 
      as.data.frame()
    
    if(calib == "specific"){
      # >> Specific TOMST calibration ----
      # Determine which coefficients to use (based on TOMST class) and calibrate
      # via quadratic calibration.
      SWC_cal_spec <- df_raw %>%
        mutate(
          a = case_when(TOMST_class == "sand" ~ TOMST_coef["sand", "a"],
                        TOMST_class == "loamy.sand.A" ~ TOMST_coef["loamy.sand.A", "a"],
                        TOMST_class == "loamy.sand.B" ~ TOMST_coef["loamy.sand.B", "a"],
                        TOMST_class == "sandy.loam.A" ~ TOMST_coef["sandy.loam.A", "a"],
                        TOMST_class == "sandy.loam.B" ~ TOMST_coef["sandy.loam.B", "a"],
                        TOMST_class == "loam" ~ TOMST_coef["loam", "a"],
                        TOMST_class == "silt.loam" ~ TOMST_coef["silt.loam", "a"]),
          b = case_when(TOMST_class == "sand" ~ TOMST_coef["sand", "b"],
                        TOMST_class == "loamy.sand.A" ~ TOMST_coef["loamy.sand.A", "b"],
                        TOMST_class == "loamy.sand.B" ~ TOMST_coef["loamy.sand.B", "b"],
                        TOMST_class == "sandy.loam.A" ~ TOMST_coef["sandy.loam.A", "b"],
                        TOMST_class == "sandy.loam.B" ~ TOMST_coef["sandy.loam.B", "b"],
                        TOMST_class == "loam" ~ TOMST_coef["loam", "b"],
                        TOMST_class == "silt.loam" ~ TOMST_coef["silt.loam", "b"]),
          c = case_when(TOMST_class == "sand" ~ TOMST_coef["sand", "c"],
                        TOMST_class == "loamy.sand.A" ~ TOMST_coef["loamy.sand.A", "c"],
                        TOMST_class == "loamy.sand.B" ~ TOMST_coef["loamy.sand.B", "c"],
                        TOMST_class == "sandy.loam.A" ~ TOMST_coef["sandy.loam.A", "c"],
                        TOMST_class == "sandy.loam.B" ~ TOMST_coef["sandy.loam.B", "c"],
                        TOMST_class == "loam" ~ TOMST_coef["loam", "c"],
                        TOMST_class == "silt.loam" ~ TOMST_coef["silt.loam", "c"]),
          SWC = round((raw_moist^2 * a + raw_moist * b + c), 4)
        ) %>%
        select(all_of(orig_data_cols), TOMST_class, SWC)
      
      return(SWC_cal_spec)
    }
    
    # # Export result
    # write.csv(SWC_cal_spec, "output/SWC_specific_cal.csv")
    
    if(calib == "universal"){
      # >> Universal TOMST calibration ----
      SWC_cal_uni <- df_raw %>%
        mutate(
          a = TOMST_coef["universal", "a"],
          b = TOMST_coef["universal", "b"],
          c = TOMST_coef["universal", "c"],
          SWC_uni = round((raw_moist^2 * a + raw_moist * b + c), 4)
        ) %>%
        select(all_of(orig_data_cols), TOMST_class, SWC_uni)
      
      return(SWC_cal_uni)
      
    }
  }
    
    
    
### Normalise (scale) data between 0 and 1 ----
  normalise <- function(x){
    (x - min(x, na.rm = T)) / (max(x, na.rm = T) - min(x, na.rm = T))
  }
    
    
    
### Calculate Solar Radiation Index ----
    
  # Code adapted from S. Schøler Nielsen and N. Chardon (sri_calcuation.R in https://gitlab.com/nathaliechardon/gl_microclim)
  # Based on Keating et al. 2007. Journal of Wildlife Management, 71:1344-1348
  
  sri <- function(mode, start_date, end_date, lon, lat, slope, aspect, ...){
    
    sinDeg <- function(angle){sin(angle*pi/180)}
    cosDeg <- function(angle){cos(angle*pi/180)}
    
    # >> integrated over time period ----
    if(mode == "integrated"){
      start_date <- as.Date(start_date, format = "%d-%m-%Y", tz = "America/Godthab")
      end_date <- as.Date(end_date, format = "%d-%m-%Y", tz = "America/Godthab")
      
      date_range <- seq(start_date, end_date, by = "1 day")
      
      sri_vec <- sapply(date_range, function(date){
        
        doy <- format(date, "%j") %>% as.numeric()
        time <- as.POSIXct(paste0(date, " 12:00:00"),
                           tz = "America/Godthab")
        
        # Calculate solar time
        sun <- GeoLight::solar(time)
        
        # Calculate solar zenith angle
        zen <- GeoLight::zenith(sun, lon, lat)
        
        # Calculate declination
        declin <- insol::declination(doy)
        
        # Radial angle of earth to sun at day of year (for calculation of eccentricity factor)
        day_angle <- 2*pi*(doy-1)/365
        
        # calculate eccentricity correction factor following Eq. 1.2.1 in Iqbal 1983, https://doi.org/10.1016/B978-0-12-373750-2.50006-9 and https://www.sciencedirect.com/topics/physics-and-astronomy/elliptical-orbits
        E0 <- 1.000110 + 0.034221 * cos(day_angle) + 0.00128 * sin(day_angle) + 0.000719 * cos(2 * day_angle) + 0.000077 * sin(2 * day_angle) # E0 = 0.9676863
        
        # calculate SRI
        sri_vec <- E0 * ((sinDeg(lat) * cosDeg(slope) - cosDeg(lat) * sinDeg(slope) * cosDeg(180 - aspect - declin)) * sinDeg(zen)
                         + (cosDeg(lat) * cosDeg(slope) + sinDeg(lat) * sinDeg(slope) * cosDeg(180 - aspect - declin)) * (cosDeg(zen) * cosDeg(0))
                         + cosDeg(zen) * sinDeg(slope) * sinDeg(180 - aspect - declin) * sinDeg(0))
        
      })
      
      sri_integrated <- sum(sri_vec, na.rm = TRUE) / length(date_range)
      
      return(sri_integrated)
    }
    
    # >> daily values at noon ----
    if(mode == "daily"){
      start_date <- as.Date(start_date, format = "%d-%m-%Y", tz = "America/Godthab")
      end_date <- as.Date(end_date, format = "%d-%m-%Y", tz = "America/Godthab")
      
      date_range <- seq(start_date, end_date, by = "1 day")
      
      sri_vec <- sapply(date_range, function(date){
        
        doy <- format(date, "%j") %>% as.numeric()
        time <- as.POSIXct(paste0(date, " 12:00:00"),
                           tz = "America/Godthab")
        
        # Calculate solar time
        sun <- GeoLight::solar(time)
        
        # Calculate solar zenith angle
        zen <- GeoLight::zenith(sun, lon, lat)
        
        # Calculate declination
        declin <- insol::declination(doy)
        
        # Radial angle of earth to sun at day of year (for calculation of eccentricity factor)
        day_angle <- 2*pi*(doy-1)/365
        
        # calculate eccentricity correction factor following Eq. 1.2.1 in Iqbal 1983, https://doi.org/10.1016/B978-0-12-373750-2.50006-9 and https://www.sciencedirect.com/topics/physics-and-astronomy/elliptical-orbits
        E0 <- 1.000110 + 0.034221 * cos(day_angle) + 0.00128 * sin(day_angle) + 0.000719 * cos(2 * day_angle) + 0.000077 * sin(2 * day_angle) # E0 = 0.9676863
        
        # calculate SRI
        sri_vec <- E0 * ((sinDeg(lat) * cosDeg(slope) - cosDeg(lat) * sinDeg(slope) * cosDeg(180 - aspect - declin)) * sinDeg(zen)
                         + (cosDeg(lat) * cosDeg(slope) + sinDeg(lat) * sinDeg(slope) * cosDeg(180 - aspect - declin)) * (cosDeg(zen) * cosDeg(0))
                         + cosDeg(zen) * sinDeg(slope) * sinDeg(180 - aspect - declin) * sinDeg(0))
        
      })
      
      return(sri_vec)
    }
    
  }
    
    
    
### Read and clean GeoBasis weather station data ----
  
  read_clean_geobase_data <- function(file){
    read_delim(file.path(station_data_path, file),
               delim = "\t",
               locale = locale(encoding = "latin1"),
               col_names = TRUE) %>% 
      
      # drop empty cols
      select(-matches("X\\d{2}")) %>% 
      
      # select date, time, air & ground temperature cols
      select(contains("Date"),
             contains("Time"),
             contains("Air temperature"),
             contains("Ground surface temperature"),
             contains("Soil temperature 5")) %>% 
      
      # create columns with altitude and station ID
      mutate(station_id = case_when(str_detect(file, "T1") ~ "T1",
                                    str_detect(file, "T2") ~ "T2",
                                    str_detect(file, "T3") ~ "T3",
                                    str_detect(file, "T4") ~ "T4",
                                    str_detect(file, "AWS3") ~ "AWS3",
                                    str_detect(file, "AWS4") ~ "AWS4",
                                    TRUE ~ NA_character_)) %>% 
      
      # add lat and lon from locations file
      left_join(station_locations %>% select(station_id,
                                             elevation = asl,
                                             lat,
                                             long),
                by = "station_id") %>% 
      
      # pivot longer at temperature cols
      pivot_longer(cols = contains("temperature"),
                   names_to = "sensor",
                   values_to = "temperature") %>% 
      
      # clean strata names
      mutate(sensor = factor(sensor),
             sensor = case_when(str_detect(sensor, "Air") ~ "air",
                                str_detect(sensor, "Ground") ~ "ground",
                                str_detect(sensor, "Soil") ~ "soil",
                                TRUE ~ NA_character_)) %>% 
      
      # remove erroneous /missing measurements (temperature = -9999)
      filter(!(temperature == -9999)) %>% 
      
      # rename / unify Time column name (case_when to avoid error if cols not present)
      rename_with( ~ case_when(. == "Time" ~ "time_UTCm3",
                               . == "Time (UTC-3)" ~ "time_UTCm3",
                               . == "Date" ~ "date",
                               TRUE ~ .)) %>% 
      
      # merge date and time cols
      mutate(date_time_UTCm3 = lubridate::ymd(date) + lubridate::hms(time_UTCm3)) %>% 
      
      # filter for relevant timeframe in 2019 & 2020
      filter(date_time_UTCm3 >= date("2019-06-25"),
             date_time_UTCm3 <= date("2020-08-31")) %>% 
      
      # reorder columns
      select(station_id, 
             elevation,
             lat,
             long,
             date_time_UTCm3,
             sensor,
             temperature)
    
  }

    
        
### MCMC model function ----

  model_function_mcmc <- function(response_variable, predictors, data) {
      
    # Construct model formula
    model_formula <- formula(paste0(response_variable, "~", paste0(predictors, collapse = " + ")))
    model <- MCMCglmm(model_formula, 
                      data = as.data.frame(data),
                      prior = prior, 
                      random = as.formula(paste("~", random)),
                      # pr = TRUE,
                      nitt = 100000, burnin = 70000)
    model_summary <- summary(model)
    return(list(response = response_variable,
                model = model, 
                model_summary = model_summary))
  }


### Extract maximum autocorrelation value ----

# extract maximum autocorrelation value from mcmcglmm model object

  extract_max_autocorr <- function(model_object){
    
    response_string <- model_object$response %>% str_remove("^tms_")
    response_strata <- response_string %>% str_extract("dT\\dT\\d|^T\\d")
    response_temp_var <- response_string %>% str_extract("[:alpha:]+$")
    
    sol <- model_object$model$Sol
    var <- model_object$model$VCV
    
    max_autocorr_mean <- sol %>% 
      
      # create autocorrelation matrix
      autocorr() %>% 
      
      # transform to data frame and tibble to extract row names
      as.data.frame() %>% 
      as_tibble(rownames = "lag") %>% 
      
      # filter for smallest stored lag (= 10)
      dplyr::filter(lag == "Lag 10") %>% 
      
      # drop lag column
      dplyr::select(-lag,
                    -contains("plot_id_num")  # if incl posterior for random effect
      ) %>% 
      
      # get row max
      analyze.stuff::rowMaxs() %>% 
      
      as_tibble() %>% dplyr::rename(autocorr_mean = value)
    
    max_autocorr_var <- var %>% 
      
      # create autocorrelation matrix
      autocorr() %>% 
      
      # transform to data frame and tibble to extract row names
      as.data.frame() %>% 
      as_tibble(rownames = "lag") %>% 
      
      # filter for smallest stored lag (= 10)
      dplyr::filter(lag == "Lag 10") %>% 
      
      # drop lag column
      dplyr::select(-lag,
                    -contains("plot_id_num")  # if incl posterior for random effect
      ) %>% 
      
      # get row max
      analyze.stuff::rowMaxs() %>% 
      
      as_tibble() %>% dplyr::rename(autocorr_variance = value)
    
    max_autocorr <- bind_cols(max_autocorr_mean, max_autocorr_var) %>% 
      dplyr::mutate(temp_var = paste(response_temp_var)) %>% 
      dplyr::relocate(temp_var, .before = everything()) 
    
    return(max_autocorr)  
  }


### Extract model solutions ----

# extract mean effect sizes for all predictors, strata and temp vars

  extract_model_solutions <- function(model_object, radius){
    
    response_string <- model_object$response %>% str_remove("^tms_")
    if(model_object$response %>% str_detect("hobo_temp")) response_string <- model_object$response %>% str_remove("_ndjfm1920")
    if(model_object$response %>% str_detect("tms_.*_season19")) response_string <- model_object$response %>% str_remove("^tms_") %>% str_remove("_season19")
    if(str_detect(response_string, "dT\\dT")) response_strata <- response_string %>% str_extract("dT\\dT\\d")
    if(str_detect(response_string, "^T\\d_.*$")) response_strata <- response_string %>% str_extract("T\\d")
    if(str_detect(response_string, "dT\\dhobo_.*$")) response_strata <- response_string %>% str_extract("dT\\dhobo")
    if(str_detect(response_string, "^hobo_temp_m.*$")) response_strata <- response_string %>% str_extract("hobo")
    response_temp_var <- response_string %>% str_extract("[:alpha:]+$")
    model_string <- paste0(response_strata, "_", radius)
    
    solutions <- data.frame(model_object$model_summary$solutions,
                            variable = row.names(model_object$model_summary$solutions))
    names(solutions) <- c("post.mean", "l95", "u95", "eff_sample", "pMCMC", "variable")
    
    var_order <- c(paste0(c("veg_height_avg_", "cov_lichen_", "cov_bryophytes_", "cov_shrubs_","cov_rocks_"), radius),
                   "tms_moist_vol_mean_scaled", "topo_prim_num", "sri_season19", "slope", "elevation", 
                   paste0("station_base_daily_", c("max", "min", "mean"), "_temp"))
    
    if(response_strata %>% str_detect("dT\\dT\\d|T\\d")) plot_data <- disko_data_complete_season19
    if(response_strata %>% str_detect("dT\\dhobo|hobo")) plot_data <- disko_data_complete_ndjfm1920
    
    raw_data_sd <- plot_data %>% 
      dplyr::select(all_of(solutions$variable[solutions$variable != "(Intercept)"])) %>% 
      summarise(across(everything(), 
                       sd, 
                       na.rm = TRUE)) %>% 
      pivot_longer(cols = everything(), 
                   names_to = "variable", 
                   values_to = "sd")
    
    solutions_summary <- solutions %>% 
      
      # add sd for back-scaling of effect sizes
      left_join(raw_data_sd,
                by = "variable") %>% 
      
      # arrange in variable order
      mutate(variable = fct_recode(variable,
                                   "Intercept" = "(Intercept)",
                                   "free-air mean temp." = "station_base_daily_mean_temp",
                                   "free-air min temp." = "station_base_daily_min_temp",
                                   "free-air max temp." = "station_base_daily_max_temp",
                                   "slope angle" = "slope",
                                   "solar radiation" = "sri_season19",
                                   "solar radiation" = "sri_ndjfm1920",
                                   "landform" = "topo_prim_num",
                                   "soil moisture" = "tms_moist_vol_mean_scaled",
                                   "snow cover duration" = "ndays_snowcover_ndjfm",
                                   "rock cover" = paste0("cov_rocks_", radius),
                                   "shrub cover" = paste0("cov_shrubs_", radius),
                                   "bryophyte cover" = paste0("cov_bryophytes_", radius),
                                   "lichen cover" = paste0("cov_lichen_", radius),
                                   "vegetation height" = paste0("veg_height_avg_", radius))) %>% 
      
      # select relevant columns
      dplyr::select(post.mean,
                    l95,
                    u95,
                    variable,
                    sd) %>% 
      
      # add columns indicating strata, temp variable and radius
      mutate(model = paste(model_string),
             strata = paste(response_strata),
             temp_var = paste(response_temp_var),
             radius = radius) %>% 
      
      # back-scale output effect sizes
      mutate(post.mean.backscaled = post.mean * sd,
             l95.backscaled = l95 * sd,
             u95.backscaled = u95 * sd) %>% 
      
      # calculate effect per unit increase
      mutate(post.mean.unit = case_when(
          # solar radiation (range {0;1} with small differences): per 0.01 increase
          variable %in% c("solar radiation")
          ~ 0.01 * (post.mean / sd),
          # soil moisture (range {0;1}): per 0.1 increase
          variable %in% c("soil moisture")
          ~ 0.1 * (post.mean / sd),
          # variables with limit < 10 : per 1 increase
          variable %in% c(paste("free-air", c("mean", "min", "max"), "temp."), 
                          "vegetation height", "landform", "slope angle")
          ~ 1 * (post.mean / sd),
          # variables with range {0;100} or limit ~< 200: per 10 increase
          variable %in% c(paste0(c("lichen ", "bryophyte ", "shrub ","rock "), "cover"), "snow cover duration")
          ~ 10 * (post.mean / sd),
          # variables with limit > 200: per 100 increase
          variable == "elevation"
          ~ 100 * (post.mean / sd)),
        l95.unit = case_when(
          variable %in% c("solar radiation")
          ~ 0.01 * (l95 / sd),
          variable %in% c("soil moisture")
          ~ 0.1 * (l95 / sd),
          variable %in% c(paste("free-air", c("mean", "min", "max"), "temp."), 
                          "vegetation height", "landform", "slope angle")
          ~ 1 * (l95 / sd),
          variable %in% c(paste0(c("lichen ", "bryophyte ", "shrub ","rock "), "cover"), "snow cover duration")
          ~ 10 * (l95 / sd),
          variable == "elevation"
          ~ 100 * (l95 / sd)),
        u95.unit = case_when(
          variable %in% c("solar radiation")
          ~ 0.01 * (u95 / sd),
          variable %in% c("soil moisture")
          ~ 0.1 * (u95 / sd),
          variable %in% c(paste("free-air", c("mean", "min", "max"), "temp."), 
                                "vegetation height", "landform", "slope angle")
          ~ 1 * (u95 / sd),
          variable %in% c(paste0(c("lichen ", "bryophyte ", "shrub ","rock "), "cover"), "snow cover duration")
          ~ 10 * (u95 / sd),
          variable == "elevation"
          ~ 100 * (u95 / sd))) %>%
        
      # pivot to long format
      pivot_longer(cols = c(post.mean,
                            l95,
                            u95,
                            post.mean.backscaled,
                            l95.backscaled,
                            u95.backscaled
                            , post.mean.unit,
                            l95.unit,
                            u95.unit
                            ),
                   names_to = "parameter",
                   values_to = "value")
    
    return(solutions_summary)
    
  }


### Effect size plots ----

  mcmc_plot_function <- function(model_object, labels_display) {
    response <- str_remove(model_object$response, "_season19$")
    model <- model_object$model
    solutions <- data.frame(model_object$model_summary$solutions,
                            variable = row.names(model_object$model_summary$solutions))
    names(solutions) <- c("post.mean", "l95", "u95", "eff_sample", "pMCMC", "variable")
    
    var_order <- c("veg_height_avg_50", "cov_lichen_50", "cov_bryophytes_50", "cov_shrubs_50", 
                   "cov_rocks_50", "tms_moist_vol_mean_scaled", "topo_prim_num", 
                   "sri_season19", "slope", "elevation")
    if(str_detect(response, "_mean")) var_order <- c(var_order, "station_base_daily_mean_temp")
    if(str_detect(response, "_min")) var_order <- c(var_order, "station_base_daily_min_temp")
    if(str_detect(response, "_max")) var_order <- c(var_order, "station_base_daily_max_temp")
    if(str_detect(response, "hobo")) {
      var_order <- c("veg_height_avg_50", "cov_shrubs_50", 
                     "cov_rocks_50", "ndays_snowcover_ndjfm", "topo_prim_num", 
                     "sri_ndjfm1920", "elevation")
      if(str_detect(response, "_mean")) var_order <- c(var_order, "station_base_daily_mean_temp")
      if(str_detect(response, "_min")) var_order <- c(var_order, "station_base_daily_min_temp")
      if(str_detect(response, "_max")) var_order <- c(var_order, "station_base_daily_max_temp")
    }
    solutions <- solutions[solutions$variable != "(Intercept)",] %>% 
      
      # arrange in variable order for plotting
      arrange(factor(variable, 
                     levels = var_order))
    
    solutions$sig <- "ns"
    solutions$sig[solutions$l95 < 0 & solutions$u95 < 0] <- "sig"
    solutions$sig[solutions$l95 > 0 & solutions$u95 > 0] <- "sig"
    
    if(str_detect(response, "dT\\d")){
      x_min_value <- -2
      x_max_value <- 1.6
      x_axis_breaks <- seq(-2.5, 2, 0.5)
      if(str_detect(response, ".*_max")){
        x_min_value <- -2.6
        x_max_value <- 1.5
      }
    }
    if(str_detect(response, "dT4T")){
      x_min_value <- -2.1
      x_max_value <- 1.5
      x_axis_breaks <- seq(-2, 1.5, 0.5)
      if(str_detect(response, ".*_max")){
        x_min_value <- -1.9
        x_max_value <- 1.6
      }
    }
    if(str_detect(response, "hobo_dT4hobo")){
      x_min_value <- -4
      x_max_value <- 4.3
      x_axis_breaks <- seq(-4, 4, 1)
    }
    if(str_detect(response, "tms_T\\d") | response %in% paste0("hobo_temp_", c("mean", "min", "max", "amp", "range"))){
      x_min_value <- -1.2
      x_max_value <- 2.8
      x_axis_breaks <- seq(-1, 2.5, 0.5)
      if(str_detect(response, "tms_.*_max")){
        x_min_value <- -2
        x_max_value <- 3
        x_axis_breaks <- seq(-2, 3, 1)}
      if(str_detect(response, "hobo_")){
        x_min_value <- -2
        x_max_value <- 4
        x_axis_breaks <- seq(-2, 4, 1)
      }
    }
    
    R2_x_pos <- 2
    R2_marg_y_pos <- 3.25
    R2_cond_y_pos <- R2_marg_y_pos - 1.4
    if(response %in% c(paste0("tms_T", c(1:3), "_max")) & labels_display == "all") R2_x_pos <- 0.8
    if(response %in% c(paste0("tms_T", c(1:3), "_max")) & labels_display == "left") R2_x_pos <- 2.1
    if(str_detect(response, "dT\\d")) R2_x_pos <- 1
    if(str_detect(response, "dT\\d") & str_detect(response, "_max") | str_detect(response, "dT4hobo")) R2_x_pos <- 0.8
    if(str_detect(response, "dT\\d") & str_detect(response, "dT4hobo")){
      R2_x_pos <- 2.9
      # R2_y_pos <- 9.05
    }
    if(str_detect(response, "dT\\d(?!hobo)") & str_detect(response, "_max")) R2_x_pos <- 0.8
    if(str_detect(response, "dT4T")) R2_x_pos <- 0.8
    if(str_detect(response, "dT4T") & str_detect(response, "_max")) R2_x_pos <- 1
    if(response %in% paste0("hobo_temp_", c("mean", "min", "max", "amp", "range"))) R2_x_pos <- 2.8
    if(str_detect(response, "^hobo_")){
      R2_marg_y_pos <- 1.8
      R2_cond_y_pos <- 0.9
    }
    
    x_label <- ""
    if(response %in% c(paste0("hobo_temp_", c("mean", "min", "max", "amp", "range")),
                       paste0("hobo_dT4hobo_", c("mean", "min", "max", "amp", "range")))) x_label <- "Effect size (scaled)"
    
    theme_colour <- "black"
    if(response %in% paste0("tms_T3_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_violet
    if(response %in% paste0("tms_T2_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_green
    if(response %in% paste0("tms_T1_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_brown
    if(response %in% paste0("hobo_temp_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_turquoise
  
    if(response %in% paste0("tms_dT4T3_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_purple
    if(response %in% paste0("tms_dT4T1_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_darkblue
    if(response %in% paste0("tms_dT3T1_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_yellow
    if(response %in% paste0("tms_dT3T2_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_orange
    if(response %in% paste0("tms_dT2T1_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_red
    if(response %in% paste0("hobo_dT4hobo_", c("mean", "min", "max", "amp", "range"))) theme_colour <- theme_lightblue
    
    label_colour <- rep("black", nrow(solutions))
    label_colour[solutions$sig == "sig"] <- theme_colour
    
    label_face <- rep("plain", nrow(solutions))
    label_face[solutions$sig == "sig"] <- "bold"
    
    panel_title <- "Sensor"
    if(response == "tms_T1_mean") panel_title <- "soil mean T"
    if(response == "tms_T2_mean") panel_title <- "near-surface (growing season)"
    if(response == "tms_T3_mean") panel_title <- "canopy-level (growing season)"
    if(response == "tms_T1_min") panel_title <- "soil min T"
    if(response == "tms_T2_min") panel_title <- "near-surface min T"
    if(response == "tms_T3_min") panel_title <- "canopy-level min T"
    if(response == "tms_T1_max") panel_title <- "soil max T"
    if(response == "tms_T2_max") panel_title <- "near-surface max T"
    if(response == "tms_T3_max") panel_title <- "canopy-level max T"
    
    if(response == "tms_dT4T3_mean") panel_title <- "free-air - canopy-level mean T"
    if(response == "tms_dT4T1_mean") panel_title <- "free-air - soil mean T"
    if(response == "tms_dT3T1_mean") panel_title <- "canopy-level - soil mean T"
    if(response == "tms_dT3T2_mean") panel_title <- "canopy-level - near-surface mean T"
    if(response == "tms_dT2T1_mean") panel_title <- "near-surface - soil mean T"
    if(response == "tms_dT4T3_min") panel_title <- "free-air - canopy-level min T"
    if(response == "tms_dT4T1_min") panel_title <- "free-air - soil mean T"
    if(response == "tms_dT3T1_min") panel_title <- "canopy-level - soil min T"
    if(response == "tms_dT3T2_min") panel_title <- "canopy-level - near-surface min T"
    if(response == "tms_dT2T1_min") panel_title <- "near-surface - soil min T"
    if(response == "tms_dT4T3_max") panel_title <- "free-air - canopy-level max T"
    if(response == "tms_dT4T1_max") panel_title <- "free-air - soil mean T"
    if(response == "tms_dT3T1_max") panel_title <- "canopy-level - soil max T"
    if(response == "tms_dT3T2_max") panel_title <- "canopy-level - near-surface max T"
    if(response == "tms_dT2T1_max") panel_title <- "near-surface - soil max T"
    
    # summer (TMS variables)
    if(response %in% c(paste0("tms_", c("dT4T3", "dT4T1", "dT3T1", "dT3T2", "dT2T1"), "_mean"),
                       paste0("tms_T", c(1:3), "_mean"))){
      if(labels_display == "left") var_labels <- c("vegetation height", "lichen cover", "bryophyte cover", "shrub cover", 
                                                   "rock cover", "soil moisture", "landform", 
                                                   "solar radiation", "slope angle", "elevation",
                                                   "free-air temp.")
      if(labels_display == "all") var_labels <- c("vegetation height (VEG)", "lichen cover (LIC)", "bryophyte cover (BRY)", 
                                                  "shrub cover (SHR)", 
                                                  "rock cover (ROC)", "soil moisture (MOI)", "landform (LAN)", 
                                                  "solar radiation (SOL)", "slope angle (SLO)", "elevation (ELE)",
                                                  "free-air temp. (FAT)")
      y_axis_labels_display <- "element_text(hjust = 1, size = rel(0.9))"
    } else {
      var_labels <- c("VEG", "LIC", "BRY", "SHR", 
                      "ROC", "MOI", "SNO", "LAN", "SOL", "SLO", "ELE",
                      "FAT")
      if(labels_display == "left") y_axis_labels_display <- "element_blank()"
      if(labels_display == "all") y_axis_labels_display <- "element_text(hjust = 1, size = rel(0.9))"
    } 
    
    # winter (HOBO variables)
    if(response %in% c("hobo_dT4hobo_mean",
                       "hobo_temp_mean")){
      if(labels_display == "left") var_labels <- c("vegetation height", "shrub cover", 
                                                   "rock cover", "snow cover", "landform", 
                                                   "solar radiation", "elevation",
                                                   "free-air temp.")
      if(labels_display == "all") var_labels <- c("vegetation height (VEG)", "shrub cover (SHR)", 
                                                  "rock cover (ROC)", "snow cover (SNO)", "landform (LAN)", 
                                                  "solar radiation (SOL)", "elevation (ELE)",
                                                  "free-air temp. (FAT)")
      y_axis_labels_display <- "element_text(hjust = 1, size = rel(0.9))"
    } 
    if(response %in% c(paste0("hobo_dT4hobo_", c("min", "max")),
                       paste0("hobo_temp_", c("min", "max")))){
      var_labels <- c("VEG", "LIC", "BRY", "SHR", 
                      "ROC", "SNO", "LAN", "SOL", "ELE", 
                      "FAT")
      if(labels_display == "left") y_axis_labels_display <- "element_blank()"
      if(labels_display == "all") y_axis_labels_display <- "element_text(hjust = 1, size = rel(0.9))"
    } 
  
  # display x axis title? (only in bottom rows) 
    if(!(response %in% c(paste0("tms_dT2T1_", c("mean", "min", "max")),
                         paste0("hobo_dT4hobo_", c("mean", "min", "max")),
                         paste0("tms_T1_", c("mean", "min", "max")),
                         paste0("hobo_temp_", c("mean", "min", "max"))))){
      x_axis_title_display <- "element_text(size = rel(0.9))"
    } else {
      if(labels_display == "left") x_axis_title_display <- "element_blank()"
      if(labels_display == "all") x_axis_title_display <- "element_text(size = rel(0.9))"
    }  
    
  # display x axis text? (only in bottom rows) 
    if(response %in% c(paste0("tms_dT2T1_", c("mean", "min", "max")),
                       paste0("hobo_dT4hobo_", c("mean", "min", "max")),
                       paste0("tms_T1_", c("mean", "min", "max")),
                       paste0("hobo_temp_", c("mean", "min", "max")),
                       paste0("tms_dT4T1_", c("mean", "min", "max")))){
      x_axis_labels_display <- "element_text(size = rel(0.9))"
      } else {
      if(labels_display == "left") x_axis_labels_display <- "element_blank()"
      if(labels_display == "all") x_axis_labels_display <- "element_text(size = rel(0.9))"
      } 
  
  # position of horizontal dashed lines
    if(response  %>% str_detect("^tms_")){
      hline_pos_low <- 4.5
      hline_pos_mid <- 6.5
    }
    if(response %>% str_detect("^hobo_")){
      hline_pos_low <- 2.5
      hline_pos_mid <- 4.5
    }
    
    
    # Calculate R2 - based on https://www.researchgate.net/post/How_can_I_calculate_R2_for_an_Bayesian_MCMC_multilevel_model
    #                         and eq. 26 in Nakagawa & Schielzeth 2013 > https://doi.org/10.1111/j.2041-210x.2012.00261.x
    # Variance in fitted values
    var_fitted <- var(as.vector(apply(model$Sol,  # calculate variance of predictions based on fixed effects only sigma-squared 
                                      2,          # apply to columns (rows -> 1)
                                      mean) %*%   # calculate mean of fitted solutions for all predictors
                                  t(model$X)))    # multiply by transposed model matrix (to obtain fitted solutions * sampled x values)
    # Calculate marginal R2 
    R2_marg <- var_fitted / (var_fitted + sum(apply(model$VCV, 2, mean)))  # denominator: prediction variance (see above) + sum of variances for random effects and residuals
    # Calculate conditional R2
    R2_cond <- (var_fitted + apply(model$VCV, 2, mean)[names(apply(model$VCV, 2, mean)) != "units"]) / # nominator: prediction variance + sum of variances for random effects, but NOT residuals (= "units")
                (var_fitted + sum(apply(model$VCV, 2, mean)))  # denominator: prediction variance (see above) + sum of variances for random effects and residuals (= units)
  
  
    # build plot  
    mcmc_plot <- ggplot(solutions, aes(x = post.mean, y = variable, 
                                       colour = sig)) +
      
      # vertical dashed line at x = 0
      annotate("segment", 
               x = 0, xend = 0, y = 0, yend = length(var_order) + 1,
               colour = "grey35",
               linetype = "dotted",
               size = 0.8) +
      
      # horizontal dashed lines to separate predictor groups
      annotate("segment",
               x = x_min_value, xend = x_max_value, y = hline_pos_low, yend = hline_pos_low,
               colour = "grey70",
               linetype = "dashed",
               size = 0.4) +
  
      # horizontal dashed lines to separate predictor groups
      annotate("segment",
               x = x_min_value, xend = x_max_value, y = hline_pos_mid, yend = hline_pos_mid,
               colour = "grey70",
               linetype = "dashed",
               size = 0.4) +
      
      # horizontal dashed lines to separate predictor groups
      annotate("segment",
               x = x_min_value, xend = x_max_value, 
               y = length(var_order) - 0.5, yend = length(var_order) - 0.5,
               colour = "grey70",
               linetype = "dashed",
               size = 0.4) +
      
      # posterior 95% CI bars
      geom_segment(aes(x = l95, xend = u95,
                       y = variable, yend = variable),
                   size = 1.5,
                   lineend = "round") +
      
      # mean posterior estimate
      geom_point(size = 2.5, 
                 shape = 23,
                 fill = "white") +
      
      theme_cowplot(14) +
      
      ylab("") +
      
      xlab("") +
      
      scale_colour_manual(values = c("#a6a6a6", theme_colour)) +
      
      scale_x_continuous(limits = c(x_min_value, x_max_value), 
                         breaks = x_axis_breaks) +
      
      scale_y_discrete(limits = var_order,
                       labels = var_labels) +
      
      annotate("text", x = R2_x_pos, y = R2_marg_y_pos, hjust = 0, size = 3,
               label = bquote(R[marg]^{2} == .(round(R2_marg, 2)))) + 
      
      annotate("text", x = R2_x_pos, y = R2_cond_y_pos, hjust = 0, size = 3,
               label = bquote(R[cond]^{2} == .(round(R2_cond, 2)))) + 
      
      theme(plot.title = element_text(colour = theme_colour, size = 15),
            # # add horizontal lines to guide the reader's eye - currently using dashed predictor group separators instead
            # panel.grid.major.y = element_line(colour = "grey80",
            #                                   size = 0.3),
            #plot.margin = margin(t = 0.2, l = 1.3, unit = "cm"),
            legend.position = "none") +
      
      # x axis title (resp. space) display
      eval(parse(text=(paste("theme(axis.title.x = ", x_axis_title_display, ")")))) +
      
      # x axis text display
      eval(parse(text=(paste("theme(axis.text.x = ", x_axis_labels_display, ")")))) +
      
      # y axis text display
      eval(parse(text=(paste("theme(axis.text.y = ", y_axis_labels_display, ")")))) 
    
    return(mcmc_plot)
  }



### Predict deltaT across plot sizes ----

  offset_predict_plot_function_combined <- function(model_object, predictor1, predictor2, radius, add_points = TRUE, add_rect = TRUE, add_R2 = TRUE, add_arrows = FALSE){
    
    response_var <- model_object$response
    model <- model_object$model
    
    if(predictor1 %in% c("rocks", "shrubs", "bryophytes", "lichen")) predictor_var1 <- paste("cov", predictor1, radius, sep = "_")
    
    if(predictor2 %in% c("rocks", "shrubs", "bryophytes", "lichen")) predictor_var2 <- paste("cov", predictor2, radius, sep = "_")
    
    model_solutions_icpt <- model_object$model$Sol[, "(Intercept)"]
    
    model_predictor_vec1 <- model_object$model$X[, predictor_var1]
    model_solutions_xhat1 <- model_object$model$Sol[, predictor_var1]
    
    model_predictor_vec2 <- model_object$model$X[, predictor_var2]
    model_solutions_xhat2 <- model_object$model$Sol[, predictor_var2]
    
    solutions_sig <- data.frame(model_object$model_summary$solutions,
                                     variable = row.names(model_object$model_summary$solutions)) %>% 
      rename_at(vars(everything()), ~ c("post.mean", "l95", "u95", "eff_sample", "pMCMC", "variable")) %>% 
      filter(variable %in% c(predictor_var1, predictor_var2)) %>% 
      # set line type by significance
      mutate(predictor_var = str_extract(variable, "(?<=_)\\w*(?=_)"),
             sig_line = case_when((l95 < 0 & u95 < 0) | (l95 > 0 & u95 > 0) ~ "solid",
                             TRUE ~ "dashed")) %>% 
      select(predictor_var, sig_line)
    
    if(response_var %>% str_detect("dT3T1")){
      temp_strata <- "air - soil"
      if(predictor_var1 %>% str_detect("bryophytes")) theme_colour1 <- theme_gold
      if(predictor_var1 %>% str_detect("shrubs")) theme_colour1 <- theme_brightgold
      if(predictor_var2 %>% str_detect("bryophytes")) theme_colour2 <- theme_gold
      if(predictor_var2 %>% str_detect("shrubs")) theme_colour2 <- theme_brightgold
    }
    if(response_var %>% str_detect("dT3T2")){
      temp_strata <- "air - ground"
      if(predictor_var1 %>% str_detect("bryophytes")) theme_colour1 <- theme_darkgreen
      if(predictor_var1 %>% str_detect("shrubs")) theme_colour1 <- theme_lightgreen
      if(predictor_var2 %>% str_detect("bryophytes")) theme_colour2 <- theme_darkgreen
      if(predictor_var2 %>% str_detect("shrubs")) theme_colour2 <- theme_lightgreen
    }
    if(response_var %>% str_detect("dT2T1")){
      temp_strata <- "ground - soil"
      if(predictor_var1 %>% str_detect("bryophytes")) theme_colour1 <- theme_darkred
      if(predictor_var1 %>% str_detect("shrubs")) theme_colour1 <- theme_lightred
      if(predictor_var2 %>% str_detect("bryophytes")) theme_colour2 <- theme_darkred
      if(predictor_var2 %>% str_detect("shrubs")) theme_colour2 <- theme_lightred
    }
    
    # make x and y labels
    x_label <- paste("cover [%] (r =", radius, "cm)")
    
    if(response_var %>% str_detect("mean")) temp_var <- "mean"
    if(response_var %>% str_detect("min")) temp_var <- "min"
    if(response_var %>% str_detect("max")) temp_var <- "max"
    
    y_label <- paste(temp_strata, temp_var, "T offset [°C]")
    
    # display x axis text only in bottom line
    if(radius == 564) x_axis_text <- c(0, 25, 50, 75, 100)
    if(radius %in% c(10, 50, 200)) x_axis_text <- c(rep("", 5))
    
    # extract predictions
    predictions1 <- sapply(model_predictor_vec1,
                           function(x) model_solutions_icpt + x * model_solutions_xhat1)
    predictions2 <- sapply(model_predictor_vec2,
                           function(x) model_solutions_icpt + x * model_solutions_xhat2)
    
    # extract raw data
    predictor_data_raw1 <- disko_data_complete_season19 %>% 
      drop_na(paste0("veg_height_avg_", radius),
              tms_moist_vol_mean_scaled) %>% 
      pull(predictor_var1)
    predictor_data_raw2 <- disko_data_complete_season19 %>% 
      drop_na(paste0("veg_height_avg_", radius),
              tms_moist_vol_mean_scaled) %>% 
      pull(predictor_var2)
    
    # compile data for plotting
    prediction_plot_data1 <- data.frame(
      predictor_data_raw = disko_data_complete_season19 %>% 
        drop_na(paste0("veg_height_avg_", radius),
                tms_moist_vol_mean_scaled) %>% 
        pull(predictor_var1),
      response_data = disko_data_complete_season19 %>% 
        drop_na(paste0("veg_height_avg_", radius),
                tms_moist_vol_mean_scaled) %>% 
        pull(response_var),
      preds_mean = apply(predictions1, 2, mean),
      preds_l95 = apply(predictions1, 2, quantile, probs = 0.05),
      preds_u95 = apply(predictions1, 2, quantile, probs = 0.95),
      predictor_var = paste(predictor1)
    ) 
    prediction_plot_data2 <- data.frame(
      predictor_data_raw = disko_data_complete_season19 %>% 
        drop_na(paste0("veg_height_avg_", radius),
                tms_moist_vol_mean_scaled) %>% 
        pull(predictor_var2),
      response_data = disko_data_complete_season19 %>% 
        drop_na(paste0("veg_height_avg_", radius),
                tms_moist_vol_mean_scaled) %>% 
        pull(response_var),
      preds_mean = apply(predictions2, 2, mean),
      preds_l95 = apply(predictions2, 2, quantile, probs = 0.05),
      preds_u95 = apply(predictions2, 2, quantile, probs = 0.95),
      predictor_var = paste(predictor2)
    ) 
    
    prediction_plot_data <- bind_rows(prediction_plot_data1, prediction_plot_data2) %>% 
      # add line type col to indicate significance
      left_join(solutions_sig, by = "predictor_var") %>% 
      # reorder variables to shrubs > bryophytes
      mutate(predictor_var = fct_reorder(predictor_var, desc(predictor_var)),
             sig_line = factor(sig_line),
             sig_line = fct_reorder(sig_line, desc(sig_line))) %>% as_tibble()
    
    # define axis range
    y_min <- floor(mean(c(min(prediction_plot_data$response_data, na.rm = T),
                          max(prediction_plot_data$response_data, na.rm = T))) - 6)
    y_max <- ceiling(mean(c(min(prediction_plot_data$response_data, na.rm = T),
                            max(prediction_plot_data$response_data, na.rm = T))) + 6)
    
    # Calculate R2 - based on https://www.researchgate.net/post/How_can_I_calculate_R2_for_an_Bayesian_MCMC_multilevel_model
    #                         and eq. 26 in Nakagawa & Schielzeth 2013 > https://doi.org/10.1111/j.2041-210x.2012.00261.x
    # Variance in fitted values
    var_fitted <- var(as.vector(apply(model$Sol,  # calculate variance of predictions based on fixed effects only sigma-squared 
                                      2,          # apply to columns (rows -> 1)
                                      mean) %*%   # calculate mean of fitted solutions for all predictors
                                  t(model$X)))    # multiply by transposed model matrix (to obtain fitted solutions * sampled x values)
    # Calculate marginal R2 
    R2_marg <- var_fitted / (var_fitted + sum(apply(model$VCV, 2, mean)))  # denominator: prediction variance (see above) + sum of variances for random effects and residuals
    # Calculate conditional R2
    R2_cond <- (var_fitted + apply(model$VCV, 2, mean)[names(apply(model$VCV, 2, mean)) != "units"]) / # nominator: prediction variance + sum of variances for random effects, but NOT residuals (= "units")
      (var_fitted + sum(apply(model$VCV, 2, mean)))  # denominator: prediction variance (see above) + sum of variances for random effects and residuals (= units)
    
    # R2 label positions
    R2_marg_y_pos <- y_min + 0.27 * (y_max - y_min)
    R2_cond_y_pos <- y_min + 0.13 * (y_max - y_min)
    
    # compile plot
    prediction_plot <- ggplot(data = prediction_plot_data,
                              aes(x = predictor_data_raw, y = response_data)) +
      
      # data points if add_points = T
      {if(add_points)
        geom_quasirandom(aes(fill = predictor_var),
                         col = "grey70",
                         alpha = 0.15,
                         width = 0.75,
                         shape = 21,
                         size = 3)} +
      
      # add transparent rectangle if add_rect = T
      {if(add_rect)
        geom_rect(aes(xmin = -Inf, xmax = Inf,
                      ymin = -Inf, ymax = Inf),
                  colour = NA,
                  fill = "white",
                  alpha = 0.2)} +
      
      # predicted relationship - mean
      geom_line(aes(y = preds_mean,
                    colour = predictor_var,
                    linetype = sig_line), 
                size = 1.3) +
      
      # predicted relationship - 95% CI
      geom_ribbon(aes(ymin = preds_l95, 
                      ymax = preds_u95,
                      fill = predictor_var), 
                  alpha = 0.45) +
      
      # R2 labels
      {if(add_R2)
        annotate("text", x = 5, y = R2_marg_y_pos, hjust = 0, size = 4,
                 label = bquote(R[marg]^{2} == .(round(R2_marg, 2))))} + 
          
      {if(add_R2)
        annotate("text", x = 5, y = R2_cond_y_pos, hjust = 0, size = 4,
                 label = bquote(R[cond]^{2} == .(round(R2_cond, 2))))} + 
      
      {if(temp_var == "mean"){
        if(add_arrows)
          geom_segment(data = x_icpts %>% filter(plot.circle.radius == radius),
                       aes(x = threshold.cover.., xend = threshold.cover.., 
                           y = y_min + 0.5, yend = y_min,
                           colour = cover.variable),
                       lineend = "round", linejoin = "mitre",
                       arrow = arrow(length = unit(0.20, "cm"), ends = "last", type = "closed"), 
                       show.legend = FALSE,
                       size = 1)}} + 
    
      # plot appearance
      
      # define colour levels
      scale_colour_manual(values = c(theme_colour2, theme_colour1)) +
      scale_fill_manual(values = c(theme_colour2, theme_colour1)) +
      
      # x axis text and range range
      scale_x_continuous(labels = x_axis_text,
                         limits = c(0, 100),
                         breaks = c(0, 25, 50, 75, 100)) +
      
      # y axis range
      scale_y_continuous(limits = c(y_min, y_max),
                         breaks = seq(y_min, y_max, 4)) +
      
      # axis labels
      labs(x = x_label,
           y = y_label) +
      
      # legend design
      guides(fill = "none", linetype = "none") +
      
      theme_cowplot(18) +
      
      # outside axis labels -> remove axis labels
      theme(axis.title = element_blank(),
            legend.title = element_blank())
    
    return(prediction_plot)
  }

  offset_predict_plot_function_separate <- function(model_object, predictor, radius = NULL, add_points = TRUE, add_rect = FALSE, add_R2 = TRUE){
    
    response_var <- model_object$response
    model <- model_object$model
    
    if(predictor %in% c("rocks", "shrubs", "bryophytes", "lichen")) predictor_var <- paste("cov", predictor, radius, sep = "_")
    if(predictor == "veg_height") predictor_var <- paste0("veg_height_avg_", radius)
    if(predictor %in% c("elevation", "slope", "sri_season19")) predictor_var <- predictor
    if(predictor %in% c("topo", "topography")) predictor_var <- "topo_prim_num"
    if(predictor %in% c("moist", "soil_moist", "moisture")) predictor_var <- "tms_moist_vol_mean_scaled"
    
    if(predictor %in% c("ndvi", "NDVI")) predictor_var <- "ndvi_564"
    if(predictor %in% c("kndvi", "kNDVI")) predictor_var <- "kndvi_564"
    
    model_predictor_vec <- model_object$model$X[, predictor_var]
    model_solutions_icpt <- model_object$model$Sol[, "(Intercept)"]
    model_solutions_xhat <- model_object$model$Sol[, predictor_var]
    
    solutions_sig_linetype <- data.frame(model_object$model_summary$solutions,
                                variable = row.names(model_object$model_summary$solutions)) %>% 
      rename_at(vars(everything()), ~ c("post.mean", "l95", "u95", "eff_sample", "pMCMC", "variable")) %>% 
      filter(variable == predictor_var) %>% 
      # set line type by significance
      mutate(predictor_var = str_remove(predictor_var, "_\\d{2,3}$"),
             sig_line = case_when((l95 < 0 & u95 < 0) | (l95 > 0 & u95 > 0) ~ "solid",
                                  TRUE ~ "dashed")) %>% 
      pull(sig_line)
    
    if(response_var %>% str_detect("dT3T1")){
      temp_strata <- "air - soil"
      if(predictor_var %>% str_detect("veg_height")) theme_colour <- theme_yellow
      if(predictor_var %>% str_detect("bryophytes")) theme_colour <- theme_lightgreen
      if(predictor_var %>% str_detect("shrubs")) theme_colour <- theme_darkgreen
      if(predictor_var %>% str_detect("ndvi")) theme_colour <- theme_yellow
    }
    if(response_var %>% str_detect("dT3T2")){
      temp_strata <- "air - ground"
      if(predictor_var %>% str_detect("bryophytes")) theme_colour <- theme_brightgold
      if(predictor_var %>% str_detect("shrubs")) theme_colour <- theme_gold
    }
    if(response_var %>% str_detect("dT2T1")){
      temp_strata <- "ground - soil"
      if(predictor_var %>% str_detect("bryophytes")) theme_colour <- theme_darkred
      if(predictor_var %>% str_detect("shrubs")) theme_colour <- theme_lightred
    }
    
    line_colour <- theme_colour
    if(predictor_var %>% str_detect("ndvi")) line_colour <- theme_forestgreen
    
    # make x and y labels
    if(predictor_var == "elevation") x_label <- "altitude [m.a.s.l.]"
    if(predictor_var == "slope") x_label <- "slope angle [°]"
    if(predictor_var %>% str_detect("sri")) x_label <- "Solar Radiation Index [-]"
    if(predictor_var == "topo_prim_num") x_label <- "landform type"
    if(predictor_var == "tms_moist_vol_mean") x_label <- "vol. soil moisture"
    if(predictor_var %>% str_detect("cov_rocks")) x_label <- paste0("rock cover [%] (r = ", radius, " cm)")
    if(predictor_var %>% str_detect("cov_shrubs")) x_label <- paste0("shrub cover [%] (r = ", radius, " cm)")
    if(predictor_var %>% str_detect("cov_bryophytes")) x_label <- paste0("bryophyte cover [%] (r = ", radius, " cm)")
    if(predictor_var %>% str_detect("cov_lichen")) x_label <- paste0("lichen cover [%] (r = ", radius, " cm)")
    if(predictor_var%>% str_detect("veg_height_avg")) x_label <- paste0("average vegetation height [cm] (r = ", radius, " cm)")
    if(predictor_var%>% str_detect("kndvi_564")) x_label <- "kernel NDVI"
    
    if(response_var %>% str_detect("mean")) temp_var <- "mean"
    if(response_var %>% str_detect("min")) temp_var <- "min"
    if(response_var %>% str_detect("max")) temp_var <- "max"
    
    y_label <- paste(temp_strata, temp_var, "T offset [°C]")
    
    raw_data <- disko_data_complete_season19
    if(predictor %>% str_detect("ndvi")) raw_data <- disko_data_season19_greenness
    
    # extract predictions
    predictions <- sapply(model_predictor_vec,
                          function(x) model_solutions_icpt + x * model_solutions_xhat)
    
    # extract raw data
    predictor_data_raw <- raw_data %>% 
      # remove missing values for moisture and evt predictor
      {if(!predictor_var %>% str_detect("ndvi")) drop_na(., tms_moist_vol_mean_scaled) else .} %>% 
      {if(!is.null(radius)){
        if(radius == 564) drop_na(., all_of(predictor_var)) else .} else .} %>% 
      pull(all_of(predictor_var))
    
    # compile data for plotting
    prediction_plot_data <- data.frame(
      predictor_data_raw = raw_data %>% 
        # remove missing values for moisture and evt predictor
        {if(!predictor_var %>% str_detect("ndvi")) drop_na(., tms_moist_vol_mean_scaled) else .} %>% 
        {if(!is.null(radius)){
          if(radius == 564) drop_na(., all_of(predictor_var)) else .} else .} %>% 
        pull(all_of(predictor_var)),
      response_data = raw_data %>% 
        # remove missing values for moisture and evt predictor
        {if(!predictor_var %>% str_detect("ndvi")) drop_na(., tms_moist_vol_mean_scaled) else .} %>% 
        {if(!is.null(radius)){
          if(radius == 564) drop_na(., all_of(predictor_var)) else .} else .} %>% 
        pull(all_of(response_var)),
      preds_mean = apply(predictions, 2, mean),
      preds_l95 = apply(predictions, 2, quantile, probs = 0.05),
      preds_u95 = apply(predictions, 2, quantile, probs = 0.95),
      sig_line = paste0(solutions_sig_linetype)
    ) 
    
    # define axis range
    y_min <- floor(mean(c(min(prediction_plot_data$response_data, na.rm = T),
                          max(prediction_plot_data$response_data, na.rm = T))) - 15)
    y_max <- ceiling(mean(c(min(prediction_plot_data$response_data, na.rm = T),
                            max(prediction_plot_data$response_data, na.rm = T))) + 15)
    
    # Calculate R2 - based on https://www.researchgate.net/post/How_can_I_calculate_R2_for_an_Bayesian_MCMC_multilevel_model
    #                         and eq. 26 in Nakagawa & Schielzeth 2013 > https://doi.org/10.1111/j.2041-210x.2012.00261.x
    # Variance in fitted values
    var_fitted <- var(as.vector(apply(model$Sol,  # calculate variance of predictions based on fixed effects only sigma-squared 
                                      2,          # apply to columns (rows -> 1)
                                      mean) %*%   # calculate mean of fitted solutions for all predictors
                                  t(model$X)))    # multiply by transposed model matrix (to obtain fitted solutions * sampled x values)
    # Calculate marginal R2 
    R2_marg <- var_fitted / (var_fitted + sum(apply(model$VCV, 2, mean)))  # denominator: prediction variance (see above) + sum of variances for random effects and residuals
    # Calculate conditional R2
    R2_cond <- (var_fitted + apply(model$VCV, 2, mean)[names(apply(model$VCV, 2, mean)) != "units"]) / # nominator: prediction variance + sum of variances for random effects, but NOT residuals (= "units")
      (var_fitted + sum(apply(model$VCV, 2, mean)))  # denominator: prediction variance (see above) + sum of variances for random effects and residuals (= units)
    
    # R2 label positions
    R2_x_pos <- 0.05 * diff(range(prediction_plot_data$predictor_data_raw))
    R2_marg_y_pos <- y_min + 0.2 * (y_max - y_min)
    R2_cond_y_pos <- y_min + 0.05 * (y_max - y_min)
    
    # point jitter width
    jitter_width <- 0.0075 * diff(range(prediction_plot_data$predictor_data_raw))
    
    # Compile plot
    prediction_plot <- ggplot(data = prediction_plot_data,
                              aes(x = predictor_data_raw, y = response_data)) +
      
      # data points if add_points = T
      {if(add_points)
        geom_quasirandom(fill = theme_colour,
                         col = "grey70",
                         alpha = 0.15,
                         width = jitter_width,
                         shape = 21,
                         size = 3)} +
      
      # add transparent rectangle if add_rect = T
      {if(add_rect)
        geom_rect(aes(xmin = -Inf, xmax = Inf,
                      ymin = -Inf, ymax = Inf),
                  colour = NA,
                  fill = "white",
                  alpha = 0.2)} +
      
      # predicted relationship - mean
      geom_line(aes(y = preds_mean,
                    linetype = sig_line), 
                size = 1.3,
                col = line_colour) +
      
      # predicted relationship - 95% CI
      geom_ribbon(aes(ymin = preds_l95, 
                      ymax = preds_u95), 
                  alpha = 0.25, 
                  fill = line_colour) +
      
      # y axis range
      scale_y_continuous(limits = c(y_min, y_max),
                         breaks = seq(y_min, y_max, 10)) +
      
      # R2 labels
      {if(add_R2)
        annotate("text", x = R2_x_pos, y = R2_marg_y_pos, hjust = 0, size = 4,
                 label = bquote(R[marg]^{2} == .(round(R2_marg, 2))))} + 
      
      {if(add_R2)
        annotate("text", x = R2_x_pos, y = R2_cond_y_pos, hjust = 0, size = 4,
                 label = bquote(R[cond]^{2} == .(round(R2_cond, 2))))} + 
      
      # plot appearance
      
      # axis labels
      labs(x = x_label,
           y = y_label) +
      
      theme_cowplot(18) +
      
      # outside axis labels -> remove axis labels
      theme(axis.title = element_blank())
    
    return(prediction_plot)
  }
    
    
### Extract x axis intercept (positive-negative deltaT switch point) from predictions ----
  offset_predict_x_icpt <- function(model_object, predictor1, predictor2, radius){
    
    response_string <- model_object$response %>% str_remove("^tms_")
    if(model_object$response %>% str_detect("tms_.*_season19")) response_string <- model_object$response %>% str_remove("^tms_") %>% str_remove("_season19")
    if(str_detect(response_string, "dT\\dT")) response_strata <- response_string %>% str_extract("dT\\dT\\d")
    model_string <- paste0(response_strata, "_", radius)
    
    if(predictor1 %in% c("rocks", "shrubs", "bryophytes", "lichen")) predictor_var1 <- paste("cov", predictor1, radius, sep = "_")
    
    if(predictor2 %in% c("rocks", "shrubs", "bryophytes", "lichen")) predictor_var2 <- paste("cov", predictor2, radius, sep = "_")
    
    model_solutions_icpt <- model_object$model$Sol[, "(Intercept)"]
    
    model_predictor_vec1 <- model_object$model$X[, predictor_var1]
    model_solutions_xhat1 <- model_object$model$Sol[, predictor_var1]
    
    model_predictor_vec2 <- model_object$model$X[, predictor_var2]
    model_solutions_xhat2 <- model_object$model$Sol[, predictor_var2]
    
    # extract predictions
    predictions1 <- sapply(model_predictor_vec1,
                           function(x) model_solutions_icpt + x * model_solutions_xhat1)
    predictions2 <- sapply(model_predictor_vec2,
                           function(x) model_solutions_icpt + x * model_solutions_xhat2)
    
    # compile data for linear models
    prediction_data1 <- data.frame(
      predictor_data_raw = disko_data_complete_season19 %>% 
        drop_na(paste0("veg_height_avg_", radius),
                tms_moist_vol_mean_scaled) %>% 
        pull(predictor_var1),
      preds_mean = apply(predictions1, 2, mean)
    ) 
    prediction_data2 <- data.frame(
      predictor_data_raw = disko_data_complete_season19 %>% 
        drop_na(paste0("veg_height_avg_", radius),
                tms_moist_vol_mean_scaled) %>% 
        pull(predictor_var2),
      preds_mean = apply(predictions2, 2, mean)
    ) 
    
    # run LMs on predictions
    lm_pred1 <- lm(preds_mean ~ predictor_data_raw,
                   data = prediction_data1)
    lm_pred2 <- lm(preds_mean ~ predictor_data_raw,
                   data = prediction_data2)
    
    # extract coefficients and calculate x intercept
    lm_pred1_icpt <- -lm_pred1$coefficients[1]/lm_pred1$coefficients[2]
    lm_pred2_icpt <- -lm_pred2$coefficients[1]/lm_pred2$coefficients[2]
    
    # compile into df
    x_icpt_df <- data.frame(
      "plot circle radius" = rep(radius, 2),
      "cover variable" = c(predictor1, predictor2),
      "threshold cover %" = c(lm_pred1_icpt, lm_pred2_icpt)
    )
    return(x_icpt_df)
  }

### Extrapolate microclimate from (k)NDVI ----
  # calculate NDVI
  ndvi <- function(img){
    red_band <- img[["RED"]]
    nir_band <- img[["NIR"]]
    ndvi_layer <- (nir_band - red_band) / (nir_band + red_band)
    names(ndvi_layer) <- "NDVI"
    return(ndvi_layer)
  }
  
  # calculate kNDVI
  kndvi <- function(img){
    ndvi_layer <- img[["NDVI"]]
    kndvi_layer <- tanh((ndvi_layer)^2)
    names(kndvi_layer) <- "kNDVI"
    return(kndvi_layer)
  }
  
### >> functions for masking ----
  # calculate NDWI
  ndwi <- function(img){
    nir_band <- img[["NIR"]]
    swir_band <- img[["SWIR"]]
    ndwi_layer <- (nir_band - swir_band) / (nir_band + swir_band)
    names(ndwi_layer) <- "NDWI"
    return(ndwi_layer)
  }
  
  # calculate NDSI
  ndsi <- function(img){
    nir_band <- img[["VIR"]]
    swir_band <- img[["SWIR"]]
    ndsi_layer <- (nir_band - swir_band) / (nir_band + swir_band)
    names(ndsi_layer) <- "NDSI"
    return(ndsi_layer)
  }
  
### ______________ ----
### end of script----